"""Google address model."""

# pylint: disable=too-many-lines,line-too-long
import datetime
import logging
from collections import namedtuple
from typing import Any

import geocoder  # type: ignore
import pytest_is_running
import requests_cache
from timezonefinder import TimezoneFinder  # type: ignore

from ...cache import MEMORY
from ..address_model import AddressModel
from ..weather.multi_weather_model import create_mutli_weather_model

SportsballGeocodeTuple = namedtuple(
    "SportsballGeocodeTuple",
    ["city", "state", "postal", "lat", "lng", "housenumber", "country"],
)
LEVI_STADIUM = SportsballGeocodeTuple(
    city="Santa Clara",
    state="CA",
    postal="95054",
    lat=37.4033165,
    lng=-121.9719523,
    housenumber="4900",
    country="USA",
)
ARROWHEAD_STADIUM = SportsballGeocodeTuple(
    city="Kansas City",
    state="MO",
    postal="64129",
    lat=39.0489647,
    lng=-94.486589,
    housenumber="1",
    country="USA",
)
PAYCOR_STADIUM = SportsballGeocodeTuple(
    city="Cincinnati",
    state="OH",
    postal="45202",
    lat=39.0954576,
    lng=-84.5186326,
    housenumber="1",
    country="USA",
)
LUMEN_FIELD = SportsballGeocodeTuple(
    city="Seattle",
    state="WA",
    postal="98134",
    lat=47.5951518,
    lng=-122.3342143,
    housenumber="800",
    country="USA",
)
CAESARS_SUPERDOME = SportsballGeocodeTuple(
    city="New Orleans",
    state="LA",
    postal="70112",
    lat=29.951061,
    lng=-90.0838191,
    housenumber="1500",
    country="USA",
)
TOM_BENSON_HALL_OF_FAME_STADIUM = SportsballGeocodeTuple(
    city="Canton",
    state="OH",
    postal="44708",
    lat=40.8198713,
    lng=-81.4028911,
    housenumber="",
    country="USA",
)
GILETTE_STADIUM = SportsballGeocodeTuple(
    city="Foxborough",
    state="MA",
    postal="02035",
    lat=42.0909458,
    lng=-71.2669214,
    housenumber="1",
    country="USA",
)
FORD_FIELD = SportsballGeocodeTuple(
    city="Detroit",
    state="MI",
    postal="48226",
    lat=42.3400064,
    lng=-83.0481779,
    housenumber="2000",
    country="USA",
)
HARD_ROCK_STADIUM = SportsballGeocodeTuple(
    city="Miami Gardens",
    state="FL",
    postal="33056",
    lat=25.958326,
    lng=-80.2421728,
    housenumber="100",
    country="USA",
)
RAYMOND_JAMES_STADIUM = SportsballGeocodeTuple(
    city="Tampa",
    state="FL",
    postal="33607",
    lat=27.9758691,
    lng=-82.5059093,
    housenumber="4201",
    country="USA",
)
CLEVELAND_BROWNS_STADIUM = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="44114",
    lat=41.5060535,
    lng=-81.702123,
    housenumber="100",
    country="USA",
)
STATE_FARM_STADIUM = SportsballGeocodeTuple(
    city="Glendale",
    state="AZ",
    postal="85305",
    lat=33.5276247,
    lng=-112.2651342,
    housenumber="1001",
    country="USA",
)
HIGHMARK_STADIUM = SportsballGeocodeTuple(
    city="Orchard Park",
    state="NY",
    postal="14127",
    lat=42.7737546,
    lng=-78.7895472,
    housenumber="1",
    country="USA",
)
SOLDIER_FIELD = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="60605",
    lat=41.8623132,
    lng=-87.6192633,
    housenumber="1410",
    country="USA",
)
BANK_OF_AMERICA_STADIUM = SportsballGeocodeTuple(
    city="Charlotte",
    state="NC",
    postal="28202",
    lat=35.2257795,
    lng=-80.8555399,
    housenumber="800",
    country="USA",
)
ATT_STADIUM = SportsballGeocodeTuple(
    city="Arlington",
    state="TX",
    postal="76011",
    lat=32.7479966,
    lng=-97.0959914,
    housenumber="1",
    country="USA",
)
MTT_BANK_STADIUM = SportsballGeocodeTuple(
    city="Baltimore",
    state="FL",
    postal="21230",
    lat=39.2778666,
    lng=-76.6255186,
    housenumber="101",
    country="USA",
)
SOFI_STADIUM = SportsballGeocodeTuple(
    city="Inglewood",
    state="CA",
    postal="90301",
    lat=33.9534651,
    lng=-118.3416145,
    housenumber="1001",
    country="USA",
)
ALLEGIANT_STADIUM = SportsballGeocodeTuple(
    city="Las Vegas",
    state="NV",
    postal="89118",
    lat=36.0908665,
    lng=-115.1858971,
    housenumber="3333",
    country="USA",
)
LINCOLN_FINANCIAL_FIELD = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="19148",
    lat=39.9013695,
    lng=-75.1700964,
    housenumber="",
    country="USA",
)
METLIFE_STADIUM = SportsballGeocodeTuple(
    city="East Rutherford",
    state="NJ",
    postal="07073",
    lat=40.8135064,
    lng=-74.0770319,
    housenumber="1",
    country="USA",
)
MERCEDES_BANZ_STADIUM = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="30313",
    lat=33.7553232,
    lng=-84.4031654,
    housenumber="1",
    country="USA",
)
NRG_STADIUM = SportsballGeocodeTuple(
    city="Houston",
    state="TX",
    postal="77054",
    lat=29.6847219,
    lng=-95.4132823,
    housenumber="",
    country="USA",
)
ACRISURE_STADIUM = SportsballGeocodeTuple(
    city="Pittsburgh",
    state="PA",
    postal="15212",
    lat=40.4467648,
    lng=-80.0183352,
    housenumber="100",
    country="USA",
)
LUCAS_OIL_STADIUM = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="46225",
    lat=39.7601007,
    lng=-86.1664626,
    housenumber="500",
    country="USA",
)
LAMBEAU_FIELD = SportsballGeocodeTuple(
    city="Green Bay",
    state="WI",
    postal="54304",
    lat=44.5013406,
    lng=-88.0647832,
    housenumber="1265",
    country="USA",
)
US_BANK_STADIUM = SportsballGeocodeTuple(
    city="Minneapolis",
    state="MN",
    postal="55415",
    lat=44.9736461,
    lng=-93.2600694,
    housenumber="401",
    country="USA",
)
FEDEX_FIELD = SportsballGeocodeTuple(
    city="Landover",
    state="MD",
    postal="20785",
    lat=38.9081324,
    lng=-76.8665633,
    housenumber="1600",
    country="USA",
)
NISSAN_STADIUM = SportsballGeocodeTuple(
    city="Nashville",
    state="TN",
    postal="37213",
    lat=36.166469,
    lng=-86.7738744,
    housenumber="1",
    country="USA",
)
EVERBANK_STADIUM = SportsballGeocodeTuple(
    city="Jacksonville",
    state="FL",
    postal="32202",
    lat=30.3239099,
    lng=-81.6399246,
    housenumber="1",
    country="USA",
)
EMPOWER_FIELD = SportsballGeocodeTuple(
    city="Denver",
    state="CO",
    postal="80204",
    lat=39.7438895,
    lng=-105.0226843,
    housenumber="1701",
    country="USA",
)
WEMBLEY_STADIUM = SportsballGeocodeTuple(
    city="Wembley",
    state="",
    postal="HA9 0WS",
    lat=51.5560247,
    lng=-0.2821926,
    housenumber="",
    country="UK",
)
TOTTENHAM_HOTSPURS_STADIUM = SportsballGeocodeTuple(
    city="London",
    state="",
    postal="N17 0BX",
    lat=51.6042204,
    lng=-0.071094,
    housenumber="782",
    country="UK",
)
DEUTSCHE_BANK_PARK = SportsballGeocodeTuple(
    city="Frankfurt am Main",
    state="",
    postal="60528",
    lat=50.0685807,
    lng=8.6428971,
    housenumber="362",
    country="Germany",
)
ALLIANZ_ARENA = SportsballGeocodeTuple(
    city="München",
    state="",
    postal="80939",
    lat=48.2187966,
    lng=11.6221325,
    housenumber="25",
    country="Germany",
)
GEORGIA_DOME = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="",
    lat=33.758,
    lng=-84.401,
    housenumber="1",
    country="USA",
)
TRANS_WORLD_DOME = SportsballGeocodeTuple(
    city="St. Louis",
    state="MO",
    postal="63101",
    lat=38.6328232,
    lng=-90.1910817,
    housenumber="701",
    country="USA",
)
CANDLESTICK_PARK = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="94124",
    lat=37.7129826,
    lng=-122.4064101,
    housenumber="",
    country="USA",
)
SILVERDOME = SportsballGeocodeTuple(
    city="Pontiac",
    state="MI",
    postal="48342",
    lat=42.6456689,
    lng=-83.2572144,
    housenumber="",
    country="USA",
)
TEXAS_STADIUM = SportsballGeocodeTuple(
    city="Irving",
    state="TX",
    postal="",
    lat=32.839722,
    lng=-96.9146954,
    housenumber="",
    country="USA",
)
SDCCU_STADIUM = SportsballGeocodeTuple(
    city="San Diego",
    state="CA",
    postal="92108",
    lat=32.7809825,
    lng=-117.1244523,
    housenumber="9449",
    country="USA",
)
MOUNTAIN_AMERICA_STADIUM = SportsballGeocodeTuple(
    city="Tempe",
    state="AZ",
    postal="85287",
    lat=33.4264574,
    lng=-111.9374442,
    housenumber="500",
    country="USA",
)
LOS_ANGELES_MEMORIAL_COLESIUM = SportsballGeocodeTuple(
    city="Los Angeles",
    state="CA",
    postal="90037",
    lat=34.0136647,
    lng=-118.2904104,
    housenumber="3911",
    country="USA",
)
KEZAR_STADIUM = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="94118",
    lat=37.7669182,
    lng=-122.4567445,
    housenumber="670",
    country="USA",
)
CITY_STADIUM = SportsballGeocodeTuple(
    city="Green Bay",
    state="WI",
    postal="54301",
    lat=44.5076658,
    lng=-87.9975486,
    housenumber="1500",
    country="USA",
)
COTTON_BOWL = SportsballGeocodeTuple(
    city="Dallas",
    state="TX",
    postal="75215",
    lat=32.7796106,
    lng=-96.7602328,
    housenumber="3750",
    country="USA",
)
WRIGLEY_FIELD = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="60613",
    lat=41.9484384,
    lng=-87.6579076,
    housenumber="1060",
    country="USA",
)
YANKEE_STADIUM = SportsballGeocodeTuple(
    city="Bronx",
    state="NY",
    postal="10451",
    lat=40.8296425,
    lng=-73.9310454,
    housenumber="1",
    country="USA",
)
TIGER_STADIUM = SportsballGeocodeTuple(
    city="Baton Rouge",
    state="LA",
    postal="70803",
    lat=30.412035,
    lng=-91.1863912,
    housenumber="",
    country="USA",
)
RFK_STADIUM = SportsballGeocodeTuple(
    city="Washington",
    state="DC",
    postal="20003",
    lat=38.8898525,
    lng=-76.9731573,
    housenumber="2400",
    country="USA",
)
WAR_MEMORIAL_STADIUM = SportsballGeocodeTuple(
    city="Little Rock",
    state="AR",
    postal="72205",
    lat=34.749861,
    lng=-92.3314143,
    housenumber="",
    country="USA",
)
SHEA_STADIUM = SportsballGeocodeTuple(
    city="Flushing",
    state="NY",
    postal="11368",
    lat=40.7570861,
    lng=-73.8653052,
    housenumber="41",
    country="USA",
)
MUNICIPAL_STADIUM = SportsballGeocodeTuple(
    city="Kansas City",
    state="MS",
    postal="",
    lat=39.087,
    lng=-94.558,
    housenumber="2123",
    country="USA",
)
YALE_BOWL = SportsballGeocodeTuple(
    city="New Haven",
    state="CT",
    postal="06515",
    lat=41.3132191,
    lng=-72.9630891,
    housenumber="81",
    country="USA",
)
RICE_STADIUM = SportsballGeocodeTuple(
    city="Houston",
    state="TX",
    postal="77005",
    lat=29.7162887,
    lng=-95.41188622,
    housenumber="6100",
    country="USA",
)
ROSE_BOWL = SportsballGeocodeTuple(
    city="Pasadena",
    state="CA",
    postal="91103",
    lat=34.1613284,
    lng=-118.1702211,
    housenumber="1001",
    country="USA",
)
MILWAUKEE_COUNTY_STADIUM = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="53208",
    lat=43.0303919,
    lng=-87.9787396,
    housenumber="201",
    country="USA",
)
STANFORD_STADIUM = SportsballGeocodeTuple(
    city="Stanford",
    state="CA",
    postal="94305",
    lat=37.4345298,
    lng=-122.1636976,
    housenumber="625",
    country="USA",
)
LIBERTY_BOWL_MEMORIAL_STADIUM = SportsballGeocodeTuple(
    city="Memphis",
    state="TN",
    postal="38119",
    lat=35.1213707,
    lng=-89.9969239,
    housenumber="959",
    country="USA",
)
NEO_QUIMICA_ARENA = SportsballGeocodeTuple(
    city="São Paulo",
    state="SP",
    postal="08295-005",
    lat=-23.5453134,
    lng=-46.4768041,
    housenumber="111",
    country="Brazil",
)
MCG = SportsballGeocodeTuple(
    city="Richmond",
    state="VIC",
    postal="3002",
    lat=-37.8199668,
    lng=144.9785784,
    housenumber="",
    country="USA",
)
SCG = SportsballGeocodeTuple(
    city="Moore Park",
    state="NSW",
    postal="2021",
    lat=-33.8915316,
    lng=151.2248515,
    housenumber="",
    country="Australia",
)
ENGIE_STADIUM = SportsballGeocodeTuple(
    city="Sydney Olympic Park",
    state="NSW",
    postal="2127",
    lat=-33.8471156,
    lng=151.0608386,
    housenumber="",
    country="Australia",
)
ADELAIDE_OVAL = SportsballGeocodeTuple(
    city="North Adelaide",
    state="SA",
    postal="5006",
    lat=-34.9156273,
    lng=138.5914356,
    housenumber="70",
    country="Australia",
)
GABBA = SportsballGeocodeTuple(
    city="Woolloongabba",
    state="QLD",
    postal="4102",
    lat=-27.4858375,
    lng=153.0332144,
    housenumber="",
    country="Australia",
)
OPTUS_STADIUM = SportsballGeocodeTuple(
    city="Burswood",
    state="WA",
    postal="6100",
    lat=-31.9511597,
    lng=115.884175,
    housenumber="333",
    country="Australia",
)
MARVEL_STADIUM = SportsballGeocodeTuple(
    city="Docklands",
    state="VIC",
    postal="3008",
    lat=-37.8165647,
    lng=144.9449306,
    housenumber="740",
    country="Australia",
)
MARS_STADIUM = SportsballGeocodeTuple(
    city="Wendouree",
    state="VIC",
    postal="3355",
    lat=-37.5386166,
    lng=143.8273839,
    housenumber="725",
    country="Australia",
)
GMHBA_STADIUM = SportsballGeocodeTuple(
    city="South Geelong",
    state="VIC",
    postal="3220",
    lat=-38.1579979,
    lng=144.3520981,
    housenumber="370",
    country="Australia",
)
UTAS_STADIUM = SportsballGeocodeTuple(
    city="Invermay",
    state="TAS",
    postal="7248",
    lat=-41.4259371,
    lng=147.137879,
    housenumber="2",
    country="Australia",
)
PEOPLE_FIRST_STADIUM = SportsballGeocodeTuple(
    city="Carrara",
    state="QLD",
    postal="4211",
    lat=-28.0063039,
    lng=153.3645259,
    housenumber="",
    country="Australia",
)
BLUNDSTONE_ARENA = SportsballGeocodeTuple(
    city="Bellerive",
    state="TAS",
    postal="7018",
    lat=-42.8772962,
    lng=147.3691419,
    housenumber="15",
    country="Australia",
)
MANUKA_OVAL = SportsballGeocodeTuple(
    city="Griffith",
    state="ACT",
    postal="2603",
    lat=-35.3181329,
    lng=149.1297911,
    housenumber="",
    country="Australia",
)
TIO_STADIUM = SportsballGeocodeTuple(
    city="Marrara",
    state="NT",
    postal="0812",
    lat=-12.3991939,
    lng=130.8847367,
    housenumber="70",
    country="Australia",
)
NORWOOD_OVAL = SportsballGeocodeTuple(
    city="Norwood",
    state="SA",
    postal="5067",
    lat=-34.9198089,
    lng=138.6278735,
    housenumber="",
    country="Australia",
)
ADELAIDE_HILLS = SportsballGeocodeTuple(
    city="Mount Barker Summit",
    state="SA",
    postal="5251",
    lat=-35.0779754,
    lng=138.8908443,
    housenumber="304",
    country="Australia",
)
TRAEGER_PARK = SportsballGeocodeTuple(
    city="The Gap",
    state="NT",
    postal="0870",
    lat=-23.7090566,
    lng=133.8701488,
    housenumber="",
    country="Australia",
)
CAZALYS_STADIUM = SportsballGeocodeTuple(
    city="Westcourt",
    state="QLD",
    postal="4870",
    lat=-16.9357343,
    lng=145.7464957,
    housenumber="",
    country="Australia",
)
RIVERWAY_STADIUM = SportsballGeocodeTuple(
    city="Thuringowa Central",
    state="QLD",
    postal="4817",
    lat=-19.3176321,
    lng=146.7270047,
    housenumber="",
    country="Australia",
)
JIANGWAN_STADIUM = SportsballGeocodeTuple(
    city="Shanghai",
    state="",
    postal="200433",
    lat=31.3076026,
    lng=121.5160351,
    housenumber="",
    country="China",
)
DOMAIN_STADIUM = SportsballGeocodeTuple(
    city="Subiaco",
    state="WA",
    postal="6008",
    lat=-31.9444594,
    lng=115.8285952,
    housenumber="304",
    country="Australia",
)
WESTPAC_STADIUM = SportsballGeocodeTuple(
    city="Pipitea",
    state="",
    postal="6140",
    lat=-41.2729198,
    lng=174.7846279,
    housenumber="105",
    country="New Zealand",
)
AAMI_STADIUM = SportsballGeocodeTuple(
    city="West Lakes",
    state="SA",
    postal="5021",
    lat=-34.8797138,
    lng=138.4910204,
    housenumber="",
    country="Australia",
)
BLACKTOWN_PARK = SportsballGeocodeTuple(
    city="Rooty Hill",
    state="NSW",
    postal="2766",
    lat=-33.7695492,
    lng=150.8558658,
    housenumber="",
    country="Australia",
)
PITBULL_STADIUM = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="33199",
    lat=25.7525,
    lng=-80.377778,
    housenumber="11200",
    country="USA",
)
LANNY_AND_SHARON_MARTIN_STADIUM = SportsballGeocodeTuple(
    city="Evanston",
    state="IL",
    postal="60208",
    lat=42.0584293,
    lng=-87.6707798,
    housenumber="2235",
    country="USA",
)
MIAMI_ORANGE_BOWL = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="33125",
    lat=25.7781487,
    lng=-80.2221747,
    housenumber="501",
    country="USA",
)
SPECTRUM = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="",
    lat=39.901111,
    lng=-75.171944,
    housenumber="3601",
    country="USA",
)
MADISON_SQUARE_GARDEN = SportsballGeocodeTuple(
    city="New York",
    state="NY",
    postal="",
    lat=40.750556,
    lng=-73.993611,
    housenumber="4",
    country="USA",
)
MILWAUKEE_ARENA = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.042222,
    lng=-87.916944,
    housenumber="400",
    country="USA",
)
THE_FORUM = SportsballGeocodeTuple(
    city="Inglewood",
    state="CA",
    postal="",
    lat=33.958333,
    lng=-118.341667,
    housenumber="3900",
    country="USA",
)
AMERICA_WEST_ARENA = SportsballGeocodeTuple(
    city="Phoenix",
    state="AZ",
    postal="",
    lat=33.445833,
    lng=-112.071389,
    housenumber="201",
    country="USA",
)
ALAMODOME = SportsballGeocodeTuple(
    city="San Antonio",
    state="TX",
    postal="78203",
    lat=29.416944,
    lng=-98.478889,
    housenumber="100",
    country="USA",
)
AMERICAN_AIRLINES_ARENA = SportsballGeocodeTuple(
    city="Dallas",
    state="TX",
    postal="",
    lat=32.790556,
    lng=-96.810278,
    housenumber="2500",
    country="USA",
)
THOMAS_AND_MACK_CENTER = SportsballGeocodeTuple(
    city="Las Vegas",
    state="NV",
    postal="",
    lat=36.105,
    lng=-115.144167,
    housenumber="4505",
    country="USA",
)
ORLANDO_ARENA = SportsballGeocodeTuple(
    city="Orlando",
    state="FL",
    postal="32801",
    lat=28.548889,
    lng=-81.386667,
    housenumber="600",
    country="USA",
)
TD_GARDEN = SportsballGeocodeTuple(
    city="Boston",
    state="MA",
    postal="",
    lat=42.366303,
    lng=-71.062228,
    housenumber="100",
    country="USA",
)
STATE_FARM_ARENA = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="",
    lat=33.757222,
    lng=-84.396389,
    housenumber="1",
    country="USA",
)
PEPSI_CENTRE = SportsballGeocodeTuple(
    city="Denver",
    state="CO",
    postal="",
    lat=39.748611,
    lng=-105.0075,
    housenumber="1000",
    country="USA",
)
GAINBRIDGE_FIELDHOUSE = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="",
    lat=39.763889,
    lng=-86.155556,
    housenumber="125",
    country="USA",
)
FISERV_FORUM = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.045028,
    lng=-87.918167,
    housenumber="1111",
    country="USA",
)
STAPLES_CENTRE = SportsballGeocodeTuple(
    city="Los Angeles",
    state="CA",
    postal="90015",
    lat=34.0429909,
    lng=-118.2673753,
    housenumber="1111",
    country="USA",
)
UNITED_CENTER = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="",
    lat=41.880556,
    lng=-87.674167,
    housenumber="1901",
    country="USA",
)
FEDEX_FORUM = SportsballGeocodeTuple(
    city="Memphis",
    state="TN",
    postal="",
    lat=35.138333,
    lng=-90.050556,
    housenumber="191",
    country="USA",
)
TARGET_CENTER = SportsballGeocodeTuple(
    city="Minneapolis",
    state="MN",
    postal="",
    lat=44.979444,
    lng=-93.276111,
    housenumber="600",
    country="USA",
)
GOLDEN_1_CENTER = SportsballGeocodeTuple(
    city="Sacramento",
    state="CA",
    postal="",
    lat=38.580361,
    lng=-121.499611,
    housenumber="500",
    country="USA",
)
DELTA_CENTER = SportsballGeocodeTuple(
    city="Salt Lake City",
    state="UT",
    postal="",
    lat=40.768333,
    lng=-111.901111,
    housenumber="301",
    country="USA",
)
ATT_CENTER = SportsballGeocodeTuple(
    city="San Antonio",
    state="TX",
    postal="",
    lat=29.426944,
    lng=-98.4375,
    housenumber="1",
    country="USA",
)
FTX_ARENA = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="",
    lat=25.781389,
    lng=-80.188056,
    housenumber="601",
    country="USA",
)
VIVINT_ARENA = SportsballGeocodeTuple(
    city="Salt Lake City",
    state="UT",
    postal="",
    lat=40.768333,
    lng=-111.901111,
    housenumber="301",
    country="USA",
)
CHESAPEAKE_ENERGY_ARENA = SportsballGeocodeTuple(
    city="Oklahoma City",
    state="OK",
    postal="",
    lat=35.463333,
    lng=-97.515,
    housenumber="100",
    country="USA",
)
ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX = SportsballGeocodeTuple(
    city="Lake Buena Vista",
    state="FL",
    postal="32830",
    lat=28.337083,
    lng=-81.556,
    housenumber="1375",
    country="USA",
)
QUICKEN_LOANS_ARENA = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="",
    lat=41.496389,
    lng=-81.688056,
    housenumber="1",
    country="USA",
)
KASEYA_CENTER = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="",
    lat=25.781389,
    lng=-80.188056,
    housenumber="601",
    country="USA",
)
DUNN_OLIVER_ACADOME = SportsballGeocodeTuple(
    city="Montgomery",
    state="AL",
    postal="",
    lat=32.36185,
    lng=-86.293158,
    housenumber="",
    country="USA",
)
OAKLAND_ARENA = SportsballGeocodeTuple(
    city="Oakland",
    state="CA",
    postal="",
    lat=37.750278,
    lng=-122.203056,
    housenumber="7000",
    country="USA",
)
SCOTIABANK_ARENA = SportsballGeocodeTuple(
    city="Toronto",
    state="ON",
    postal="",
    lat=43.643333,
    lng=-79.379167,
    housenumber="40",
    country="Canada",
)
BRADLEY_CENTER = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.043611,
    lng=-87.916944,
    housenumber="1001",
    country="USA",
)
THE_PIT = SportsballGeocodeTuple(
    city="Albuquerque",
    state="NM",
    postal="",
    lat=35.067,
    lng=-106.632,
    housenumber="",
    country="USA",
)
JOHN_GLASER_ARENA = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="19141",
    lat=40.039993,
    lng=-75.15654,
    housenumber="15",
    country="USA",
)
TEXAS_AM_COMMERCE_FIELD_HOUSE = SportsballGeocodeTuple(
    city="Commerce",
    state="TX",
    postal="75428",
    lat=33.245337,
    lng=-95.907619,
    housenumber="2600",
    country="USA",
)
WISDOM_GYM = SportsballGeocodeTuple(
    city="Stephenville",
    state="TX",
    postal="",
    lat=32.215438,
    lng=-98.220617,
    housenumber="",
    country="USA",
)
ROSE_HILL_GYM = SportsballGeocodeTuple(
    city="Bronx",
    state="NY",
    postal="10458",
    lat=40.862148,
    lng=-73.883824,
    housenumber="",
    country="USA",
)
JOSEPH_J_GENTILES_CENTER = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="60626",
    lat=42.000556,
    lng=-87.658889,
    housenumber="6525",
    country="USA",
)
SAVAGE_ARENA = SportsballGeocodeTuple(
    city="Toledo",
    state="OH",
    postal="43606",
    lat=41.660232,
    lng=-83.609795,
    housenumber="2025",
    country="USA",
)
MCDOUGALD_MCLENON_ARENA = SportsballGeocodeTuple(
    city="Durham",
    state="NC",
    postal="27707",
    lat=35.975884,
    lng=-78.897745,
    housenumber="1801",
    country="USA",
)
ATHELTICS_CENTER_ORENA = SportsballGeocodeTuple(
    city="Rochester",
    state="MI",
    postal="",
    lat=42.673972,
    lng=-83.213158,
    housenumber="",
    country="USA",
)
NUTTER_CENTER = SportsballGeocodeTuple(
    city="Dayton",
    state="OH",
    postal="",
    lat=39.781944,
    lng=-84.0525,
    housenumber="3640",
    country="USA",
)
COLONIAL_LIFE_ARENA = SportsballGeocodeTuple(
    city="Columbia",
    state="SC",
    postal="",
    lat=33.995,
    lng=-81.037222,
    housenumber="801",
    country="USA",
)
JAMES_H_HILTON_COLISEUM = SportsballGeocodeTuple(
    city="Ames",
    state="IA",
    postal="50010",
    lat=42.02101,
    lng=-93.634763,
    housenumber="",
    country="USA",
)
BRESLIN_EVENTS_CENTER = SportsballGeocodeTuple(
    city="East Lansing",
    state="MI",
    postal="48824",
    lat=42.728227,
    lng=-84.492396,
    housenumber="534",
    country="USA",
)
CHASE_ATHLETIC_CENTER = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="",
    lat=41.499167,
    lng=-81.694722,
    housenumber="",
    country="USA",
)
MURPHY_ATHELTIC_CENTER = SportsballGeocodeTuple(
    city="Murfreesboro",
    state="TN",
    postal="37132",
    lat=35.852467,
    lng=-86.369803,
    housenumber="2650",
    country="USA",
)
STEPHEN_C_OCONNELL_CENTER = SportsballGeocodeTuple(
    city="Gainesville",
    state="FL",
    postal="32611",
    lat=29.649444,
    lng=-82.351111,
    housenumber="250",
    country="USA",
)
F_G_CLARK_ACTIVITY_CENTER = SportsballGeocodeTuple(
    city="Baton Rouge",
    state="LA",
    postal="",
    lat=30.521667,
    lng=-91.185556,
    housenumber="",
    country="USA",
)
KSU_CONVOCATION_CENTER = SportsballGeocodeTuple(
    city="Kennesaw",
    state="GA",
    postal="30144",
    lat=34.036924,
    lng=-84.580329,
    housenumber="590",
    country="USA",
)
WALKUP_SKYDOME = SportsballGeocodeTuple(
    city="Flagstaff",
    state="AZ",
    postal="",
    lat=35.1805,
    lng=-111.6525,
    housenumber="",
    country="USA",
)
DAHLBERG_ARENA = SportsballGeocodeTuple(
    city="Missoula",
    state="MT",
    postal="",
    lat=46.864,
    lng=-113.983,
    housenumber="32",
    country="USA",
)
GREAT_SOUTHERN_BANK_ARENA = SportsballGeocodeTuple(
    city="Springfield",
    state="MO",
    postal="65897",
    lat=37.2021052,
    lng=-93.2855636,
    housenumber="685",
    country="USA",
)
MCCANN_ARENA = SportsballGeocodeTuple(
    city="Poughkeepsie",
    state="NY",
    postal="",
    lat=41.718431,
    lng=-73.934,
    housenumber="",
    country="USA",
)
COLEMAN_COLISEUM = SportsballGeocodeTuple(
    city="Tuscaloosa",
    state="AL",
    postal="35487",
    lat=33.202939,
    lng=-87.539706,
    housenumber="1201",
    country="USA",
)
ROSS_E_TEMPLETON_CENTER = SportsballGeocodeTuple(
    city="Clinton",
    state="SC",
    postal="29325",
    lat=34.465,
    lng=-81.869,
    housenumber="503",
    country="USA",
)
LEVIEN_GYM = SportsballGeocodeTuple(
    city="New York",
    state="NY",
    postal="",
    lat=40.80979,
    lng=-73.961715,
    housenumber="3030",
    country="USA",
)
CRISLER_CENTER = SportsballGeocodeTuple(
    city="Ann Arbor",
    state="MI",
    postal="48104",
    lat=42.265037,
    lng=-83.746768,
    housenumber="333",
    country="USA",
)
HYNES_ATHELTIC_CENTER = SportsballGeocodeTuple(
    city="New Rochelle",
    state="NY",
    postal="",
    lat=40.92664,
    lng=-73.784325,
    housenumber="",
    country="USA",
)
OLE_MISS = SportsballGeocodeTuple(
    city="Oxford",
    state="MS",
    postal="38677",
    lat=34.363164,
    lng=-89.535453,
    housenumber="",
    country="USA",
)
HOLMES_CENTER = SportsballGeocodeTuple(
    city="Boone",
    state="NC",
    postal="28608",
    lat=36.210624,
    lng=-81.675952,
    housenumber="111",
    country="USA",
)
FARRIS_CENTER = SportsballGeocodeTuple(
    city="Conway",
    state="AR",
    postal="",
    lat=35.081667,
    lng=-92.459444,
    housenumber="",
    country="USA",
)
HTC_CENTER = SportsballGeocodeTuple(
    city="Conway",
    state="SC",
    postal="29579",
    lat=33.799167,
    lng=-79.015556,
    housenumber="104",
    country="USA",
)
GERSTEN_PAVILION = SportsballGeocodeTuple(
    city="Los Angeles",
    state="CA",
    postal="90045",
    lat=33.9675,
    lng=-118.415556,
    housenumber="1",
    country="USA",
)
BOGOTA_SAVINGS_BANK_CENTER = SportsballGeocodeTuple(
    city="Teaneck",
    state="NJ",
    postal="07601",
    lat=40.8967,
    lng=-74.0324,
    housenumber="",
    country="USA",
)
CORBETT_SPORTS_CENTER = SportsballGeocodeTuple(
    city="Greensboro",
    state="NC",
    postal="27411",
    lat=36.076783,
    lng=-79.768849,
    housenumber="1601",
    country="USA",
)
EA_DIDDLE_ARENA = SportsballGeocodeTuple(
    city="Bowling Green",
    state="KY",
    postal="42101",
    lat=36.985833,
    lng=-86.4575,
    housenumber="1526",
    country="USA",
)
JMA_WIRELESS_DOME = SportsballGeocodeTuple(
    city="Syracuse",
    state="NY",
    postal="13244",
    lat=43.036111,
    lng=-76.136389,
    housenumber="900",
    country="USA",
)
AG_SPANOS_CENTER = SportsballGeocodeTuple(
    city="Stockton",
    state="CA",
    postal="95211",
    lat=37.976669,
    lng=-121.315095,
    housenumber="1178",
    country="USA",
)
WAR_MEMORIAL_GYMNASIUM = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="94118",
    lat=37.776944,
    lng=-122.449444,
    housenumber="2335",
    country="USA",
)
HENDERSON_CENTER = SportsballGeocodeTuple(
    city="Huntington",
    state="WV",
    postal="25755",
    lat=38.424517,
    lng=-82.425211,
    housenumber="",
    country="USA",
)
TED_CONSTANT_CONVOCATION_CENTER = SportsballGeocodeTuple(
    city="Norfolk",
    state="VA",
    postal="",
    lat=36.884169,
    lng=-76.301231,
    housenumber="4320",
    country="USA",
)
STONY_BROOK_ARENA = SportsballGeocodeTuple(
    city="Stony Brook",
    state="NY",
    postal="11790",
    lat=40.91741,
    lng=-73.125955,
    housenumber="100",
    country="USA",
)
SPECTRUM_CENTRE = SportsballGeocodeTuple(
    city="Charlotte",
    state="NC",
    postal="",
    lat=35.225,
    lng=-80.839167,
    housenumber="333",
    country="USA",
)
CAPITAL_ONE_ARENA = SportsballGeocodeTuple(
    city="Washington",
    state="DC",
    postal="",
    lat=38.898056,
    lng=-77.020833,
    housenumber="601",
    country="USA",
)
BARCLAYS_CENTER = SportsballGeocodeTuple(
    city="Brooklyn",
    state="NY",
    postal="",
    lat=40.682661,
    lng=-73.975225,
    housenumber="620",
    country="USA",
)
LITTLE_CAESARS_ARENA = SportsballGeocodeTuple(
    city="Detroit",
    state="MI",
    postal="",
    lat=42.341111,
    lng=-83.055,
    housenumber="2645",
    country="USA",
)
PAYCOM_CENTRE = SportsballGeocodeTuple(
    city="Oklahoma City",
    state="OK",
    postal="",
    lat=35.463333,
    lng=-97.515,
    housenumber="100",
    country="USA",
)
KIA_CENTER = SportsballGeocodeTuple(
    city="Orlando",
    state="FL",
    postal="",
    lat=28.539167,
    lng=-81.383611,
    housenumber="400",
    country="USA",
)
INTUIT_DOME = SportsballGeocodeTuple(
    city="Inglewood",
    state="CA",
    postal="",
    lat=33.9451,
    lng=-118.3431,
    housenumber="3930",
    country="USA",
)
MODA_CENTER = SportsballGeocodeTuple(
    city="Portland",
    state="OR",
    postal="",
    lat=45.531667,
    lng=-122.666667,
    housenumber="1",
    country="USA",
)
TOYOTA_CENTRE = SportsballGeocodeTuple(
    city="Houston",
    state="TX",
    postal="",
    lat=29.750833,
    lng=-95.362222,
    housenumber="1510",
    country="USA",
)
ROCKET_MORTGAGE_FIELDHOUSE = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="",
    lat=41.496389,
    lng=-81.688056,
    housenumber="1",
    country="USA",
)
CHASE_CENTER = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="",
    lat=37.768056,
    lng=-122.3875,
    housenumber="1",
    country="USA",
)
FROST_BANK_CENTER = SportsballGeocodeTuple(
    city="San Antonio",
    state="TX",
    postal="",
    lat=29.426944,
    lng=-98.4375,
    housenumber="1",
    country="USA",
)
ACCOR_ARENA = SportsballGeocodeTuple(
    city="Paris",
    state="Ile-de-France",
    postal="",
    lat=48.838611,
    lng=2.378611,
    housenumber="8",
    country="France",
)
ARCO_ARENA = SportsballGeocodeTuple(
    city="Sacramento",
    state="CA",
    postal="",
    lat=38.649167,
    lng=-121.518056,
    housenumber="1",
    country="USA",
)
STAN_SHERIFF_CENTER = SportsballGeocodeTuple(
    city="Honolulu",
    state="HI",
    postal="96822-2312",
    lat=21.294167,
    lng=-157.818889,
    housenumber="1355",
    country="USA",
)
CLIMATE_PLEDGE_ARENA = SportsballGeocodeTuple(
    city="Seattle",
    state="WA",
    postal="",
    lat=47.622,
    lng=-122.354,
    housenumber="334",
    country="USA",
)
THE_PALACE_OF_AUBURN_HILLS = SportsballGeocodeTuple(
    city="Auburn Hills",
    state="MI",
    postal="",
    lat=42.696944,
    lng=-83.245556,
    housenumber="6",
    country="USA",
)
STATE_FARM_FIELDHOUSE = SportsballGeocodeTuple(
    city="Lake Buena Vista",
    state="FL",
    postal="",
    lat=28.337083,
    lng=-81.556,
    housenumber="",
    country="USA",
)
AMALIE_ARENA = SportsballGeocodeTuple(
    city="Tampa",
    state="FL",
    postal="",
    lat=27.942778,
    lng=-82.451944,
    housenumber="401",
    country="USA",
)
TOYOTA_STADIUM = SportsballGeocodeTuple(
    city="Frisco",
    state="TX",
    postal="75033",
    lat=33.154444,
    lng=-96.835278,
    housenumber="9200",
    country="USA",
)
MOODY_CENTER = SportsballGeocodeTuple(
    city="Austin",
    state="TX",
    postal="",
    lat=30.280972,
    lng=-97.730472,
    housenumber="2001",
    country="USA",
)
JERSEY_MIKES_ARENA = SportsballGeocodeTuple(
    city="New Brunswick",
    state="NJ",
    postal="08854",
    lat=40.525278,
    lng=-74.441111,
    housenumber="83",
    country="USA",
)
GSU_CONVOCATION_CENTER = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="30312",
    lat=33.7427,
    lng=-84.38869,
    housenumber="455",
    country="USA",
)
O2_ARENA = SportsballGeocodeTuple(
    city="London",
    state="",
    postal="SE10",
    lat=51.5029,
    lng=0.0032,
    housenumber="",
    country="UK",
)
IMPERIAL_ARENA = SportsballGeocodeTuple(
    city="Nassau",
    state="",
    postal="",
    lat=25.0836,
    lng=-77.318,
    housenumber="1",
    country="Bahamas",
)
PPG_PAINTS_ARENA = SportsballGeocodeTuple(
    city="Pittsburgh",
    state="PA",
    postal="",
    lat=40.439444,
    lng=-79.989167,
    housenumber="1001",
    country="USA",
)
TRUIST_ARENA = SportsballGeocodeTuple(
    city="Highland Heights",
    state="KT",
    postal="41099",
    lat=39.032273,
    lng=-84.458864,
    housenumber="500",
    country="USA",
)
ENTERPRISE_CENTER = SportsballGeocodeTuple(
    city="St. Louis",
    state="MO",
    postal="",
    lat=38.626667,
    lng=-90.2025,
    housenumber="1401",
    country="USA",
)
HARRAHS_CHEROKEE_CENTER = SportsballGeocodeTuple(
    city="Asheville",
    state="NC",
    postal="",
    lat=35.597547,
    lng=-82.555384,
    housenumber="87",
    country="USA",
)
CAREFIRST_ARENA = SportsballGeocodeTuple(
    city="Washington",
    state="DC",
    postal="",
    lat=38.846972,
    lng=-76.991444,
    housenumber="1100",
    country="USA",
)
FORD_CENTER_AT_THE_STAR = SportsballGeocodeTuple(
    city="Frisco",
    state="TX",
    postal="",
    lat=33.1105,
    lng=-96.8281,
    housenumber="9",
    country="USA",
)
DUNKIN_DONUTS_CENTER = SportsballGeocodeTuple(
    city="Providence",
    state="RI",
    postal="",
    lat=41.823611,
    lng=-71.418333,
    housenumber="1",
    country="USA",
)
CHI_HEALTH_CENTER = SportsballGeocodeTuple(
    city="Omaha",
    state="NB",
    postal="",
    lat=41.263,
    lng=-95.928,
    housenumber="455",
    country="USA",
)
RYAN_CENTER = SportsballGeocodeTuple(
    city="Kingston",
    state="RI",
    postal="02881",
    lat=41.4875,
    lng=-71.535556,
    housenumber="1",
    country="USA",
)
GENEROSO_POPE_ATHELTIC_COMPLEX = SportsballGeocodeTuple(
    city="Brooklyn Heights",
    state="NY",
    postal="11201",
    lat=40.693147,
    lng=-73.992164,
    housenumber="180",
    country="USA",
)
ROBERT_A_MOTT_GYMNASIUM = SportsballGeocodeTuple(
    city="San Luis Obispo",
    state="CA",
    postal="93407",
    lat=35.29886,
    lng=-120.65855,
    housenumber="1",
    country="USA",
)
KIBBIE_DOME = SportsballGeocodeTuple(
    city="Moscow",
    state="ID",
    postal="83844",
    lat=46.726,
    lng=-117.017,
    housenumber="",
    country="USA",
)
ELMORE_GYMNASIUM = SportsballGeocodeTuple(
    city="Normal",
    state="AL",
    postal="35762",
    lat=34.7852,
    lng=-86.5752,
    housenumber="4900",
    country="USA",
)
REDHAWK_CENTER = SportsballGeocodeTuple(
    city="Seattle",
    state="WA",
    postal="",
    lat=47.607222,
    lng=-122.313333,
    housenumber="",
    country="USA",
)
VIRGIN_ISLANDS_SPORT_AND_FITNESS_CENTER = SportsballGeocodeTuple(
    city="St. Thomas",
    state="USVI",
    postal="",
    lat=18.340096,
    lng=-64.97306,
    housenumber="",
    country="USA",
)
ANAHEIM_CONVENTION_CENTER = SportsballGeocodeTuple(
    city="Anaheim",
    state="CA",
    postal="92802",
    lat=33.802455,
    lng=-117.919843,
    housenumber="800",
    country="USA",
)
WATSO_CENTER = SportsballGeocodeTuple(
    city="Coral Gables",
    state="FL",
    postal="",
    lat=25.715,
    lng=-80.279167,
    housenumber="1245",
    country="USA",
)
HAMPTON_CONVOCATION_CENTER = SportsballGeocodeTuple(
    city="Hampton",
    state="VA",
    postal="23668",
    lat=37.01974,
    lng=-76.33108,
    housenumber="100",
    country="USA",
)
BINGHAMPTON_UNIVERSITY_EVENTS_CENTER = SportsballGeocodeTuple(
    city="Binghamton",
    state="NY",
    postal="13902-6000",
    lat=42.093333,
    lng=-75.971944,
    housenumber="4400",
    country="USA",
)
ICCU_ARENA = SportsballGeocodeTuple(
    city="Moscow",
    state="ID",
    postal="",
    lat=46.7275,
    lng=-117.018056,
    housenumber="",
    country="USA",
)
YUENGLING_CENTER = SportsballGeocodeTuple(
    city="Tampa",
    state="FL",
    postal="",
    lat=28.059236,
    lng=-82.406472,
    housenumber="12499",
    country="USA",
)
HERTZ_ARENA = SportsballGeocodeTuple(
    city="Estero",
    state="FL",
    postal="",
    lat=26.440668,
    lng=-81.778809,
    housenumber="11000",
    country="USA",
)
IDAHO_CENTRAL_ARENA = SportsballGeocodeTuple(
    city="Boise",
    state="ID",
    postal="",
    lat=43.614,
    lng=-116.204,
    housenumber="233",
    country="USA",
)
CHASE_FAMILY_ARENA = SportsballGeocodeTuple(
    city="Hartford",
    state="CT",
    postal="06117",
    lat=41.8018079,
    lng=-72.7191231,
    housenumber="200",
    country="USA",
)
ROSE_GARDEN = SportsballGeocodeTuple(
    city="Portland",
    state="OR",
    postal="",
    lat=45.531667,
    lng=-122.666667,
    housenumber="1",
    country="USA",
)
DESERT_FINANCIAL_ARENA = SportsballGeocodeTuple(
    city="Tempe",
    state="AZ",
    postal="",
    lat=33.424524,
    lng=-111.930948,
    housenumber="600",
    country="USA",
)
TIMES_UNION_CENTER = SportsballGeocodeTuple(
    city="Albany",
    state="NY",
    postal="",
    lat=42.648611,
    lng=-73.754722,
    housenumber="51",
    country="USA",
)
SIU_ARENA = SportsballGeocodeTuple(
    city="Carbondale",
    state="IL",
    postal="",
    lat=37.708333,
    lng=-89.218611,
    housenumber="",
    country="USA",
)
TOYOTA_CENTER = SportsballGeocodeTuple(
    city="Kennewick",
    state="WA",
    postal="",
    lat=46.22,
    lng=-119.217,
    housenumber="7016",
    country="USA",
)
LLOYD_NOBLE_CENTER = SportsballGeocodeTuple(
    city="Norman",
    state="OK",
    postal="73072",
    lat=35.1875,
    lng=-97.444444,
    housenumber="2900",
    country="USA",
)
PETE_MARAVICH_ASSEMBLY_CENTER = SportsballGeocodeTuple(
    city="Baton Rouge",
    state="LA",
    postal="",
    lat=30.4142,
    lng=-91.1845,
    housenumber="",
    country="USA",
)
CHARLOTTE_COLISEUM = SportsballGeocodeTuple(
    city="Charlotte",
    state="NC",
    postal="",
    lat=35.186389,
    lng=-80.912778,
    housenumber="",
    country="USA",
)
REUNION_ARENA = SportsballGeocodeTuple(
    city="Dallas",
    state="TX",
    postal="75207",
    lat=32.772778,
    lng=-96.808056,
    housenumber="777",
    country="USA",
)
ROGERS_ARENA = SportsballGeocodeTuple(
    city="Vancouver",
    state="BC",
    postal="",
    lat=49.277778,
    lng=-123.108889,
    housenumber="800",
    country="CA",
)
MERRELL_CENTER = SportsballGeocodeTuple(
    city="Katy",
    state="TX",
    postal="77494",
    lat=29.780278,
    lng=-95.832222,
    housenumber="6301",
    country="USA",
)
NASSAU_COLISEUM = SportsballGeocodeTuple(
    city="Uniondale",
    state="NY",
    postal="",
    lat=40.722778,
    lng=-73.590556,
    housenumber="1255",
    country="USA",
)
MCNICHOLS_SPORTS_ARENA = SportsballGeocodeTuple(
    city="Denver",
    state="CO",
    postal="",
    lat=39.742778,
    lng=-105.0225,
    housenumber="1635",
    country="USA",
)
MARKET_SQUARE_ARENA = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="46204",
    lat=39.768333,
    lng=-86.151944,
    housenumber="300",
    country="USA",
)
HULMAN_CENTER = SportsballGeocodeTuple(
    city="Terre Haute",
    state="IN",
    postal="47809",
    lat=39.468333,
    lng=-87.405,
    housenumber="200",
    country="USA",
)
SAN_DIEGO_SPORTS_ARENA = SportsballGeocodeTuple(
    city="San Diego",
    state="CA",
    postal="",
    lat=32.755278,
    lng=-117.212222,
    housenumber="3500",
    country="USA",
)
ALLEN_COUNTY_WAR_MEMORIAL_COLISEUM = SportsballGeocodeTuple(
    city="Fort Wayne",
    state="IN",
    postal="23173",
    lat=41.115556,
    lng=-85.124444,
    housenumber="4000",
    country="USA",
)
INDIANA_ASSEMBLY_HALL = SportsballGeocodeTuple(
    city="Bloomington",
    state="IN",
    postal="47408-1590",
    lat=39.180833,
    lng=-86.522222,
    housenumber="1001",
    country="USA",
)
SMITH_SPECTRUM = SportsballGeocodeTuple(
    city="Logan",
    state="UT",
    postal="",
    lat=41.748,
    lng=-111.812,
    housenumber="900",
    country="USA",
)
MOBY_ARENA = SportsballGeocodeTuple(
    city="Fort Collins",
    state="CO",
    postal="",
    lat=40.575669,
    lng=-105.093403,
    housenumber="951",
    country="USA",
)
DORTON_ARENA = SportsballGeocodeTuple(
    city="Raleigh",
    state="NC",
    postal="",
    lat=35.793611,
    lng=-78.71,
    housenumber="1025",
    country="USA",
)
CHARLES_KOCH_ARENA = SportsballGeocodeTuple(
    city="Wichita",
    state="KS",
    postal="67260",
    lat=37.721667,
    lng=-97.2975,
    housenumber="",
    country="USA",
)
SAN_JOSE_CIVIC_AUDITORIUM = SportsballGeocodeTuple(
    city="San Jose",
    state="CA",
    postal="95113",
    lat=37.330987,
    lng=-121.890168,
    housenumber="135",
    country="USA",
)
MIAMI_BEACH_CONVENTION_CENTER = SportsballGeocodeTuple(
    city="Miami Beach",
    state="FL",
    postal="33139",
    lat=25.7948,
    lng=-80.1332,
    housenumber="1901",
    country="USA",
)
BOSTON_GARDENS = SportsballGeocodeTuple(
    city="Boston",
    state="MA",
    postal="",
    lat=42.365833,
    lng=-71.061667,
    housenumber="150",
    country="USA",
)
THE_JUNGLE = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="46202",
    lat=39.770556,
    lng=-86.175,
    housenumber="901",
    country="USA",
)
BAROSSA_PARK = SportsballGeocodeTuple(
    city="Lyndoch",
    state="SA",
    postal="5351",
    lat=-34.5988377,
    lng=138.8028998,
    housenumber="2",
    country="Australia",
)
BUCCANEER_FIELDHOUSE = SportsballGeocodeTuple(
    city="Charleston",
    state="SC",
    postal="29406",
    lat=32.980822,
    lng=-80.067125,
    housenumber="9200",
    country="USA",
)
WELLNESS_AND_EVENTS_CENTER = SportsballGeocodeTuple(
    city="Newark",
    state="NJ",
    postal="07102",
    lat=40.7453,
    lng=-74.183,
    housenumber="100",
    country="USA",
)
CIVIC_ARENA = SportsballGeocodeTuple(
    city="Pittsburgh",
    state="PA",
    postal="15219",
    lat=40.441667,
    lng=-79.99,
    housenumber="66",
    country="USA",
)
SIMMONS_BANK_ARENA = SportsballGeocodeTuple(
    city="North Little Rock",
    state="AR",
    postal="72114",
    lat=34.755111,
    lng=-92.264439,
    housenumber="1",
    country="USA",
)
BOK_CENTER = SportsballGeocodeTuple(
    city="Tulsa",
    state="OK",
    postal="",
    lat=36.152722,
    lng=-95.996333,
    housenumber="200",
    country="USA",
)
LEGACY_CENTER = SportsballGeocodeTuple(
    city="Lake Charles",
    state="LA",
    postal="70607",
    lat=30.1755,
    lng=-93.2095,
    housenumber="",
    country="USA",
)
EXTRAMILE_ARENA = SportsballGeocodeTuple(
    city="Boise",
    state="ID",
    postal="",
    lat=43.6035,
    lng=-116.199,
    housenumber="1401",
    country="USA",
)
REYNOLDS_COLISEUM = SportsballGeocodeTuple(
    city="Raleigh",
    state="NC",
    postal="",
    lat=35.783,
    lng=-78.67,
    housenumber="103",
    country="USA",
)
VANCOUVER_CONVENTION_CENTER = SportsballGeocodeTuple(
    city="Vancouver",
    state="BC",
    postal="",
    lat=49.289167,
    lng=-123.113797,
    housenumber="1055",
    country="Canada",
)
KENDALL_ISAACS_GYMNASIUM = SportsballGeocodeTuple(
    city="Nassau",
    state="",
    postal="",
    lat=25.0524506,
    lng=-77.3627058,
    housenumber="",
    country="Bahamas",
)
SCHAR_CENTER = SportsballGeocodeTuple(
    city="Elon",
    state="NC",
    postal="",
    lat=36.10805,
    lng=-79.51084,
    housenumber="",
    country="USA",
)
STUART_SIEGEL_CENTER = SportsballGeocodeTuple(
    city="Richmond",
    state="VA",
    postal="23284",
    lat=37.552918,
    lng=-77.4529,
    housenumber="1200",
    country="USA",
)
MEMORIAL_COLISEUM = SportsballGeocodeTuple(
    city="Portland",
    state="OR",
    postal="",
    lat=45.532,
    lng=-122.669,
    housenumber="300",
    country="USA",
)
FINNERAN_PAVILION = SportsballGeocodeTuple(
    city="Villanova",
    state="PA",
    postal="19085",
    lat=40.034072,
    lng=-75.336553,
    housenumber="",
    country="USA",
)
SCHEELS_ARENA = SportsballGeocodeTuple(
    city="Fargo",
    state="ND",
    postal="",
    lat=46.900442,
    lng=-96.799025,
    housenumber="1600",
    country="USA",
)
BROOKSHIRE_GROCERY_ARENA = SportsballGeocodeTuple(
    city="Bossier City",
    state="LA",
    postal="",
    lat=32.465167,
    lng=-93.673583,
    housenumber="2000",
    country="USA",
)
NEW_ORLEANS_CITY = SportsballGeocodeTuple(
    city="New Orleans",
    state="LA",
    postal="",
    lat=29.976111,
    lng=-90.078333,
    housenumber="",
    country="USA",
)
PETCO_PARK = SportsballGeocodeTuple(
    city="San Diego",
    state="CA",
    postal="92101",
    lat=32.7073,
    lng=-117.1566,
    housenumber="100",
    country="USA",
)
HART_RECREATION_CENTER = SportsballGeocodeTuple(
    city="Worcester",
    state="MA",
    postal="01610",
    lat=42.235046,
    lng=-71.806381,
    housenumber="1",
    country="USA",
)
CFSB_CENTER = SportsballGeocodeTuple(
    city="Murray",
    state="KY",
    postal="42071",
    lat=36.62267,
    lng=-88.32031,
    housenumber="1401",
    country="USA",
)
TD_BANK_SPORTS_CENTER = SportsballGeocodeTuple(
    city="Hamden",
    state="CT",
    postal="06518",
    lat=41.413833,
    lng=-72.911157,
    housenumber="305",
    country="USA",
)
BANK_OF_COLORADO_ARENA = SportsballGeocodeTuple(
    city="Greeley",
    state="CO",
    postal="80639",
    lat=40.402217,
    lng=-104.703044,
    housenumber="270",
    country="USA",
)
LENOVO_CENTER = SportsballGeocodeTuple(
    city="Raleigh",
    state="NC",
    postal="",
    lat=35.803333,
    lng=-78.721944,
    housenumber="1400",
    country="USA",
)
CABOT_CENTER = SportsballGeocodeTuple(
    city="Boston",
    state="MA",
    postal="02115",
    lat=42.3396,
    lng=-71.0898,
    housenumber="400",
    country="USA",
)
CENTRUM_ARENA = SportsballGeocodeTuple(
    city="Cedar City",
    state="UT",
    postal="84720",
    lat=37.675556,
    lng=-113.073056,
    housenumber="351",
    country="USA",
)
BANK_OF_KENTUCKY_CENTER = SportsballGeocodeTuple(
    city="Highland Heights",
    state="KY",
    postal="41099",
    lat=39.032273,
    lng=-84.458864,
    housenumber="500",
    country="USA",
)
THE_NEST = SportsballGeocodeTuple(
    city="Sacramento",
    state="CA",
    postal="",
    lat=38.561903,
    lng=-121.426878,
    housenumber="",
    country="USA",
)
EAGLEBANK_ARENA = SportsballGeocodeTuple(
    city="Fairfax",
    state="VA",
    postal="",
    lat=38.827,
    lng=-77.31,
    housenumber="4500",
    country="USA",
)
KEYBANK_CENTER = SportsballGeocodeTuple(
    city="Buffalo",
    state="NY",
    postal="",
    lat=42.875,
    lng=-78.876389,
    housenumber="1",
    country="USA",
)
ADDITION_FINANCIAL_ARENA = SportsballGeocodeTuple(
    city="Orlando",
    state="FL",
    postal="",
    lat=28.6068,
    lng=-81.1976,
    housenumber="12777",
    country="USA",
)
UCCU_CENTER = SportsballGeocodeTuple(
    city="Orem",
    state="UT",
    postal="",
    lat=40.278724,
    lng=-111.716956,
    housenumber="800",
    country="USA",
)
STATE_FARM_CENTER = SportsballGeocodeTuple(
    city="Champaign",
    state="IL",
    postal="",
    lat=40.096259,
    lng=-88.235956,
    housenumber="1800",
    country="USA",
)
HARBOR_YARD = SportsballGeocodeTuple(
    city="Bridgeport",
    state="CT",
    postal="06604",
    lat=41.171944,
    lng=-73.1875,
    housenumber="500",
    country="USA",
)
OCEAN_BANK_CONVOCATION_CENTER = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="33199",
    lat=25.756667,
    lng=-80.379444,
    housenumber="11200",
    country="USA",
)
UTRGV_FIELDHOUSE = SportsballGeocodeTuple(
    city="Edinburg",
    state="TX",
    postal="",
    lat=26.310278,
    lng=-98.178056,
    housenumber="",
    country="USA",
)
UCR_STUDENT_REC_CENTER = SportsballGeocodeTuple(
    city="Riverside",
    state="CA",
    postal="",
    lat=33.9789,
    lng=-117.32813,
    housenumber="",
    country="USA",
)
DEGOL_ARENA = SportsballGeocodeTuple(
    city="Loretto",
    state="PA",
    postal="15940",
    lat=40.504612,
    lng=-78.640901,
    housenumber="140",
    country="USA",
)
RETRIEVER_ACTIVITIES_CENTER = SportsballGeocodeTuple(
    city="Baltimore",
    state="MD",
    postal="21250",
    lat=39.2528994,
    lng=-76.712267,
    housenumber="1000",
    country="USA",
)
AL_LAWSON_CENTER = SportsballGeocodeTuple(
    city="Tallahassee",
    state="FL",
    postal="32310",
    lat=30.424318,
    lng=-84.290473,
    housenumber="1800",
    country="USA",
)
XFINITY_CENTER = SportsballGeocodeTuple(
    city="College Park",
    state="MD",
    postal="",
    lat=38.995278,
    lng=-76.941389,
    housenumber="",
    country="USA",
)
UNITED_SUPERMARKETS_ARENA = SportsballGeocodeTuple(
    city="Lubbock",
    state="TX",
    postal="79409",
    lat=33.581261,
    lng=-101.886636,
    housenumber="1701",
    country="USA",
)
BEASLEY_COLISEUM = SportsballGeocodeTuple(
    city="Pullman",
    state="WA",
    postal="",
    lat=46.735,
    lng=-117.1575,
    housenumber="925",
    country="USA",
)
SCHOLLMAIER_ARENA = SportsballGeocodeTuple(
    city="Fort Worth",
    state="TX",
    postal="76109",
    lat=32.708774,
    lng=-97.36673,
    housenumber="2900",
    country="USA",
)
ALUMNI_HALL = SportsballGeocodeTuple(
    city="Providence",
    state="RI",
    postal="02918",
    lat=41.84575,
    lng=-71.437029,
    housenumber="",
    country="USA",
)
FREDRICK_C_HOBDY_ASSEMBLY_CENTER = SportsballGeocodeTuple(
    city="Grambling",
    state="LA",
    postal="",
    lat=32.520284,
    lng=-92.723578,
    housenumber="1234",
    country="USA",
)
_CACHED_GEOCODES: dict[str, Any] = {
    "S.C.G. - Australia": SCG,
    "Victoria Park - Australia": SportsballGeocodeTuple(
        city="Abbotsford",
        state="VIC",
        postal="3067",
        lat=-37.8105167,
        lng=144.9822987,
        housenumber="",
        country="Australia",
    ),
    "Tom Benson Hall of Fame Stadium": TOM_BENSON_HALL_OF_FAME_STADIUM,
    "MetLife Stadium": METLIFE_STADIUM,
    "Gillette Stadium": GILETTE_STADIUM,
    "Acrisure Stadium": ACRISURE_STADIUM,
    "Hard Rock Stadium": HARD_ROCK_STADIUM,
    "M&T Bank Stadium": MTT_BANK_STADIUM,
    "Highmark Stadium": HIGHMARK_STADIUM,
    "U.S. Bank Stadium": US_BANK_STADIUM,
    "Cleveland Browns Stadium": CLEVELAND_BROWNS_STADIUM,
    "EverBank Stadium": EVERBANK_STADIUM,
    "Nissan Stadium": NISSAN_STADIUM,
    "Paycor Stadium": PAYCOR_STADIUM,
    "SoFi Stadium": SOFI_STADIUM,
    "State Farm Stadium": STATE_FARM_STADIUM,
    "Lucas Oil Stadium": LUCAS_OIL_STADIUM,
    "NRG Stadium": NRG_STADIUM,
    "Soldier Field": SOLDIER_FIELD,
    "GEHA Field at Arrowhead Stadium": ARROWHEAD_STADIUM,
    "Bank of America Stadium": BANK_OF_AMERICA_STADIUM,
    "Allegiant Stadium": ALLEGIANT_STADIUM,
    "Empower Field at Mile High": EMPOWER_FIELD,
    "Levi's Stadium": LEVI_STADIUM,
    "Mercedes-Benz Stadium": MERCEDES_BANZ_STADIUM,
    "Raymond James Stadium": RAYMOND_JAMES_STADIUM,
    "Lambeau Field": LAMBEAU_FIELD,
    "Lincoln Financial Field": LINCOLN_FINANCIAL_FIELD,
    "Ford Field": FORD_FIELD,
    "AT&T Stadium": ATT_STADIUM,
    "Lumen Field": LUMEN_FIELD,
    "Caesars Superdome": CAESARS_SUPERDOME,
    "Neo Química Arena": NEO_QUIMICA_ARENA,
    "FedExField": FEDEX_FIELD,
    "Tottenham Hotspur Stadium": TOTTENHAM_HOTSPURS_STADIUM,
    "Wembley Stadium": WEMBLEY_STADIUM,
    "Allianz Arena": ALLIANZ_ARENA,
    "Levi Stadium": LEVI_STADIUM,
    "Levi’s Stadium": LEVI_STADIUM,
    "Deutsche Bank Park": DEUTSCHE_BANK_PARK,
    "Arrowhead Stadium": ARROWHEAD_STADIUM,
    "Paul Brown Stadium": PAYCOR_STADIUM,
    "Trans World Dome": TRANS_WORLD_DOME,
    "Kingdome": LUMEN_FIELD,
    "Georgia Dome": GEORGIA_DOME,
    "Louisiana Superdome": CAESARS_SUPERDOME,
    "Tom Benson Hall of Fame Stadium - Canton - OH - 44708": TOM_BENSON_HALL_OF_FAME_STADIUM,
    "Gillette Stadium - Foxborough - MA - 02035": GILETTE_STADIUM,
    "Lumen Field - Seattle - WA - 98134": LUMEN_FIELD,
    "Paycor Stadium - Cincinnati - OH - 45202": PAYCOR_STADIUM,
    "Ford Field - Detroit - MI - 48226": FORD_FIELD,
    "Hard Rock Stadium - Miami Gardens - FL - 33056": HARD_ROCK_STADIUM,
    "Raymond James Stadium - Tampa - FL - 33607": RAYMOND_JAMES_STADIUM,
    "Huntington Bank Field - Cleveland - OH - 44114": CLEVELAND_BROWNS_STADIUM,
    "State Farm Stadium - Glendale - AZ - 85305": STATE_FARM_STADIUM,
    "Highmark Stadium - Orchard Park - NY - 14127": HIGHMARK_STADIUM,
    "Soldier Field - Chicago - IL - 60605": SOLDIER_FIELD,
    "Bank of America Stadium - Charlotte - NC - 28202": BANK_OF_AMERICA_STADIUM,
    "AT&T Stadium - Arlington - TX - 76011": ATT_STADIUM,
    "M&T Bank Stadium - Baltimore - MD - 21230": MTT_BANK_STADIUM,
    "SoFi Stadium - Inglewood - CA - 90301": SOFI_STADIUM,
    "Caesars Superdome - New Orleans - LA - 70112": CAESARS_SUPERDOME,
    "Allegiant Stadium - Las Vegas - NV - 89118": ALLEGIANT_STADIUM,
    "Lincoln Financial Field - Philadelphia - PA - 19148": LINCOLN_FINANCIAL_FIELD,
    "MetLife Stadium - East Rutherford - NJ - 07073": METLIFE_STADIUM,
    "Mercedes-Benz Stadium - Atlanta - GA - 30313": MERCEDES_BANZ_STADIUM,
    "NRG Stadium - Houston - TX - 77054": NRG_STADIUM,
    "Acrisure Stadium - Pittsburgh - PA - 15212": ACRISURE_STADIUM,
    "Lucas Oil Stadium - Indianapolis - IN - 46225": LUCAS_OIL_STADIUM,
    "Lambeau Field - Green Bay - WI - 54304": LAMBEAU_FIELD,
    "U.S. Bank Stadium - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "Levi's Stadium - Santa Clara - CA - 95054": LEVI_STADIUM,
    "Northwest Stadium - Landover - MD - 20785": FEDEX_FIELD,
    "Nissan Stadium - Nashville - TN - 37213": NISSAN_STADIUM,
    "GEHA Field at Arrowhead Stadium - Kansas City - MO - 64129": ARROWHEAD_STADIUM,
    "EverBank Stadium - Jacksonville - FL - 32202": EVERBANK_STADIUM,
    "Empower Field at Mile High - Denver - CO - 80204": EMPOWER_FIELD,
    "Brunswick St - Australia": SportsballGeocodeTuple(
        city="Fitzroy North",
        state="VIC",
        postal="3068",
        lat=-37.7891016,
        lng=144.9759327,
        housenumber="1",
        country="Australia",
    ),
    "Corio Oval - Australia": SportsballGeocodeTuple(
        city="East Geelong",
        state="VIC",
        postal="3219",
        lat=-38.1525822,
        lng=144.3787522,
        housenumber="5",
        country="Australia",
    ),
    "Lake Oval - Australia": SportsballGeocodeTuple(
        city="Albert Park",
        state="VIC",
        postal="3206",
        lat=-37.8403445,
        lng=144.9458567,
        housenumber="",
        country="Australia",
    ),
    "East Melbourne - Australia": SportsballGeocodeTuple(
        city="Richmond",
        state="VIC",
        postal="3002",
        lat=-37.8174763,
        lng=144.9777351,
        housenumber="",
        country="Australia",
    ),
    "Junction Oval - Australia": SportsballGeocodeTuple(
        city="St Kilda",
        state="VIC",
        postal="3182",
        lat=-37.8559698,
        lng=144.9779958,
        housenumber="",
        country="Australia",
    ),
    "M.C.G. - Australia": MCG,
    "Princes Park - Australia": SportsballGeocodeTuple(
        city="Carlton North",
        state="VIC",
        postal="3054",
        lat=-37.7849821,
        lng=144.9565047,
        housenumber="200-590",
        country="Australia",
    ),
    "Wembley Stadium - London": WEMBLEY_STADIUM,
    "Tottenham Hotspur Stadium - London": TOTTENHAM_HOTSPURS_STADIUM,
    "Punt Rd - Australia": SportsballGeocodeTuple(
        city="East Melbourne",
        state="VIC",
        postal="3002",
        lat=-37.8222208,
        lng=144.9856865,
        housenumber="",
        country="Australia",
    ),
    "Frankfurt Stadium - Frankfurt": DEUTSCHE_BANK_PARK,
    "Windy Hill - Australia": SportsballGeocodeTuple(
        city="Essendon",
        state="VIC",
        postal="3040",
        lat=-37.7515878,
        lng=144.9001347,
        housenumber="",
        country="Australia",
    ),
    "Camping World Stadium - Orlando - FL - 32805": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32805",
        lat=28.5390192,
        lng=-81.4033962,
        housenumber="1",
        country="USA",
    ),
    "Allianz Arena - Munich": ALLIANZ_ARENA,
    "Estadio Azteca - Mexico City": SportsballGeocodeTuple(
        city="Ciudad de México",
        state="CDMX",
        postal="04650",
        lat=19.3028606,
        lng=-99.1553986,
        housenumber="3465",
        country="Mexico",
    ),
    "Glenferrie Oval - Australia": SportsballGeocodeTuple(
        city="Hawthorn",
        state="VIC",
        postal="3122",
        lat=-37.8206183,
        lng=145.0303644,
        housenumber="34",
        country="Australia",
    ),
    "Dignity Health Sports Park - Carson - CA - 90746": SportsballGeocodeTuple(
        city="Carson",
        state="CA",
        postal="90746",
        lat=33.8643776,
        lng=-118.2660135,
        housenumber="18400",
        country="USA",
    ),
    "Arden St - Australia": SportsballGeocodeTuple(
        city="North Melbourne",
        state="VIC",
        postal="3051",
        lat=-37.7989787,
        lng=144.9388898,
        housenumber="204-206",
        country="Australia",
    ),
    "Oakland Coliseum - Oakland - CA - 94621": SportsballGeocodeTuple(
        city="Oakland",
        state="CA",
        postal="94621",
        lat=37.7514142,
        lng=-122.2034855,
        housenumber="204-206",
        country="USA",
    ),
    "Los Angeles Memorial Coliseum - Los Angeles - CA - 90037": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Western Oval - Australia": SportsballGeocodeTuple(
        city="Parkville",
        state="VIC",
        postal="3052",
        lat=-37.7781687,
        lng=144.9505349,
        housenumber="",
        country="Australia",
    ),
    "Twickenham Stadium - London": SportsballGeocodeTuple(
        city="Twickenham",
        state="",
        postal="TW2 7BA",
        lat=51.4559558,
        lng=-0.34408,
        housenumber="200",
        country="UK",
    ),
    "Olympic Park - Australia": SportsballGeocodeTuple(
        city="Heidelberg West",
        state="VIC",
        postal="3081",
        lat=-37.7397886,
        lng=145.0317471,
        housenumber="",
        country="Australia",
    ),
    "Georgia Dome - Atlanta - GA": GEORGIA_DOME,
    "SDCCU Stadium - San Diego - CA": SDCCU_STADIUM,
    "Kardinia Park - Australia": GMHBA_STADIUM,
    "The Dome at America's Center - St. Louis - MO - 63101": TRANS_WORLD_DOME,
    "Huntington Bank Stadium - Minneapolis - MN - 55455": US_BANK_STADIUM,
    "Yarraville Oval - Australia": SportsballGeocodeTuple(
        city="Yarraville",
        state="VIC",
        postal="3013",
        lat=-37.8150875,
        lng=144.8824932,
        housenumber="",
        country="Australia",
    ),
    "Candlestick Park - San Francisco - CA": CANDLESTICK_PARK,
    "Mall of America Field - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "Toorak Park - Australia": SportsballGeocodeTuple(
        city="Armadale",
        state="VIC",
        postal="3143",
        lat=-37.8528107,
        lng=145.0114987,
        housenumber="580",
        country="Australia",
    ),
    "Rogers Centre - Toronto - ON": SportsballGeocodeTuple(
        city="Toronto",
        state="ON",
        postal="M5V 1J1",
        lat=43.6415757,
        lng=-79.3942991,
        housenumber="580",
        country="Canada",
    ),
    "Euroa - Australia": SportsballGeocodeTuple(
        city="Euroa",
        state="VIC",
        postal="3666",
        lat=-36.7464868,
        lng=145.5724273,
        housenumber="",
        country="Australia",
    ),
    "Aloha Stadium - Honolulu - HI - 96818": SportsballGeocodeTuple(
        city="Aiea",
        state="HI",
        postal="96701",
        lat=21.3728016,
        lng=-157.9348645,
        housenumber="99-500",
        country="USA",
    ),
    "Giants Stadium - East Rutherford - NJ": METLIFE_STADIUM,
    "Metrodome - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "North Hobart - Australia": SportsballGeocodeTuple(
        city="North Hobart",
        state="TAS",
        postal="7000",
        lat=-42.8682555,
        lng=147.3146486,
        housenumber="1-5",
        country="Australia",
    ),
    "Texas Stadium - Irving - TX": TEXAS_STADIUM,
    "Yallourn - Australia": SportsballGeocodeTuple(
        city="Yallourn North",
        state="VIC",
        postal="3825",
        lat=-38.1629374,
        lng=146.3595115,
        housenumber="",
        country="Australia",
    ),
    "Albury - Australia": SportsballGeocodeTuple(
        city="Hamilton Valley",
        state="NSW",
        postal="2641",
        lat=-36.0349793,
        lng=146.9073391,
        housenumber="1",
        country="Australia",
    ),
    "Invesco Field - Denver - CO - 80804": EMPOWER_FIELD,
    "Brisbane Exhibition - Australia": SportsballGeocodeTuple(
        city="Bowen Hills",
        state="QLD",
        postal="4006",
        lat=-27.4503048,
        lng=153.0301872,
        housenumber="600",
        country="Australia",
    ),
    "Monster Park - San Francisco - CA - 94124": CANDLESTICK_PARK,
    "RCA Dome - Indianapolis - IN": LUCAS_OIL_STADIUM,
    "Mountain America Stadium - Tempe - AZ - 85287": MOUNTAIN_AMERICA_STADIUM,
    "Veterans Stadium - Philadelphia - PA": LINCOLN_FINANCIAL_FIELD,
    "Silverdome - Pontiac - MI": SILVERDOME,
    "Giants Stadium": METLIFE_STADIUM,
    "Mile High Stadium": EMPOWER_FIELD,
    "Pontiac Silverdome": SILVERDOME,
    "Foxboro Stadium": GILETTE_STADIUM,
    "Veterans Stadium": LINCOLN_FINANCIAL_FIELD,
    "Texas Stadium": TEXAS_STADIUM,
    "Three Rivers Stadium": ACRISURE_STADIUM,
    "Qualcomm Stadium": SDCCU_STADIUM,
    "Sun Devil Stadium": MOUNTAIN_AMERICA_STADIUM,
    "Three Rivers Stadium - Pittsburgh - PA": ACRISURE_STADIUM,
    "Moorabbin Oval - Australia": SportsballGeocodeTuple(
        city="Moorabbin",
        state="VIC",
        postal="3189",
        lat=-37.9371257,
        lng=145.0404112,
        housenumber="3",
        country="Australia",
    ),
    "Vanderbilt Stadium": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.1438701,
        lng=-86.8284249,
        housenumber="",
        country="USA",
    ),
    "Liberty Bowl Memorial Stadium": LIBERTY_BOWL_MEMORIAL_STADIUM,
    "RFK Stadium": RFK_STADIUM,
    "Astrodome": NRG_STADIUM,
    "Cleveland Municipal Stadium": CLEVELAND_BROWNS_STADIUM,
    "Riverfront Stadium": PAYCOR_STADIUM,
    "Candlestick Park": CANDLESTICK_PARK,
    "Los Angeles Memorial Coliseum": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Coburg Oval - Australia": SportsballGeocodeTuple(
        city="Coburg",
        state="VIC",
        postal="3058",
        lat=-37.7437207,
        lng=144.9671031,
        housenumber="",
        country="Australia",
    ),
    "Waverley Park - Australia": SportsballGeocodeTuple(
        city="Mulgrave",
        state="VIC",
        postal="3170",
        lat=-37.9258818,
        lng=145.1869239,
        housenumber="2A",
        country="Australia",
    ),
    "Rose Bowl": ROSE_BOWL,
    "Miami Orange Bowl": MIAMI_ORANGE_BOWL,
    "Stanford Stadium": STANFORD_STADIUM,
    "Milwaukee County Stadium": MILWAUKEE_COUNTY_STADIUM,
    "Shea Stadium": SHEA_STADIUM,
    "Schaefer Stadium": GILETTE_STADIUM,
    "Yale Bowl": YALE_BOWL,
    "Tiger Stadium": TIGER_STADIUM,
    "War Memorial Stadium": WAR_MEMORIAL_STADIUM,
    "Yankee Stadium": YANKEE_STADIUM,
    "Municipal Stadium": MUNICIPAL_STADIUM,
    "Cotton Bowl": COTTON_BOWL,
    "Kezar Stadium": KEZAR_STADIUM,
    "Franklin Field": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.9502158,
        lng=-75.1949801,
        housenumber="235",
        country="USA",
    ),
    "Wrigley Field": WRIGLEY_FIELD,
    "City Stadium": CITY_STADIUM,
    "IG Field - Winnipeg - MB": SportsballGeocodeTuple(
        city="Winnipeg",
        state="MB",
        postal="R3T 1Z2",
        lat=49.8077033,
        lng=-97.1456866,
        housenumber="315",
        country="Canada",
    ),
    "Subiaco - Australia": DOMAIN_STADIUM,
    "Rice Stadium": RICE_STADIUM,
    "Gabba - Australia": GABBA,
    "Independence Stadium - 71109": SportsballGeocodeTuple(
        city="Shreveport",
        state="LA",
        postal="71109",
        lat=32.475745,
        lng=-93.7944423,
        housenumber="3301",
        country="USA",
    ),
    "Carrara - Australia": PEOPLE_FIRST_STADIUM,
    "W.A.C.A. - Australia": SportsballGeocodeTuple(
        city="East Perth",
        state="WA",
        postal="6004",
        lat=-31.959812,
        lng=115.874661,
        housenumber="",
        country="Australia",
    ),
    "Los Angeles Memorial Coliseum - Los Angeles, California - United States": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Memorial Stadium (Lincoln) - Terre Haute, Indiana, USA - United States": SportsballGeocodeTuple(
        city="Lincoln",
        state="NE",
        postal="68588",
        lat=40.8206975,
        lng=-96.7081629,
        housenumber="1",
        country="USA",
    ),
    "Kezar Stadium - San Francisco, California - United States": KEZAR_STADIUM,
    "Cotton Bowl - Dallas, Texas - United States": COTTON_BOWL,
    "Wrigley Field - Chicago, Illinois - United States": WRIGLEY_FIELD,
    "Yankee Stadium - Bronx, New York - United States": YANKEE_STADIUM,
    "Tiger Stadium - Baton Rouge, Louisiana, USA - United States": TIGER_STADIUM,
    "Lambeau Field - Green Bay, Wisconsin - United States": LAMBEAU_FIELD,
    "RFK Stadium - Washington DC - United States": RFK_STADIUM,
    "War Memorial Stadium - Little Rock, Arkansas - United States": WAR_MEMORIAL_STADIUM,
    "Three Rivers Stadium - Pittsburgh, PA - United States": ACRISURE_STADIUM,
    "Astrodome - Houston, TX - United States": NRG_STADIUM,
    "Mile High Stadium -  - ": EMPOWER_FIELD,
    "Football Park - Australia": AAMI_STADIUM,
    "Docklands - Australia": MARVEL_STADIUM,
    "Manuka Oval - Australia": MANUKA_OVAL,
    "Stadium Australia - Australia": ENGIE_STADIUM,
    "York Park - Australia": UTAS_STADIUM,
    "Marrara Oval - Australia": TIO_STADIUM,
    "Adelaide Oval - Australia": ADELAIDE_OVAL,
    "Sydney Showground - Australia": ENGIE_STADIUM,
    "Bellerive Oval - Australia": BLUNDSTONE_ARENA,
    "Cazaly's Stadium - Australia": CAZALYS_STADIUM,
    "Wellington - Australia": WESTPAC_STADIUM,
    "Traeger Park - Australia": TRAEGER_PARK,
    "Eureka Stadium - Australia": MARS_STADIUM,
    "Perth Stadium - Australia": OPTUS_STADIUM,
    "Jiangwan Stadium - Australia": JIANGWAN_STADIUM,
    "Soldier Field - Chicago, Illinois - United States": SOLDIER_FIELD,
    "Arrowhead Stadium - Kansas City, Missouri - United States": ARROWHEAD_STADIUM,
    "Yale Bowl - New Haven, Connecticut, USA - United States": YALE_BOWL,
    "Rice Stadium - Houston, Texas, U.S. - United States": RICE_STADIUM,
    "Giants Stadium - New York - United States": METLIFE_STADIUM,
    "Rose Bowl - Hampshire - England": ROSE_BOWL,
    "Riverfront Stadium - Cincinnati, OH - United States": PAYCOR_STADIUM,
    "Kingdome - Seattle, WA - United States": LUMEN_FIELD,
    "Milwaukee County Stadium - Milwaukee, WI - United States": MILWAUKEE_COUNTY_STADIUM,
    "Candlestick Park - San Francisco, CA - United States": CANDLESTICK_PARK,
    "Cleveland Municipal Stadium - Cleveland, OH - United States": CLEVELAND_BROWNS_STADIUM,
    "Stanford Stadium - Stanford, California, USA - United States": STANFORD_STADIUM,
    "Sun Devil Stadium - Tempe, Arizona, USA - United States": MOUNTAIN_AMERICA_STADIUM,
    "Liberty Bowl Memorial Stadium - Memphis, Tennessee, USA - United States": LIBERTY_BOWL_MEMORIAL_STADIUM,
    "Qualcomm Stadium - San Diego, California - United States": SDCCU_STADIUM,
    "Raymond James Stadium - Tampa Bay, Florida, USA - United States": RAYMOND_JAMES_STADIUM,
    "Cleveland Browns Stadium - Cleveland, Ohio - United States": CLEVELAND_BROWNS_STADIUM,
    "Citi Field - Flushing, New York - United States": SHEA_STADIUM,
    "Bruce Stadium - Australia": SportsballGeocodeTuple(
        city="Bruce",
        state="ACT",
        postal="2617",
        lat=-35.249994,
        lng=149.1001351,
        housenumber="",
        country="Australia",
    ),
    "Blacktown - Australia": BLACKTOWN_PARK,
    "Gillette Stadium - Foxborough, Massachusetts - United States": GILETTE_STADIUM,
    "Riverway Stadium - Australia": RIVERWAY_STADIUM,
    "Norwood Oval - Australia": NORWOOD_OVAL,
    "Summit Sports Park - Australia": ADELAIDE_HILLS,
    "Mile High": EMPOWER_FIELD,
    "Nissan Stadium - Nashville, Tennessee, USA - United States": NISSAN_STADIUM,
    "SoFi Stadium - Inglewood, CA - United States": SOFI_STADIUM,
    "Highmark Stadium - Orchard Park, New York - United States": HIGHMARK_STADIUM,
    "Mercedes-Benz Stadium - Atlanta, Georgia - United States": MERCEDES_BANZ_STADIUM,
    "Lucas Oil Stadium - Indianapolis, Indiana, USA - United States": LUCAS_OIL_STADIUM,
    "U.S. Bank Stadium - Minneapolis, Minnesota, USA - United States": US_BANK_STADIUM,
    "Caesars Superdome - New Orleans, Louisiana, United States - United States": CAESARS_SUPERDOME,
    "Acrisure Stadium - Pittsburgh, Pennsylvania, USA - United States": ACRISURE_STADIUM,
    "FedExField - Landover, Maryland, USA - United States": FEDEX_FIELD,
    "M&T Bank Stadium - Baltimore, Maryland - United States": MTT_BANK_STADIUM,
    "Empower Field at Mile High - Denver, Colorado, USA - United States": EMPOWER_FIELD,
    "Lumen Field - Seattle, WA, USA - United States": LUMEN_FIELD,
    "MetLife Stadium - East Rutherford, New Jersey - United States": METLIFE_STADIUM,
    "Lincoln Financial Field - Philadelphia, Pennsylvania - United States": LINCOLN_FINANCIAL_FIELD,
    "Paycor Stadium - Cincinnati, Ohio - United States": PAYCOR_STADIUM,
    "Ford Field - Detroit, Michigan - United States": FORD_FIELD,
    "EverBank Stadium - Jacksonville, Florida - United States": EVERBANK_STADIUM,
    "NRG Stadium - Houston, Texas, USA - United States": NRG_STADIUM,
    "State Farm Stadium - Glendale, Arizona - United States": STATE_FARM_STADIUM,
    "AT&T Stadium - Arlington, Texas, USA - United States": ATT_STADIUM,
    "Bank of America Stadium - Charlotte, NC, United States - United States": BANK_OF_AMERICA_STADIUM,
    "Hard Rock Stadium - Coral Gables, Florida, USA - United States": HARD_ROCK_STADIUM,
    "GEHA Field at Arrowhead Stadium - Kansas City, Missouri, United States - United States": ARROWHEAD_STADIUM,
    "Wembley Stadium - Wembley, London - International": WEMBLEY_STADIUM,
    "Tottenham Hotspur Stadium - Bill Nicholson Way, Tottenham, London - England": TOTTENHAM_HOTSPURS_STADIUM,
    "Deutsche Bank Park - Frankfurt, Germany - Germany": DEUTSCHE_BANK_PARK,
    "Arlington Stadium - Arlington, TX - United States": ATT_STADIUM,
    "Allegiant Stadium - Paradise, Nevada, USA - United States": ALLEGIANT_STADIUM,
    "Neo Química Arena - São Paulo, Brazil - Brazil": NEO_QUIMICA_ARENA,
    "Allianz Arena - Munich, Germany - Germany": ALLIANZ_ARENA,
    "Levi's Stadium - Santa Clara, California, USA - United States": LEVI_STADIUM,
    "MCG": MCG,
    "SCG": SCG,
    "ENGIE Stadium": ENGIE_STADIUM,
    "Adelaide Oval": ADELAIDE_OVAL,
    "Gabba": GABBA,
    "Optus Stadium": OPTUS_STADIUM,
    "Marvel Stadium": MARVEL_STADIUM,
    "Mars Stadium": MARS_STADIUM,
    "GMHBA Stadium": GMHBA_STADIUM,
    "UTAS Stadium": UTAS_STADIUM,
    "People First Stadium": PEOPLE_FIRST_STADIUM,
    "Blundstone Arena": BLUNDSTONE_ARENA,
    "Manuka Oval": MANUKA_OVAL,
    "TIO Stadium": TIO_STADIUM,
    "Norwood Oval": NORWOOD_OVAL,
    "Adelaide Hills": ADELAIDE_HILLS,
    "Traeger Park": TRAEGER_PARK,
    "Cazaly’s Stadium": CAZALYS_STADIUM,
    "Marvl": MARVEL_STADIUM,
    "Accor Stadium": ENGIE_STADIUM,
    "Riverway Stadium": RIVERWAY_STADIUM,
    "Jiangwan Sports Centre": JIANGWAN_STADIUM,
    "Domain Stadium": DOMAIN_STADIUM,
    "Westpac Stadium": WESTPAC_STADIUM,
    "AAMI Stadium": AAMI_STADIUM,
    "Blacktown Park": BLACKTOWN_PARK,
    "Husky Stadium - Seattle - WA - 98195": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="98195",
        lat=47.6503,
        lng=-122.3016,
        housenumber="3800",
        country="USA",
    ),
    "L&N Federal Credit Union Stadium - Louisville - KY - 40208": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="40208",
        lat=38.205833,
        lng=-85.758889,
        housenumber="2800",
        country="USA",
    ),
    "Bobcat Stadium (TX) - San Marcos - TX - 78666": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="78666",
        lat=29.891111,
        lng=-97.925556,
        housenumber="1100",
        country="USA",
    ),
    "Rice-Eccles Stadium - Salt Lake City - UT - 84112": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="84112",
        lat=40.759975,
        lng=-111.848853,
        housenumber="451",
        country="USA",
    ),
    "Boone Pickens Stadium - Stillwater - OK - 74075": SportsballGeocodeTuple(
        city="Stillwater",
        state="OK",
        postal="74075",
        lat=36.125833,
        lng=-97.066389,
        housenumber="700",
        country="USA",
    ),
    "Cajun Field - Lafayette - LA - 70506": SportsballGeocodeTuple(
        city="Lafayette",
        state="LA",
        postal="70506",
        lat=30.215833,
        lng=-92.041944,
        housenumber="201",
        country="USA",
    ),
    "Ben Hill Griffin Stadium - Gainesville - FL - 32611": SportsballGeocodeTuple(
        city="Gainesville",
        state="FL",
        postal="32611",
        lat=29.6500337,
        lng=-82.3488407,
        housenumber="157",
        country="USA",
    ),
    "Protective Stadium - Birmingham - AL - 35203": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="35203",
        lat=33.5278,
        lng=-86.8092,
        housenumber="",
        country="USA",
    ),
    "Warren McGuirk Alumni Stadium - Amherst - MA - 01003": SportsballGeocodeTuple(
        city="Amherst",
        state="MA",
        postal="01003",
        lat=42.377306,
        lng=-72.536019,
        housenumber="300",
        country="USA",
    ),
    "Doyt L. Perry Stadium - Bowling Green - OH - 43403": SportsballGeocodeTuple(
        city="Bowling Green",
        state="OH",
        postal="43403",
        lat=41.378056,
        lng=-83.6225,
        housenumber="",
        country="USA",
    ),
    "Allegacy Federal Credit Union Stadium - Winston-Salem - NC - 27105": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="27105",
        lat=36.130556,
        lng=-80.254722,
        housenumber="411",
        country="USA",
    ),
    "McLane Stadium - Waco - TX - 76704": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="76704",
        lat=31.5582,
        lng=-97.1157,
        housenumber="1001",
        country="USA",
    ),
    "Autzen Stadium - Eugene - OR - 97401": SportsballGeocodeTuple(
        city="Eugene",
        state="OR",
        postal="97401",
        lat=44.058333,
        lng=-123.068611,
        housenumber="2727",
        country="USA",
    ),
    "Lanny and Sharon Martin Stadium - Evanston - IL - 60208": LANNY_AND_SHARON_MARTIN_STADIUM,
    "Kinnick Stadium - Iowa City - IA - 52240": SportsballGeocodeTuple(
        city="Iowa City",
        state="IA",
        postal="52240",
        lat=41.658611,
        lng=-91.551111,
        housenumber="886",
        country="USA",
    ),
    "Carter-Finley Stadium - Raleigh - NC - 27607": SportsballGeocodeTuple(
        city="Raleigh",
        state="NC",
        postal="27607",
        lat=35.800833,
        lng=-78.719444,
        housenumber="4600",
        country="USA",
    ),
    "Bobby Dodd Stadium - Atlanta - GA - 30332": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30332",
        lat=33.7725,
        lng=-84.392778,
        housenumber="155",
        country="USA",
    ),
    "Aviva Stadium - Dublin": SportsballGeocodeTuple(
        city="Dublin",
        state="",
        postal="D04K5F9",
        lat=53.335278,
        lng=-6.228333,
        housenumber="62",
        country="Ireland",
    ),
    "Doak Campbell Stadium - Tallahassee - FL - 32304": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32304",
        lat=30.438056,
        lng=-84.304444,
        housenumber="403",
        country="USA",
    ),
    "Ross-Ade Stadium - West Lafayette - IN - 47906": SportsballGeocodeTuple(
        city="West Lafayette",
        state="IN",
        postal="47906",
        lat=40.434444,
        lng=-86.918333,
        housenumber="850",
        country="USA",
    ),
    "Clarence T.C. Ching Athletics Complex - Honolulu - HI - 96822": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="96822",
        lat=21.294,
        lng=-157.818,
        housenumber="",
        country="USA",
    ),
    "Mackay Stadium - Reno - NV - 89557": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="89557",
        lat=39.546944,
        lng=-119.8175,
        housenumber="1664",
        country="USA",
    ),
    "Veterans Memorial Stadium (AL) - Troy - AL - 36082": SportsballGeocodeTuple(
        city="Troy",
        state="AL",
        postal="36082",
        lat=31.799444,
        lng=-85.951944,
        housenumber="338",
        country="USA",
    ),
    "Memorial Stadium - Columbia - MO - 65203": SportsballGeocodeTuple(
        city="Columbia",
        state="MO",
        postal="65203",
        lat=38.935833,
        lng=-92.333056,
        housenumber="600",
        country="USA",
    ),
    "Glass Bowl - Toledo - OH - 43606": SportsballGeocodeTuple(
        city="Toledo",
        state="OH",
        postal="43606",
        lat=41.656944,
        lng=-83.613611,
        housenumber="3044",
        country="USA",
    ),
    "Milan Puskar Stadium - Morgantown - WV - 26505": SportsballGeocodeTuple(
        city="Morgantown",
        state="WV",
        postal="26505",
        lat=39.650278,
        lng=-79.954722,
        housenumber="900",
        country="USA",
    ),
    "Ohio Stadium - Columbus - OH - 43210": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="43210",
        lat=40.001667,
        lng=-83.019722,
        housenumber="411",
        country="USA",
    ),
    "Memorial Stadium (Bloomington, IN) - Bloomington - IN - 47408": SportsballGeocodeTuple(
        city="Bloomington",
        state="IN",
        postal="47408",
        lat=39.180833,
        lng=-86.525556,
        housenumber="701",
        country="USA",
    ),
    "Jordan-Hare Stadium - Auburn - AL - 36849": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="36849",
        lat=32.602222,
        lng=-85.489167,
        housenumber="251",
        country="USA",
    ),
    "Camp Randall Stadium - Madison - WI - 53711": SportsballGeocodeTuple(
        city="Madison",
        state="WI",
        postal="53711",
        lat=43.07,
        lng=-89.412778,
        housenumber="",
        country="USA",
    ),
    "War Memorial Stadium (AR) - Little Rock - AR - 72205": SportsballGeocodeTuple(
        city="Little Rock",
        state="AR",
        postal="72205",
        lat=34.749861,
        lng=-92.33,
        housenumber="1",
        country="USA",
    ),
    "AmFirst Stadium - Jacksonville - AL - 36265": SportsballGeocodeTuple(
        city="Jacksonville",
        state="AL",
        postal="36265",
        lat=33.820278,
        lng=-85.766389,
        housenumber="700",
        country="USA",
    ),
    "Jones AT&T Stadium - Lubbock - TX - 79407": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="79407",
        lat=33.591111,
        lng=-101.872778,
        housenumber="2526",
        country="USA",
    ),
    "Bryant-Denny Stadium - Tuscaloosa - AL - 35401": SportsballGeocodeTuple(
        city="Tuscaloosa",
        state="AL",
        postal="35401",
        lat=33.208333,
        lng=-87.550278,
        housenumber="920",
        country="USA",
    ),
    "Dowdy-Ficklen Stadium - Greenville - NC - 37604": SportsballGeocodeTuple(
        city="Greenville",
        state="NC",
        postal="37604",
        lat=35.596389,
        lng=-77.365278,
        housenumber="100",
        country="USA",
    ),
    "SHI Stadium - Piscataway - NJ - 08854": SportsballGeocodeTuple(
        city="Piscataway",
        state="NJ",
        postal="08854",
        lat=40.513611,
        lng=-74.465278,
        housenumber="1",
        country="USA",
    ),
    "Folsom Field - Boulder - CO - 80305": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="80305",
        lat=40.009,
        lng=-105.267,
        housenumber="2400",
        country="USA",
    ),
    "Kroger Field - Lexington - KY - 40506": SportsballGeocodeTuple(
        city="Lexington",
        state="KY",
        postal="40506",
        lat=38.022778,
        lng=-84.505278,
        housenumber="1540",
        country="USA",
    ),
    "Williams Stadium (VA) - Lynchburg - VA - 24502": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="24502",
        lat=37.354,
        lng=-79.175,
        housenumber="1972",
        country="USA",
    ),
    "JMA Wireless Dome - Syracuse - NY - 13244": JMA_WIRELESS_DOME,
    "Davis Wade Stadium - Starkville - MS - 39762": SportsballGeocodeTuple(
        city="Starkville",
        state="MS",
        postal="39762",
        lat=33.456389,
        lng=-88.793611,
        housenumber="90",
        country="USA",
    ),
    "FBC Mortgage Stadium - Orlando - FL - 32816": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32816",
        lat=28.6091,
        lng=-81.1924,
        housenumber="4465",
        country="USA",
    ),
    "SECU Stadium - College Park - MD - 20742": SportsballGeocodeTuple(
        city="College Park",
        state="MD",
        postal="20742",
        lat=38.990278,
        lng=-76.947222,
        housenumber="90",
        country="USA",
    ),
    "Michigan Stadium - Ann Arbor - MI - 48104": SportsballGeocodeTuple(
        city="Ann Arbor",
        state="MI",
        postal="48104",
        lat=42.2661,
        lng=-83.7508,
        housenumber="1201",
        country="USA",
    ),
    "Memorial Stadium (Champaign, IL) - Champaign - IL - 61820": SportsballGeocodeTuple(
        city="Champaign",
        state="IL",
        postal="61820",
        lat=40.099167,
        lng=-88.235833,
        housenumber="1402",
        country="USA",
    ),
    "Simmons Bank Liberty Stadium - Memphis - TN - 38104": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="38104",
        lat=35.121,
        lng=-89.9774,
        housenumber="335",
        country="USA",
    ),
    "Huskie Stadium - Dekalb - IL - 60115": SportsballGeocodeTuple(
        city="Dekalb",
        state="IL",
        postal="60115",
        lat=41.934,
        lng=-88.778,
        housenumber="1245",
        country="USA",
    ),
    "FirstBank Stadium - Nashville - TN - 37212": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.144167,
        lng=-86.808889,
        housenumber="",
        country="USA",
    ),
    'Johnny "Red" Floyd Stadium - Murfreesboro - TN - 37130': SportsballGeocodeTuple(
        city="Murfreesboro",
        state="TN",
        postal="37130",
        lat=35.850513,
        lng=-86.368223,
        housenumber="1327",
        country="USA",
    ),
    "Kelly/Shorts Stadium - Mount Pleasant - MI - 48858": SportsballGeocodeTuple(
        city="Mount Pleasant",
        state="MI",
        postal="48858",
        lat=43.5775,
        lng=-84.770833,
        housenumber="2300",
        country="USA",
    ),
    "Kyle Field - College Station - TX - 77840": SportsballGeocodeTuple(
        city="College Station",
        state="TX",
        postal="77840",
        lat=30.6099,
        lng=-96.3405,
        housenumber="756",
        country="USA",
    ),
    "Allen E. Paulson Stadium - Statesboro - GA - 30458": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="30458",
        lat=32.412161,
        lng=-81.783135,
        housenumber="207",
        country="USA",
    ),
    "Stanford Stadium - Stanford - CA - 94305": SportsballGeocodeTuple(
        city="Stanford",
        state="CA",
        postal="94305",
        lat=37.434444,
        lng=-122.161111,
        housenumber="625",
        country="USA",
    ),
    "Wallace Wade Stadium - Durham - NC - 27708": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="27708",
        lat=35.995278,
        lng=-78.941667,
        housenumber="",
        country="USA",
    ),
    "Vaught-Hemingway Stadium - Oxford - MS - 38655": SportsballGeocodeTuple(
        city="Oxford",
        state="MS",
        postal="38655",
        lat=34.361944,
        lng=-89.534167,
        housenumber="6",
        country="USA",
    ),
    "TDECU Stadium - Houston - TX - 77204": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77204",
        lat=29.721944,
        lng=-95.349167,
        housenumber="3874",
        country="USA",
    ),
    "Joan C. Edwards Stadium - Huntington - WV - 25703": SportsballGeocodeTuple(
        city="Huntington",
        state="WV",
        postal="25703",
        lat=38.425,
        lng=-82.420833,
        housenumber="2001",
        country="USA",
    ),
    "Hancock Whitney Stadium - Mobile - AL - 36688": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36688",
        lat=30.696904,
        lng=-88.192013,
        housenumber="",
        country="USA",
    ),
    "Maverik Stadium - Logan - UT - 84341": SportsballGeocodeTuple(
        city="Logan",
        state="UT",
        postal="84341",
        lat=41.751667,
        lng=-111.811667,
        housenumber="1000",
        country="USA",
    ),
    "Williams-Brice Stadium - Columbia - SC - 29201": SportsballGeocodeTuple(
        city="Columbia",
        state="SC",
        postal="29201",
        lat=33.973056,
        lng=-81.019167,
        housenumber="1174",
        country="USA",
    ),
    "Spartan Stadium - East Lansing - MI - 48824": SportsballGeocodeTuple(
        city="East Lansing",
        state="MI",
        postal="48824",
        lat=42.728056,
        lng=-84.484722,
        housenumber="1",
        country="USA",
    ),
    "Alamodome - San Antonio - TX - 78203": ALAMODOME,
    "Jack Trice Stadium - Ames - IA - 50011": SportsballGeocodeTuple(
        city="Ames",
        state="IA",
        postal="50011",
        lat=42.014167,
        lng=-93.635833,
        housenumber="1798",
        country="USA",
    ),
    "Arizona Stadium - Tucson - AZ - 85719": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="85719",
        lat=32.229,
        lng=-110.949,
        housenumber="545",
        country="USA",
    ),
    "California Memorial Stadium - Berkeley - CA - 94720": SportsballGeocodeTuple(
        city="Berkeley",
        state="CA",
        postal="94720",
        lat=37.871111,
        lng=-122.250833,
        housenumber="210",
        country="USA",
    ),
    "Memorial Stadium (Norman, OK) - Norman - OK - 73019": SportsballGeocodeTuple(
        city="Norman",
        state="OK",
        postal="73019",
        lat=35.205833,
        lng=-97.4425,
        housenumber="1185",
        country="USA",
    ),
    "Neyland Stadium - Knoxville - TN - 37996": SportsballGeocodeTuple(
        city="Knoxville",
        state="TN",
        postal="37996",
        lat=35.955,
        lng=-83.925,
        housenumber="1235",
        country="USA",
    ),
    "Bill Snyder Family Stadium - Manhattan - KS - 66502": SportsballGeocodeTuple(
        city="Manhattan",
        state="KS",
        postal="66502",
        lat=39.201944,
        lng=-96.593889,
        housenumber="1800",
        country="USA",
    ),
    "Jerry Richardson Stadium - Charlotte - NC - 28223": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28223",
        lat=35.310556,
        lng=-80.740278,
        housenumber="",
        country="USA",
    ),
    "UB Stadium - Buffalo - NY - 14228": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14228",
        lat=42.999167,
        lng=-78.7775,
        housenumber="",
        country="USA",
    ),
    "Michie Stadium - West Point - NY - 10996": SportsballGeocodeTuple(
        city="West Point",
        state="NY",
        postal="10996",
        lat=41.3875,
        lng=-73.964167,
        housenumber="700",
        country="USA",
    ),
    "DKR-Texas Memorial Stadium - Austin - TX - 78712": SportsballGeocodeTuple(
        city="Austin",
        state="TX",
        postal="78712",
        lat=30.28367,
        lng=-97.73256,
        housenumber="405",
        country="USA",
    ),
    "Nippert Stadium - Cincinnati - OH - 45221": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45221",
        lat=39.1312,
        lng=-84.5162,
        housenumber="2700",
        country="USA",
    ),
    "Rice Stadium - Houston - TX - 77005": RICE_STADIUM,
    "Scott Stadium - Charlottesville - VA - 22903": SportsballGeocodeTuple(
        city="Charlottesville",
        state="VA",
        postal="22903",
        lat=38.031111,
        lng=-78.513611,
        housenumber="1815",
        country="USA",
    ),
    "Memorial Stadium (Lincoln, NE) - Lincoln - NE - 68508": SportsballGeocodeTuple(
        city="Lincoln",
        state="NE",
        postal="68508",
        lat=40.8206,
        lng=-96.706,
        housenumber="600",
        country="USA",
    ),
    "Centennial Bank Stadium - Jonesboro - AR - 72401": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AR",
        postal="72401",
        lat=35.848889,
        lng=-90.667222,
        housenumber="2180",
        country="USA",
    ),
    "Navy-Marine Corps Memorial Stadium - Annapolis - MD - 21401": SportsballGeocodeTuple(
        city="Annapolis",
        state="MD",
        postal="21401",
        lat=38.985,
        lng=-76.507,
        housenumber="550",
        country="USA",
    ),
    "Malone Stadium - Monroe - LA - 71203": SportsballGeocodeTuple(
        city="Monroe",
        state="LA",
        postal="71203",
        lat=32.530833,
        lng=-92.065833,
        housenumber="514",
        country="USA",
    ),
    "Gerald J. Ford Stadium - Dallas - TX - 75205": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="75205",
        lat=32.836644,
        lng=-96.783994,
        housenumber="5801",
        country="USA",
    ),
    "CEFCU Stadium - San Jose - CA - 95112": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95112",
        lat=37.31972,
        lng=-121.868333,
        housenumber="1257",
        country="USA",
    ),
    "University Stadium (NM) - Albuquerque - NM - 87106": SportsballGeocodeTuple(
        city="Albuquerque",
        state="NM",
        postal="87106",
        lat=35.066944,
        lng=-106.628333,
        housenumber="1111",
        country="USA",
    ),
    "Snapdragon Stadium - San Diego - CA - 92108": SDCCU_STADIUM,
    "LaVell Edwards Stadium - Provo - UT - 84604": SportsballGeocodeTuple(
        city="Provo",
        state="UT",
        postal="84604",
        lat=40.258,
        lng=-111.655,
        housenumber="1700",
        country="USA",
    ),
    "Joe Aillet Stadium - Ruston - LA - 71270": SportsballGeocodeTuple(
        city="Ruston",
        state="LA",
        postal="71270",
        lat=32.532021,
        lng=-92.655899,
        housenumber="1450",
        country="USA",
    ),
    "Chapman Stadium - Tulsa - OK - 74104": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74104",
        lat=36.148611,
        lng=-95.943889,
        housenumber="3112",
        country="USA",
    ),
    "Falcon Stadium - USAF Academy - CO - 80840": SportsballGeocodeTuple(
        city="",
        state="CO",
        postal="80840",
        lat=38.997,
        lng=-104.843,
        housenumber="4900",
        country="USA",
    ),
    "Kidd Brewer Stadium - Boone - NC - 28607": SportsballGeocodeTuple(
        city="Boone",
        state="NC",
        postal="28607",
        lat=36.211667,
        lng=-81.685556,
        housenumber="270",
        country="USA",
    ),
    "Aggie Memorial Stadium - Las Cruces - NM - 88003": SportsballGeocodeTuple(
        city="Las Cruces",
        state="NM",
        postal="88003",
        lat=32.27949,
        lng=-106.744288,
        housenumber="",
        country="USA",
    ),
    "Fifth Third Stadium - Kennesaw - GA - 30144": SportsballGeocodeTuple(
        city="Kennesaw",
        state="GA",
        postal="30144",
        lat=34.028967,
        lng=-84.567626,
        housenumber="3200",
        country="USA",
    ),
    "Beaver Stadium - University Park - PA - 16802": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.8121,
        lng=-77.856,
        housenumber="1",
        country="USA",
    ),
    "Pratt & Whitney Stadium - East Hartford - CT - 06118": SportsballGeocodeTuple(
        city="East Hartford",
        state="CT",
        postal="06118",
        lat=41.759722,
        lng=-72.618889,
        housenumber="615",
        country="USA",
    ),
    "Sanford Stadium - Athens - GA - 30602": SportsballGeocodeTuple(
        city="Athens",
        state="GA",
        postal="30602",
        lat=33.949803,
        lng=-83.373364,
        housenumber="",
        country="USA",
    ),
    "Gesa Field - Pullman - WA - 99164": SportsballGeocodeTuple(
        city="Pullman",
        state="WA",
        postal="99164",
        lat=46.732,
        lng=-117.16,
        housenumber="720",
        country="USA",
    ),
    "Houchens Industries-L.T. Smith Stadium - Bowling Green - KY - 42101": SportsballGeocodeTuple(
        city="Bowling Green",
        state="KY",
        postal="42101",
        lat=36.984722,
        lng=-86.459444,
        housenumber="",
        country="USA",
    ),
    "Center Parc Stadium - Atlanta - GA - 30315": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30315",
        lat=33.735278,
        lng=-84.389444,
        housenumber="755",
        country="USA",
    ),
    "S.B. Ballard Stadium - Norfolk - VA - 23508": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23508",
        lat=36.8889,
        lng=-76.304878,
        housenumber="5115",
        country="USA",
    ),
    "M. M. Roberts Stadium - Hattiesburg - MS - 39406": SportsballGeocodeTuple(
        city="Hattiesburg",
        state="MS",
        postal="39406",
        lat=31.328889,
        lng=-89.331389,
        housenumber="118",
        country="USA",
    ),
    "Tiger Stadium (LA) - Baton Rouge - LA - 70803": SportsballGeocodeTuple(
        city="Baton Rouge",
        state="LA",
        postal="70803",
        lat=30.412222,
        lng=-91.183889,
        housenumber="",
        country="USA",
    ),
    "Valley Children's Stadium - Fresno - CA - 93710": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="93710",
        lat=36.814,
        lng=-119.758,
        housenumber="1620",
        country="USA",
    ),
    "Peden Stadium - Athens - OH - 45701": SportsballGeocodeTuple(
        city="Athens",
        state="OH",
        postal="45701",
        lat=39.321111,
        lng=-82.102778,
        housenumber="200",
        country="USA",
    ),
    "Notre Dame Stadium - Notre Dame - IN - 46556": SportsballGeocodeTuple(
        city="Notre Dame",
        state="IN",
        postal="46556",
        lat=41.69833,
        lng=-86.23389,
        housenumber="2010",
        country="USA",
    ),
    "Lane Stadium - Blacksburg - VA - 24060": SportsballGeocodeTuple(
        city="Blacksburg",
        state="VA",
        postal="24060",
        lat=37.22,
        lng=-80.418056,
        housenumber="285",
        country="USA",
    ),
    "Pitbull Stadium - Miami - FL - 33199": PITBULL_STADIUM,
    "Amon G. Carter Stadium - Fort Worth - TX - 76129": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="76129",
        lat=32.709722,
        lng=-97.368056,
        housenumber="2850",
        country="USA",
    ),
    "Memorial Stadium (Clemson, SC) - Clemson - SC - 29634": SportsballGeocodeTuple(
        city="Clemson",
        state="SC",
        postal="29634",
        lat=34.678611,
        lng=-82.843056,
        housenumber="",
        country="USA",
    ),
    "Dix Stadium - Kent - OH - 44242": SportsballGeocodeTuple(
        city="Kent",
        state="OH",
        postal="44242",
        lat=41.139167,
        lng=-81.313333,
        housenumber="2227",
        country="USA",
    ),
    "DATCU Stadium - Denton - TX - 76205": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="76205",
        lat=33.203611,
        lng=-97.159444,
        housenumber="1251",
        country="USA",
    ),
    "FAU Stadium - Boca Raton - FL - 33431": SportsballGeocodeTuple(
        city="Boca Raton",
        state="FL",
        postal="33431",
        lat=26.375278,
        lng=-80.100278,
        housenumber="777",
        country="USA",
    ),
    "Kenan Stadium - Chapel Hill - NC - 27514": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="27514",
        lat=35.906944,
        lng=-79.047778,
        housenumber="78",
        country="USA",
    ),
    "Brooks Stadium (SC) - Conway - SC - 29526": SportsballGeocodeTuple(
        city="Conway",
        state="SC",
        postal="29526",
        lat=33.7929,
        lng=-79.0175,
        housenumber="540",
        country="USA",
    ),
    "Canvas Stadium - Fort Collins - CO - 80521": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="80521",
        lat=40.5698965,
        lng=-105.0910097,
        housenumber="751",
        country="USA",
    ),
    "Yulman Stadium - New Orleans - LA - 70118": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="70118",
        lat=29.94482,
        lng=-90.116816,
        housenumber="",
        country="USA",
    ),
    "Bridgeforth Stadium - Harrisonburg - VA - 22807": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="22807",
        lat=38.435278,
        lng=-78.873056,
        housenumber="",
        country="USA",
    ),
    "War Memorial Stadium - Laramie - WY - 82070": SportsballGeocodeTuple(
        city="Laramie",
        state="WY",
        postal="82070",
        lat=41.3117075,
        lng=-105.5708596,
        housenumber="",
        country="USA",
    ),
    "Sun Bowl - El Paso - TX - 79902": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="79902",
        lat=31.773,
        lng=-106.508,
        housenumber="2701",
        country="USA",
    ),
    "Scheumann Stadium - Muncie - IN - 47304": SportsballGeocodeTuple(
        city="Muncie",
        state="IN",
        postal="47304",
        lat=40.216111,
        lng=-85.416667,
        housenumber="",
        country="USA",
    ),
    "Razorback Stadium - Fayetteville - AR - 72701": SportsballGeocodeTuple(
        city="Fayetteville",
        state="AR",
        postal="72701",
        lat=36.068056,
        lng=-94.178889,
        housenumber="350",
        country="USA",
    ),
    "Reser Stadium - Corvallis - OR - 97331": SportsballGeocodeTuple(
        city="Corvallis",
        state="OR",
        postal="97331",
        lat=44.5595424,
        lng=-123.2839683,
        housenumber="2600",
        country="USA",
    ),
    "Yager Stadium - Oxford - OH - 45056": SportsballGeocodeTuple(
        city="Oxford",
        state="OH",
        postal="45056",
        lat=39.5195227,
        lng=-84.7355128,
        housenumber="",
        country="USA",
    ),
    "Rose Bowl - Pasadena - CA - 91103": ROSE_BOWL,
    "Waldo Stadium - Kalamazoo - MI - 49008": SportsballGeocodeTuple(
        city="Kalamazoo",
        state="MI",
        postal="49008",
        lat=42.285833,
        lng=-85.601111,
        housenumber="1903",
        country="USA",
    ),
    "InfoCision Stadium - Akron - OH - 44304": SportsballGeocodeTuple(
        city="Akron",
        state="OH",
        postal="44304",
        lat=41.072347,
        lng=-81.508019,
        housenumber="",
        country="USA",
    ),
    "Rynearson Stadium - Ypsilanti - MI - 48197": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="48197",
        lat=42.2558889,
        lng=-83.6499574,
        housenumber="799",
        country="USA",
    ),
    "Children's Mercy Park - Kansas City - KS - 66111": SportsballGeocodeTuple(
        city="Kansas City",
        state="KS",
        postal="66111",
        lat=39.12174,
        lng=-94.82318,
        housenumber="1",
        country="USA",
    ),
    "Elliott T. Bowers Stadium - Huntsville - TX - 77340": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="77340",
        lat=30.713889,
        lng=-95.541667,
        housenumber="620",
        country="USA",
    ),
    "Alumni Stadium (Chestnut Hill, MA) - Chestnut Hill - MA - 02467": SportsballGeocodeTuple(
        city="Chestnut Hill",
        state="MA",
        postal="02467",
        lat=42.335,
        lng=-71.166389,
        housenumber="",
        country="USA",
    ),
    "Albertsons Stadium - Boise - ID - 83706": SportsballGeocodeTuple(
        city="Boise",
        state="ID",
        postal="83706",
        lat=43.603,
        lng=-116.196,
        housenumber="1400",
        country="USA",
    ),
    "Cotton Bowl - Dallas - TX - 75215": COTTON_BOWL,
    "Wrigley Field - Chicago - IL - 60613": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60613",
        lat=41.948056,
        lng=-87.655556,
        housenumber="1060",
        country="USA",
    ),
    "Yankee Stadium - Bronx - NY - 10451": SportsballGeocodeTuple(
        city="Bronx",
        state="NY",
        postal="10451",
        lat=40.829167,
        lng=-73.926389,
        housenumber="1",
        country="USA",
    ),
    "Cramton Bowl - Montgomery - AL - 36107": SportsballGeocodeTuple(
        city="Montgomery",
        state="AL",
        postal="36107",
        lat=32.37949,
        lng=-86.293002,
        housenumber="1022",
        country="USA",
    ),
    "Fenway Park - Boston - MA - 02297": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="02297",
        lat=42.34625,
        lng=-71.09775,
        housenumber="4",
        country="USA",
    ),
    "Toyota Stadium - Frisco - TX - 75033": TOYOTA_STADIUM,
    "Chase Field - Phoenix - AZ - 85004": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="85004",
        lat=33.445278,
        lng=-112.066944,
        housenumber="401",
        country="USA",
    ),
    "Thomas A. Robinson National Stadium - Nassau": SportsballGeocodeTuple(
        city="Nassau",
        state="",
        postal="",
        lat=25.054381,
        lng=-77.360217,
        housenumber="",
        country="Bahamas",
    ),
    "Independence Stadium - Shreveport - LA - 71109": SportsballGeocodeTuple(
        city="Shreveport",
        state="LA",
        postal="71109",
        lat=32.475556,
        lng=-93.791944,
        housenumber="",
        country="USA",
    ),
    "David Booth Kansas Memorial Stadium - Lawrence - KS - 66044": SportsballGeocodeTuple(
        city="Lawrence",
        state="KS",
        postal="66044",
        lat=38.963333,
        lng=-95.246389,
        housenumber="1101",
        country="USA",
    ),
    "Riccardo Silva Stadium - Miami - FL - 33199": PITBULL_STADIUM,
    "Ryan Field - Evanston - IL - 60208": LANNY_AND_SHARON_MARTIN_STADIUM,
    "Petco Park - San Diego - CA - 92101": PETCO_PARK,
    "Providence Park - Portland - OR - 97205": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="97205",
        lat=45.521389,
        lng=-122.691667,
        housenumber="1844",
        country="USA",
    ),
    "Choctaw Stadium - Arlington - TX - 76011": SportsballGeocodeTuple(
        city="Arlington",
        state="TX",
        postal="76011",
        lat=32.751389,
        lng=-97.082778,
        housenumber="1000",
        country="USA",
    ),
    "Inter&Co Stadium - Orlando - FL - 32805": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32805",
        lat=28.5411,
        lng=-81.3893,
        housenumber="655",
        country="USA",
    ),
    "Legion Field (AL) - Birmingham - AL - 35204": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="35204",
        lat=33.511389,
        lng=-86.842778,
        housenumber="400",
        country="USA",
    ),
    "Sam Boyd Stadium - Las Vegas - NV - 89122": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="89122",
        lat=36.086,
        lng=-115.017,
        housenumber="7000",
        country="USA",
    ),
    "HighPoint.com Stadium - Piscataway - NJ - 08854": SportsballGeocodeTuple(
        city="Piscataway",
        state="NJ",
        postal="08854",
        lat=40.513611,
        lng=-74.465278,
        housenumber="1",
        country="USA",
    ),
    "SDCCU Stadium - San Diego - CA - 92108": SDCCU_STADIUM,
    "Ladd-Peebles Stadium - Mobile - AL - 36604": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36604",
        lat=30.673,
        lng=-88.076,
        housenumber="1621",
        country="USA",
    ),
    "loanDepot park - Miami - FL - 33125": MIAMI_ORANGE_BOWL,
    "Barker-Lane Stadium - Buies Creek - NC - 27546": SportsballGeocodeTuple(
        city="Buies Creek",
        state="NC",
        postal="27546",
        lat=35.4046,
        lng=-78.7427,
        housenumber="558",
        country="USA",
    ),
    "Kibbie Dome - Moscow - ID - 83844": KIBBIE_DOME,
    "Allianz Stadium - Sydney - NSW": SCG,
    "Tropicana Field - St. Petersburg - FL - 33705": SportsballGeocodeTuple(
        city="St. Petersburg",
        state="FL",
        postal="33705",
        lat=27.768333,
        lng=-82.653333,
        housenumber="1",
        country="USA",
    ),
    "ANZ Stadium - Sydney - NSW": ENGIE_STADIUM,
    "Hughes Stadium (CO) - Fort Collins - CO - 80526": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="80526",
        lat=40.562,
        lng=-105.142,
        housenumber="",
        country="USA",
    ),
    "Bristol Motor Speedway - Bristol - TN - 37620": SportsballGeocodeTuple(
        city="Bristol",
        state="TN",
        postal="37620",
        lat=36.5156,
        lng=-82.2569,
        housenumber="151",
        country="USA",
    ),
    "Rate Field - Chicago - IL - 60616": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60616",
        lat=41.83,
        lng=-87.633889,
        housenumber="333",
        country="USA",
    ),
    "Croke Park Stadium - Dublin": SportsballGeocodeTuple(
        city="Dublin",
        state="",
        postal="D03 P6K7",
        lat=53.3609,
        lng=-6.2519,
        housenumber="",
        country="Ireland",
    ),
    "Yale Bowl - New Haven - CT - 06515": YALE_BOWL,
    "Floyd Casey Stadium - Waco - TX - 76798": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="76798",
        lat=31.531342,
        lng=-97.148731,
        housenumber="3088",
        country="USA",
    ),
    'William "Dick" Price Stadium - Norfolk - VA - 23504': SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23504",
        lat=36.846964,
        lng=-76.260053,
        housenumber="700",
        country="USA",
    ),
    "Superior Dome - Marquette - MI - 49855": SportsballGeocodeTuple(
        city="Marquette",
        state="MI",
        postal="49855",
        lat=46.56,
        lng=-87.393611,
        housenumber="",
        country="USA",
    ),
    "Robertson Stadium - Houston - TX - 77004": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77004",
        lat=29.721944,
        lng=-95.349167,
        housenumber="3874",
        country="USA",
    ),
    "Roy Kidd Stadium - Richmond - KY - 40475": SportsballGeocodeTuple(
        city="Richmond",
        state="KY",
        postal="40475",
        lat=37.73439,
        lng=-84.29741,
        housenumber="",
        country="USA",
    ),
    "Capital One Arena, Washington, District of Columbia": CAPITAL_ONE_ARENA,
    "Stan Sheriff Center, Honolulu, Hawaii": STAN_SHERIFF_CENTER,
    "Value City Arena, Columbus, Ohio": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="",
        lat=40.007511,
        lng=-83.025102,
        housenumber="555",
        country="USA",
    ),
    "James A. Rhodes Arena, Akron, Ohio": SportsballGeocodeTuple(
        city="Akron",
        state="OH",
        postal="44303",
        lat=41.075833,
        lng=-81.508611,
        housenumber="373",
        country="USA",
    ),
    "Resch Center, Green Bay, Wisconsin": SportsballGeocodeTuple(
        city="Green Bay",
        state="WI",
        postal="",
        lat=44.499547,
        lng=-88.055049,
        housenumber="820",
        country="USA",
    ),
    "Hagan Arena, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.995245,
        lng=-75.234806,
        housenumber="",
        country="USA",
    ),
    "Wells Fargo Center, Philadelphia, Pennsylvania": SPECTRUM,
    "UW-Milwaukee Panther Arena, Milwaukee, Wisconsin": MILWAUKEE_ARENA,
    "Pauley Pavilion, Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="",
        lat=34.070211,
        lng=-118.446775,
        housenumber="301",
        country="USA",
    ),
    "Save Mart Center, Fresno, California": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="",
        lat=36.809722,
        lng=-119.738611,
        housenumber="2650",
        country="USA",
    ),
    "The Pit, Albuquerque, New Mexico": THE_PIT,
    "Gill Coliseum, Corvallis, Oregon": SportsballGeocodeTuple(
        city="Corvallis",
        state="OR",
        postal="",
        lat=44.5613,
        lng=-123.2805,
        housenumber="660",
        country="USA",
    ),
    "Liacouras Center, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.979722,
        lng=-75.158611,
        housenumber="1776",
        country="USA",
    ),
    "Williams Arena, Minneapolis, Minnesota": SportsballGeocodeTuple(
        city="Minneapolis",
        state="MN",
        postal="55455",
        lat=44.976944,
        lng=-93.228333,
        housenumber="1925",
        country="USA",
    ),
    "John W. Pope Jr. Convocation Center, Buies Creek, North Carolina": SportsballGeocodeTuple(
        city="Buies Creek",
        state="NC",
        postal="27506",
        lat=35.407905,
        lng=-78.736696,
        housenumber="",
        country="USA",
    ),
    "Bob Carpenter Center, Newark, Delaware": SportsballGeocodeTuple(
        city="Newark",
        state="DE",
        postal="",
        lat=39.660556,
        lng=-75.748639,
        housenumber="631",
        country="USA",
    ),
    "FIU Arena, Miami, Florida": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="33199-2516",
        lat=25.756667,
        lng=-80.379444,
        housenumber="11200",
        country="USA",
    ),
    "UMBC Event Center, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="21250",
        lat=39.252342,
        lng=-76.707431,
        housenumber="1000",
        country="USA",
    ),
    "Ted Constant Convocation Ctr., Norfolk, Virginia": TED_CONSTANT_CONVOCATION_CENTER,
    "Yanitelli Center, Jersey City, New Jersey": SportsballGeocodeTuple(
        city="Jersey City",
        state="NJ",
        postal="07306",
        lat=40.727648,
        lng=-74.073173,
        housenumber="2641",
        country="USA",
    ),
    "Edmunds Center, DeLand, Florida": SportsballGeocodeTuple(
        city="DeLand",
        state="FL",
        postal="32723",
        lat=29.039584,
        lng=-81.301819,
        housenumber="143",
        country="USA",
    ),
    "Pinnacle Bank Arena, Lincoln, Nebraska": SportsballGeocodeTuple(
        city="Lincoln",
        state="NB",
        postal="",
        lat=40.817778,
        lng=-96.713333,
        housenumber="400",
        country="USA",
    ),
    "Welsh-Ryan Arena, Evanston, Illinois": SportsballGeocodeTuple(
        city="Evanston",
        state="IL",
        postal="60201",
        lat=42.066944,
        lng=-87.692778,
        housenumber="2705",
        country="USA",
    ),
    "Gentry Center Complex, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.168889,
        lng=-86.829444,
        housenumber="",
        country="USA",
    ),
    "Eblen Center, Cookeville, Tennessee": SportsballGeocodeTuple(
        city="Cookeville",
        state="TN",
        postal="",
        lat=36.178508,
        lng=-85.51,
        housenumber="1100",
        country="USA",
    ),
    "The Thunderdome, Santa Barbara, California": SportsballGeocodeTuple(
        city="Santa Barbara",
        state="CA",
        postal="",
        lat=34.413792,
        lng=-119.851147,
        housenumber="",
        country="USA",
    ),
    "Jenny Craig Pavillion, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.7745,
        lng=-117.1837,
        housenumber="5998",
        country="USA",
    ),
    "Physical Education Complex, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="21216",
        lat=39.315453,
        lng=-76.657381,
        housenumber="2500",
        country="USA",
    ),
    "Estelle and Zoom Fleisher Athletic Center, Newark, New Jersey": SportsballGeocodeTuple(
        city="Newark",
        state="NJ",
        postal="",
        lat=40.743125,
        lng=-74.182161,
        housenumber="",
        country="USA",
    ),
    "SEFCU Arena, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="12222",
        lat=42.681667,
        lng=-73.828333,
        housenumber="1400",
        country="USA",
    ),
    "Knights Hall, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="40205",
        lat=38.2215197,
        lng=-85.7077667,
        housenumber="2000",
        country="USA",
    ),
    "Alico Arena, Fort Myers, Florida": SportsballGeocodeTuple(
        city="Fort Myers",
        state="FL",
        postal="",
        lat=26.471111,
        lng=-81.764722,
        housenumber="",
        country="USA",
    ),
    "The HTC Center, Conway, South Carolina": HTC_CENTER,
    "Daskalakis Athletic Center, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.956389,
        lng=-75.190833,
        housenumber="",
        country="USA",
    ),
    "Leo D. Mahoney Arena, Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="06824",
        lat=41.159722,
        lng=-73.256667,
        housenumber="",
        country="USA",
    ),
    "Convocation Center, Hampton, Virginia": HAMPTON_CONVOCATION_CENTER,
    "Hynes Athletics Center, New Rochelle, New York": HYNES_ATHELTIC_CENTER,
    "Swisher Gymnasium, Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32211",
        lat=30.350278,
        lng=-81.605,
        housenumber="1",
        country="USA",
    ),
    "Pete Mathews Coliseum, Jacksonville, Alabama": SportsballGeocodeTuple(
        city="Jacksonville",
        state="AL",
        postal="36265",
        lat=33.824,
        lng=-85.773,
        housenumber="700",
        country="USA",
    ),
    "Atlantic Union Bank Center, Harrisonburg, Virginia": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="",
        lat=38.430437,
        lng=-78.859574,
        housenumber="645",
        country="USA",
    ),
    "KSU Convocation Center , Kennesaw, Georgia": KSU_CONVOCATION_CENTER,
    "Ellis T. Johnson Arena, Morehead, Kentucky": SportsballGeocodeTuple(
        city="Morehead",
        state="KY",
        postal="40351",
        lat=38.188786,
        lng=-83.429006,
        housenumber="111",
        country="USA",
    ),
    "Ellis Corbett Sports Center, Greensboro, North Carolina": CORBETT_SPORTS_CENTER,
    "Trask Coliseum, Wilmington, North Carolina": SportsballGeocodeTuple(
        city="Wilmington",
        state="NC",
        postal="",
        lat=34.225,
        lng=-77.878333,
        housenumber="",
        country="USA",
    ),
    "UNF Arena , Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32224",
        lat=30.2734,
        lng=-81.5079,
        housenumber="11852",
        country="USA",
    ),
    "Alumni Gymnasium, Lawrenceville, New Jersey": SportsballGeocodeTuple(
        city="Lawrenceville",
        state="NJ",
        postal="",
        lat=40.2788,
        lng=-74.7354,
        housenumber="",
        country="USA",
    ),
    "MVP Arena, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="",
        lat=42.648611,
        lng=-73.754722,
        housenumber="51",
        country="USA",
    ),
    "SECU Arena, Towson, Maryland": SportsballGeocodeTuple(
        city="Towson",
        state="MD",
        postal="21252",
        lat=39.387361,
        lng=-76.617083,
        housenumber="8000",
        country="USA",
    ),
    "Roy L. Patrick Gymnasium, Burlington, Vermont": SportsballGeocodeTuple(
        city="Burlington",
        state="VT",
        postal="",
        lat=44.470264,
        lng=-73.194705,
        housenumber="97",
        country="USA",
    ),
    "Convocation Center, Jonesboro, Arkansas": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AR",
        postal="72401",
        lat=35.845422,
        lng=-90.670319,
        housenumber="217",
        country="USA",
    ),
    "Reed Gym, Pocatello, Idaho": SportsballGeocodeTuple(
        city="Pocatello",
        state="ID",
        postal="",
        lat=42.8645,
        lng=-112.429,
        housenumber="936",
        country="USA",
    ),
    "Scheels Center, Fargo, North Dakota": SCHEELS_ARENA,
    "Findlay Toyota Court at Walkup Skydome, Flagstaff, Arizona": WALKUP_SKYDOME,
    "Sanford Coyote Sports Center, Vermillon, South Dakota": SportsballGeocodeTuple(
        city="Vermillon",
        state="SD",
        postal="57069",
        lat=42.790111,
        lng=-96.927806,
        housenumber="",
        country="USA",
    ),
    "Screaming Eagles Arena, Evansville, Indiana": SportsballGeocodeTuple(
        city="Evansville",
        state="IN",
        postal="47712",
        lat=37.961944,
        lng=-87.674722,
        housenumber="8600",
        country="USA",
    ),
    "Wisdom Gym, Stephenville, Texas": WISDOM_GYM,
    "Skyhawk Arena, Martin, Tennessee": SportsballGeocodeTuple(
        city="Martin",
        state="TN",
        postal="",
        lat=36.343648,
        lng=-88.867185,
        housenumber="95",
        country="USA",
    ),
    "College Park Center, Arlington, Texas": SportsballGeocodeTuple(
        city="Arlington",
        state="TX",
        postal="76019",
        lat=32.730586,
        lng=-97.107972,
        housenumber="600",
        country="USA",
    ),
    "GCU Arena, Phoenix, Arizona": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="85017",
        lat=33.510152,
        lng=-112.128884,
        housenumber="3300",
        country="USA",
    ),
    "Liberty Arena, Lynchburg, Virginia": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="",
        lat=37.349356,
        lng=-79.180225,
        housenumber="",
        country="USA",
    ),
    "Bank of Colorado Arena, Greeley, Colorado": BANK_OF_COLORADO_ARENA,
    "Dee Events Center, Ogden, Utah": SportsballGeocodeTuple(
        city="Ogden",
        state="UT",
        postal="",
        lat=41.1825,
        lng=-111.945,
        housenumber="4400",
        country="USA",
    ),
    "Robert A. Mott Athletics Center, San Luis Obispo, California": ROBERT_A_MOTT_GYMNASIUM,
    "Bren Events Center, Irvine, California": SportsballGeocodeTuple(
        city="Irvine",
        state="CA",
        postal="92612",
        lat=33.649167,
        lng=-117.846944,
        housenumber="100",
        country="USA",
    ),
    "The Walter Pyramid, Long Beach, California": SportsballGeocodeTuple(
        city="Long Beach",
        state="CA",
        postal="90840",
        lat=33.787222,
        lng=-118.114167,
        housenumber="1250",
        country="USA",
    ),
    "Albert Gersten Pavilion, Los Angeles, California": GERSTEN_PAVILION,
    "Firestone Fieldhouse, Malibu, California": SportsballGeocodeTuple(
        city="Malibu",
        state="CA",
        postal="",
        lat=34.038571,
        lng=-118.709625,
        housenumber="",
        country="USA",
    ),
    "Chiles Center, Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.575,
        lng=-122.728,
        housenumber="",
        country="USA",
    ),
    "Redhawk Center, Seattle, Washington": REDHAWK_CENTER,
    "James H. Hilton Coliseum , Ames, Iowa": JAMES_H_HILTON_COLISEUM,
    "Thompson-Boling Arena, Knoxville, Tennessee": SportsballGeocodeTuple(
        city="Knoxville",
        state="TN",
        postal="37916",
        lat=35.951167,
        lng=-83.925028,
        housenumber="1600",
        country="USA",
    ),
    "Hofheinz Pavilion, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77004",
        lat=29.724722,
        lng=-95.346944,
        housenumber="3875",
        country="USA",
    ),
    "Breslin Events Center, East Lansing, Michigan": BRESLIN_EVENTS_CENTER,
    "Alaska Airlines Arena, Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.652,
        lng=-122.302,
        housenumber="3870",
        country="USA",
    ),
    "Thomas & Mack Center, Las Vegas, Nevada": THOMAS_AND_MACK_CENTER,
    "Christl Arena, West Point, New York": SportsballGeocodeTuple(
        city="West Point",
        state="NY",
        postal="10996",
        lat=41.38641,
        lng=-73.96571,
        housenumber="600",
        country="USA",
    ),
    "The McKenzie Arena, Chattanooga, Tennessee": SportsballGeocodeTuple(
        city="Chattanooga",
        state="TN",
        postal="37403",
        lat=35.050382,
        lng=-85.30091,
        housenumber="720",
        country="USA",
    ),
    "University of Dayton Arena, Dayton, Ohio": SportsballGeocodeTuple(
        city="Dayton",
        state="OH",
        postal="45417",
        lat=39.7348749,
        lng=-84.2021489,
        housenumber="1801",
        country="USA",
    ),
    "John Glaser Arena, Philadelphia, Pennsylvania": JOHN_GLASER_ARENA,
    "University Center, Hammond, Louisiana": SportsballGeocodeTuple(
        city="Hammond",
        state="LA",
        postal="70401",
        lat=30.52,
        lng=-90.472778,
        housenumber="",
        country="USA",
    ),
    "Donald N. Dedmon Center, Radford, Virginia": SportsballGeocodeTuple(
        city="Radford",
        state="VA",
        postal="24141",
        lat=37.1386,
        lng=-80.541769,
        housenumber="101",
        country="USA",
    ),
    "Knapp Center, Des Moines, Iowa": SportsballGeocodeTuple(
        city="Des Moines",
        state="IA",
        postal="50311",
        lat=41.604444,
        lng=-93.651944,
        housenumber="2601",
        country="USA",
    ),
    "Joseph J. Gentile Center, Chicago, Illinois": JOSEPH_J_GENTILES_CENTER,
    "JQH Arena, Springfield, Missouri": GREAT_SOUTHERN_BANK_ARENA,
    "Case Gym, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.353932,
        lng=-71.120355,
        housenumber="285",
        country="USA",
    ),
    "Kimmel Arena, Asheville, North Carolina": SportsballGeocodeTuple(
        city="Asheville",
        state="NC",
        postal="28804",
        lat=35.6181,
        lng=-82.5689,
        housenumber="227",
        country="USA",
    ),
    "Memorial Gymnasium, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37235",
        lat=36.144611,
        lng=-86.80742,
        housenumber="",
        country="USA",
    ),
    "Cameron Hall, Lexington, Virginia": SportsballGeocodeTuple(
        city="Lexington",
        state="VA",
        postal="24450",
        lat=37.788333,
        lng=-79.436389,
        housenumber="401",
        country="USA",
    ),
    "Lawrence Joel Coliseum, Winston-Salem, North Carolina": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="27105",
        lat=36.127866,
        lng=-80.257628,
        housenumber="2825",
        country="USA",
    ),
    "Winthrop Coliseum, Rock Hill, South Carolina": SportsballGeocodeTuple(
        city="Rock Hill",
        state="SC",
        postal="29730",
        lat=34.947911,
        lng=-81.014972,
        housenumber="1162",
        country="USA",
    ),
    "Sojka Pavilion, Lewisburg, Pennsylvania": SportsballGeocodeTuple(
        city="Lewisburg",
        state="PA",
        postal="17837",
        lat=40.956964,
        lng=-76.887093,
        housenumber="701",
        country="USA",
    ),
    "Hinkle Fieldhouse, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.843611,
        lng=-86.167222,
        housenumber="510",
        country="USA",
    ),
    "Henry J. Goodman Arena, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.499167,
        lng=-81.676944,
        housenumber="2000",
        country="USA",
    ),
    "Rose Hill Gym, Bronx, New York": ROSE_HILL_GYM,
    "Bon Secours Wellness Arena, Greenville, South Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="SC",
        postal="",
        lat=34.852789,
        lng=-82.391458,
        housenumber="650",
        country="USA",
    ),
    "Charles E. Smith Center, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="20052",
        lat=38.897755,
        lng=-77.049329,
        housenumber="600",
        country="USA",
    ),
    "Burr Gymnasium, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.9264,
        lng=-77.0221,
        housenumber="",
        country="USA",
    ),
    "Fant-Ewing Coliseum, Monroe, Louisiana": SportsballGeocodeTuple(
        city="Monroe",
        state="LA",
        postal="",
        lat=32.531,
        lng=-92.069,
        housenumber="4319",
        country="USA",
    ),
    "Alumni Hall, Annapolis, Maryland": SportsballGeocodeTuple(
        city="Annapolis",
        state="MD",
        postal="21402",
        lat=38.984491,
        lng=-76.487782,
        housenumber="461",
        country="USA",
    ),
    "Dean Smith Center, Chapel Hill, North Carolina": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="",
        lat=35.899722,
        lng=-79.043889,
        housenumber="300",
        country="USA",
    ),
    "Greensboro Coliseum, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.059722,
        lng=-79.825556,
        housenumber="1921",
        country="USA",
    ),
    "Athletics Center O'rena, Rochester, Michigan": ATHELTICS_CENTER_ORENA,
    "Yuengling Center, Tampa, Florida": YUENGLING_CENTER,
    "Reilly Center, St. Bonaventure, New York": SportsballGeocodeTuple(
        city="St. Bonaventure",
        state="NY",
        postal="",
        lat=42.079428,
        lng=-78.484998,
        housenumber="",
        country="USA",
    ),
    "Devlin Fieldhouse, New Orleans, Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="70118",
        lat=29.938611,
        lng=-90.120556,
        housenumber="",
        country="USA",
    ),
    "Cassell Coliseum, Blacksburg, Virginia": SportsballGeocodeTuple(
        city="Blacksburg",
        state="VA",
        postal="",
        lat=37.222222,
        lng=-80.418889,
        housenumber="675",
        country="USA",
    ),
    "Ervin J. Nutter Center, Dayton, Ohio": NUTTER_CENTER,
    "Carver Arena, Peoria, Illinois": SportsballGeocodeTuple(
        city="Peoria",
        state="IL",
        postal="61602-1423",
        lat=40.691667,
        lng=-89.594167,
        housenumber="201",
        country="USA",
    ),
    "UIC Pavilion, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60607",
        lat=41.874722,
        lng=-87.656111,
        housenumber="525",
        country="USA",
    ),
    "Mitchell Center, Mobile, Alabama": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36608",
        lat=30.69229,
        lng=-88.17975,
        housenumber="2195",
        country="USA",
    ),
    "Ed & Rae Schollmaier Arena, Fort Worth, Texas": SCHOLLMAIER_ARENA,
    "Strahan Coliseum, San Marcos, Texas": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="78666",
        lat=29.888611,
        lng=-97.932778,
        housenumber="601",
        country="USA",
    ),
    "Coors Events/Conference Center, Boulder, Colorado": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="",
        lat=40.0047,
        lng=-105.2606,
        housenumber="950",
        country="USA",
    ),
    "Hamilton Gymnasium, Denver, Colorado": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="",
        lat=39.682106,
        lng=-104.961592,
        housenumber="2240",
        country="USA",
    ),
    "Donald L. Tucker Center, Tallahassee, Florida": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32301-1619",
        lat=30.437842,
        lng=-84.28669,
        housenumber="505",
        country="USA",
    ),
    "John Paul Jones Arena, Charlottesville, Virginia": SportsballGeocodeTuple(
        city="Charlottesville",
        state="VA",
        postal="22903",
        lat=38.046,
        lng=-78.5068,
        housenumber="295",
        country="USA",
    ),
    "Lloyd Noble Center, Norman, Oklahoma": LLOYD_NOBLE_CENTER,
    "Brown Stadium (RI) - Providence - RI - 02906": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="02906",
        lat=41.842222,
        lng=-71.394444,
        housenumber="400",
        country="USA",
    ),
    "Auburn Arena, Auburn, Alabama": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="36849",
        lat=32.60253,
        lng=-85.49301,
        housenumber="250",
        country="USA",
    ),
    "Cameron Indoor Stadium, Durham, North Carolina": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="",
        lat=35.9976,
        lng=-78.9422,
        housenumber="115",
        country="USA",
    ),
    "Coleman Coliseum , Tuscaloosa, Alabama": COLEMAN_COLISEUM,
    "Stephen C. O'Connell Center, Gainesville, Florida": STEPHEN_C_OCONNELL_CENTER,
    "Wintrust Arena, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="",
        lat=41.853611,
        lng=-87.621389,
        housenumber="200",
        country="USA",
    ),
    "Rupp Arena, Lexington, Kentucky": SportsballGeocodeTuple(
        city="Lexington",
        state="KY",
        postal="40506",
        lat=38.049444,
        lng=-84.502778,
        housenumber="432",
        country="USA",
    ),
    "Assembly Hall, Bloomington, Indiana": INDIANA_ASSEMBLY_HALL,
    "Kohl Center, Madison, Wisconsin": SportsballGeocodeTuple(
        city="Madison",
        state="WI",
        postal="53715-1206",
        lat=43.06942,
        lng=-89.396972,
        housenumber="601",
        country="USA",
    ),
    "McKale Center, Tucson, Arizona": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="",
        lat=32.23,
        lng=-110.95,
        housenumber="1",
        country="USA",
    ),
    "Memorial Athletic & Convocation Center, Kent, Ohio": SportsballGeocodeTuple(
        city="Kent",
        state="OH",
        postal="44242",
        lat=41.148,
        lng=-81.344,
        housenumber="1025",
        country="USA",
    ),
    "Madison Square Garden (IV), New York, New York": MADISON_SQUARE_GARDEN,
    "Stuart Siegel Center, Richmond, Virginia": STUART_SIEGEL_CENTER,
    "Curb Event Center, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.132222,
        lng=-86.794444,
        housenumber="2002",
        country="USA",
    ),
    "Bramlage Coliseum, Manhattan, Kansas": SportsballGeocodeTuple(
        city="Manhattan",
        state="KS",
        postal="66502",
        lat=39.200361,
        lng=-96.593833,
        housenumber="1800",
        country="USA",
    ),
    "Convocation Center, DeKalb, Illinois": SportsballGeocodeTuple(
        city="DeKalb",
        state="IL",
        postal="60115-2854",
        lat=41.935106,
        lng=-88.785569,
        housenumber="1525",
        country="USA",
    ),
    "McLeod Center, Cedar Falls, Iowa": SportsballGeocodeTuple(
        city="Cedar Falls",
        state="IO",
        postal="",
        lat=42.51395,
        lng=-92.46714,
        housenumber="",
        country="USA",
    ),
    "Desert Financial Arena, Tempe, Arizona": DESERT_FINANCIAL_ARENA,
    "Lawlor Events Center, Reno, Nevada": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="",
        lat=39.545069,
        lng=-119.818269,
        housenumber="1500",
        country="USA",
    ),
    "San Jose State Event Center, San Jose, California": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95192",
        lat=37.33536,
        lng=-121.87985,
        housenumber="290",
        country="USA",
    ),
    "Galen Center, Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="",
        lat=34.021,
        lng=-118.28,
        housenumber="3400",
        country="USA",
    ),
    "Cintas Center, Cincinnati, Ohio": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45207",
        lat=39.150148,
        lng=-84.471881,
        housenumber="1624",
        country="USA",
    ),
    "Stroh Center, Bowling Green, Ohio": SportsballGeocodeTuple(
        city="Bowling Green",
        state="OH",
        postal="43402",
        lat=41.375343,
        lng=-83.624711,
        housenumber="1535",
        country="USA",
    ),
    "McGuirk Arena, Mt. Pleasant, Michigan": SportsballGeocodeTuple(
        city="Mt. Pleasant",
        state="MI",
        postal="",
        lat=43.580888,
        lng=-84.773941,
        housenumber="",
        country="USA",
    ),
    "Williams Arena at Minges Coliseum, Greenville, North Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="NC",
        postal="27858",
        lat=35.597391,
        lng=-77.367167,
        housenumber="1",
        country="USA",
    ),
    "Convocation Center, Athens, Ohio": SportsballGeocodeTuple(
        city="Athens",
        state="OH",
        postal="45701",
        lat=39.323056,
        lng=-82.105556,
        housenumber="95",
        country="USA",
    ),
    "Carrier Dome, Syracuse, New York": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="",
        lat=43.036111,
        lng=-76.136389,
        housenumber="900",
        country="USA",
    ),
    "Charles Koch Arena, Wichita, Kansas": CHARLES_KOCH_ARENA,
    "CHI Health Center Omaha, Omaha, Nebraska": CHI_HEALTH_CENTER,
    "Tudor Fieldhouse, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77251",
        lat=29.715102,
        lng=-95.403895,
        housenumber="6100",
        country="USA",
    ),
    "Show Me Center, Cape Girardeau, Missouri": SportsballGeocodeTuple(
        city="Cape Girardeau",
        state="MO",
        postal="63701",
        lat=37.32,
        lng=-89.5271,
        housenumber="1333",
        country="USA",
    ),
    "ExtraMile Arena, Boise, Idaho": EXTRAMILE_ARENA,
    "Marriott Center, Provo, Utah": SportsballGeocodeTuple(
        city="Provo",
        state="UT",
        postal="",
        lat=40.254,
        lng=-111.649,
        housenumber="701",
        country="USA",
    ),
    "McCamish Pavilion, Atlanta, Georgia": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="",
        lat=33.780833,
        lng=-84.392778,
        housenumber="965",
        country="USA",
    ),
    "Maravich Assembly Center, Baton Rouge, Louisiana": PETE_MARAVICH_ASSEMBLY_CENTER,
    "Viejas Arena, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.77375,
        lng=-117.074583,
        housenumber="5500",
        country="USA",
    ),
    "Reitz Arena, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.346803,
        lng=-76.618615,
        housenumber="4501",
        country="USA",
    ),
    "Xfinity Center, College Park, Maryland": XFINITY_CENTER,
    "Rutgers Athletic Center, New Brunswick, New Jersey": SportsballGeocodeTuple(
        city="New Brunswick",
        state="NJ",
        postal="08854",
        lat=40.525278,
        lng=-74.441111,
        housenumber="83",
        country="USA",
    ),
    "Davey L. Whitney Complex, Alcorn State, Mississippi": SportsballGeocodeTuple(
        city="Alcorn State",
        state="MS",
        postal="",
        lat=31.873225,
        lng=-91.13318,
        housenumber="",
        country="USA",
    ),
    "H.O. Clemmons Arena, Pine Bluff, Arkansas": SportsballGeocodeTuple(
        city="Pine Bluff",
        state="AR",
        postal="",
        lat=34.243825,
        lng=-92.017429,
        housenumber="",
        country="USA",
    ),
    "Assembly Center, Grambling, Louisiana": SportsballGeocodeTuple(
        city="Grambling",
        state="LA",
        postal="",
        lat=32.520284,
        lng=-92.723578,
        housenumber="1234",
        country="USA",
    ),
    "McDermott Center, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="",
        lat=29.468139,
        lng=-98.469417,
        housenumber="",
        country="USA",
    ),
    "Lee E. Williams Athletics and Assembly Center, Jackson, Mississippi": SportsballGeocodeTuple(
        city="Jackson",
        state="MS",
        postal="39217",
        lat=32.299724,
        lng=-90.211887,
        housenumber="1400",
        country="USA",
    ),
    "Harrison HPER Complex, Itta Bena, Mississippi": SportsballGeocodeTuple(
        city="Itta Bena",
        state="MS",
        postal="",
        lat=33.51406,
        lng=-90.189362,
        housenumber="",
        country="USA",
    ),
    "Hill Field House, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.3425,
        lng=-76.585,
        housenumber="1700",
        country="USA",
    ),
    "McLendon-McDougald Gym, Durham, North Carolina": MCDOUGALD_MCLENON_ARENA,
    "Purcell Pavilion at the Joyce Center, South Bend, Indiana": SportsballGeocodeTuple(
        city="South Bend",
        state="IN",
        postal="46556",
        lat=41.698443,
        lng=-86.231292,
        housenumber="",
        country="USA",
    ),
    "SHM Memorial Center, Orangeburg, South Carolina": SportsballGeocodeTuple(
        city="Orangeburg",
        state="SC",
        postal="29117",
        lat=33.500979,
        lng=-80.846522,
        housenumber="300",
        country="USA",
    ),
    "William Johnson Coliseum, Nacogdoches, Texas": SportsballGeocodeTuple(
        city="Nacogdoches",
        state="TX",
        postal="75964",
        lat=31.622222,
        lng=-94.640833,
        housenumber="700",
        country="USA",
    ),
    "UTRGV Fieldhouse, Edinburg, Texas": UTRGV_FIELDHOUSE,
    "Frank and Lucille Sharp Gymnasium, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77074",
        lat=29.41,
        lng=-95.31,
        housenumber="7502",
        country="USA",
    ),
    "Montagne Center, Beaumont, Texas": SportsballGeocodeTuple(
        city="Beaumont",
        state="TX",
        postal="77710",
        lat=30.2,
        lng=-94.4,
        housenumber="4400",
        country="USA",
    ),
    "F. G. Clark Activity Center, Baton Rouge, Louisiana": F_G_CLARK_ACTIVITY_CENTER,
    "American Bank Center, Corpus Christi, Texas": SportsballGeocodeTuple(
        city="Corpus Christi",
        state="TX",
        postal="",
        lat=27.807339,
        lng=-97.393561,
        housenumber="1901",
        country="USA",
    ),
    "Schar Center, Elon, North Carolina": SCHAR_CENTER,
    "Bryce Jordan Center, University Park, Pennsylvania": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.79578,
        lng=-77.869399,
        housenumber="",
        country="USA",
    ),
    "Mackey Arena, West Lafayette, Indiana": SportsballGeocodeTuple(
        city="West Lafayette",
        state="IN",
        postal="47907",
        lat=40.433322,
        lng=-86.916144,
        housenumber="900",
        country="USA",
    ),
    "Crisler Arena, Ann Arbor, Michigan": CRISLER_CENTER,
    "FAU Arena, Boca Raton, Florida": SportsballGeocodeTuple(
        city="Boca Raton",
        state="FL",
        postal="33431",
        lat=26.372222,
        lng=-80.109167,
        housenumber="777",
        country="USA",
    ),
    "Hammel Court, North Andover, Massachusetts": SportsballGeocodeTuple(
        city="North Andover",
        state="MA",
        postal="",
        lat=42.667843,
        lng=-71.119995,
        housenumber="",
        country="USA",
    ),
    "Koessler Athletic Center, Buffalo, New York": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14208",
        lat=42.920919,
        lng=-78.85754,
        housenumber="1829",
        country="USA",
    ),
    "Detrick Gymnasium, New Britain, Connecticut": SportsballGeocodeTuple(
        city="New Britain",
        state="CT",
        postal="06053",
        lat=41.693,
        lng=-72.7649,
        housenumber="1615",
        country="USA",
    ),
    "Bogota Savings Bank Center, Teaneck, New Jersey": BOGOTA_SAVINGS_BANK_CENTER,
    "Emil and Patricia Jones Convocation Center, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60628",
        lat=41.7165,
        lng=-87.6084,
        housenumber="9501",
        country="USA",
    ),
    "McCann Recreation Center, Poughkeepsie, New York": MCCANN_ARENA,
    "Knott Arena, Emmitsburg, Maryland": SportsballGeocodeTuple(
        city="Emmitsburg",
        state="MD",
        postal="21727",
        lat=39.679492,
        lng=-77.346435,
        housenumber="16300",
        country="USA",
    ),
    "Gallagher Center, Niagara University, New York": SportsballGeocodeTuple(
        city="Niagara University",
        state="NY",
        postal="14109",
        lat=43.137035,
        lng=-79.038026,
        housenumber="2009",
        country="USA",
    ),
    "UPMC Events Center, Moon, Pennsylvania": SportsballGeocodeTuple(
        city="Moon",
        state="PA",
        postal="",
        lat=40.520212,
        lng=-80.21476,
        housenumber="",
        country="USA",
    ),
    "Donald W. Reynolds Center, Tulsa, Oklahoma": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74104",
        lat=36.148611,
        lng=-95.941944,
        housenumber="800",
        country="USA",
    ),
    "Ramsey Center, Cullowhee, North Carolina": SportsballGeocodeTuple(
        city="Cullowhee",
        state="NC",
        postal="28723",
        lat=35.3037,
        lng=-83.1823,
        housenumber="92",
        country="USA",
    ),
    "Jack Stephens Center, Little Rock, Arkansas": SportsballGeocodeTuple(
        city="Little Rock",
        state="AR",
        postal="72204",
        lat=34.727778,
        lng=-92.339722,
        housenumber="2801",
        country="USA",
    ),
    "Moody Center, Austin, Texas": MOODY_CENTER,
    "The Colonial Life Arena, Columbia, South Carolina": COLONIAL_LIFE_ARENA,
    "United Supermarkets Arena, Lubbock, Texas": UNITED_SUPERMARKETS_ARENA,
    "Reed Arena, College Station, Texas": SportsballGeocodeTuple(
        city="College Station",
        state="TX",
        postal="77843",
        lat=30.60578,
        lng=-96.34619,
        housenumber="730",
        country="USA",
    ),
    "Humphrey Coliseum, Starkville, Mississippi": SportsballGeocodeTuple(
        city="Starkville",
        state="MS",
        postal="39762",
        lat=33.461667,
        lng=-88.794444,
        housenumber="55",
        country="USA",
    ),
    "Bud Walton Arena, Fayetteville, Arkansas": SportsballGeocodeTuple(
        city="Fayetteville",
        state="AR",
        postal="72701-5570",
        lat=36.061518,
        lng=-94.178188,
        housenumber="1270",
        country="USA",
    ),
    "Fifth Third Arena, Cincinnati, Ohio": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45221",
        lat=39.131101,
        lng=-84.514207,
        housenumber="2700",
        country="USA",
    ),
    "State Farm Center, Champaign, Illinois": STATE_FARM_CENTER,
    "Stegeman Coliseum, Athens, Georgia": SportsballGeocodeTuple(
        city="Athens",
        state="GA",
        postal="30605",
        lat=33.9428,
        lng=-83.378,
        housenumber="100",
        country="USA",
    ),
    "McCarthey Athletic Center, Spokane, Washington": SportsballGeocodeTuple(
        city="Spokane",
        state="WA",
        postal="",
        lat=47.665,
        lng=-117.399,
        housenumber="801",
        country="USA",
    ),
    "FedExForum, Memphis, Tennessee": FEDEX_FORUM,
    "The Pavilion at Ole Miss, Oxford, Mississippi": OLE_MISS,
    "Dee Glen Smith Spectrum, Logan, Utah": SMITH_SPECTRUM,
    "Holmes Convocation Center, Boone, North Carolina": HOLMES_CENTER,
    "Leede Arena, Hanover, New Hampshire": SportsballGeocodeTuple(
        city="Hanover",
        state="NH",
        postal="03755",
        lat=43.703056,
        lng=-72.283333,
        housenumber="",
        country="USA",
    ),
    "Convocation Center, Ypsilanti, Michigan": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="48197",
        lat=42.254444,
        lng=-83.647222,
        housenumber="799",
        country="USA",
    ),
    "Kirby Sports Center, Easton, Pennsylvania": SportsballGeocodeTuple(
        city="Easton",
        state="PA",
        postal="18042",
        lat=40.7019,
        lng=-75.2107,
        housenumber="700",
        country="USA",
    ),
    "Memorial Gymnasium, Orono, Maine": SportsballGeocodeTuple(
        city="Orono",
        state="ME",
        postal="",
        lat=44.9037,
        lng=-68.67,
        housenumber="18",
        country="USA",
    ),
    "Henderson Center, Huntington, West Virginia": HENDERSON_CENTER,
    "Costello Athletic Center, Lowell, Massachusetts": SportsballGeocodeTuple(
        city="Lowell",
        state="MA",
        postal="",
        lat=42.6555,
        lng=-71.3242,
        housenumber="",
        country="USA",
    ),
    "Multipurpose Activity Center, West Long Branch, New Jersey": SportsballGeocodeTuple(
        city="West Long Branch",
        state="NJ",
        postal="07764",
        lat=40.279475,
        lng=-74.007583,
        housenumber="400",
        country="USA",
    ),
    "Lundholm Gymnasium, Durham, New Hampshire": SportsballGeocodeTuple(
        city="Durham",
        state="NH",
        postal="03824",
        lat=43.138611,
        lng=-70.938056,
        housenumber="145",
        country="USA",
    ),
    "Petersen Events Center, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="",
        lat=40.443777,
        lng=-79.962274,
        housenumber="3719",
        country="USA",
    ),
    "Dunkin' Donuts Center, Providence, Rhode Island": DUNKIN_DONUTS_CENTER,
    "G.B. Hodge Center, Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="",
        lat=34.996696,
        lng=-81.968774,
        housenumber="",
        country="USA",
    ),
    "Daytona Stadium - Daytona Beach - FL - 32124": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="32124",
        lat=29.173056,
        lng=-81.1175,
        housenumber="3777",
        country="USA",
    ),
    "Redbird Arena, Normal, Illinois": SportsballGeocodeTuple(
        city="Normal",
        state="IL",
        postal="61761",
        lat=40.510606,
        lng=-88.999011,
        housenumber="232",
        country="USA",
    ),
    "Carver-Hawkeye Arena, Iowa City, Iowa": SportsballGeocodeTuple(
        city="Iowa City",
        state="IO",
        postal="52242",
        lat=41.663611,
        lng=-91.554444,
        housenumber="1",
        country="USA",
    ),
    "Baxter Arena, Omaha, Nebraska": SportsballGeocodeTuple(
        city="Omaha",
        state="NB",
        postal="",
        lat=41.236,
        lng=-96.013,
        housenumber="2425",
        country="USA",
    ),
    "Pete Hanna Center, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.4638,
        lng=-86.7973,
        housenumber="",
        country="USA",
    ),
    "The SIU Arena, Carbondale, Illinois": SIU_ARENA,
    "Moody Coliseum, Dallas, Texas": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="75205",
        lat=32.840278,
        lng=-96.780556,
        housenumber="6024",
        country="USA",
    ),
    "Reed Green Coliseum, Hattiesburg, Mississippi": SportsballGeocodeTuple(
        city="Hattiesburg",
        state="MS",
        postal="",
        lat=31.330833,
        lng=-89.337778,
        housenumber="112",
        country="USA",
    ),
    "Convocation Center, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="78249",
        lat=29.582222,
        lng=-98.621389,
        housenumber="1",
        country="USA",
    ),
    "E.A. Diddle Arena, Bowling Green, Kentucky": EA_DIDDLE_ARENA,
    "Don Haskins Center, El Paso, Texas": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="79968",
        lat=31.777608,
        lng=-106.505718,
        housenumber="151",
        country="USA",
    ),
    "Jon M. Huntsman Center, Salt Lake City, Utah": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="",
        lat=40.762,
        lng=-111.839,
        housenumber="1825",
        country="USA",
    ),
    "The Pavilion, Davis, California": SportsballGeocodeTuple(
        city="Davis",
        state="CA",
        postal="95616",
        lat=38.541667,
        lng=-121.759444,
        housenumber="1",
        country="USA",
    ),
    "A.G. Spanos Center, Stockton, California": AG_SPANOS_CENTER,
    "Leavey Center, Santa Clara, California": SportsballGeocodeTuple(
        city="Santa Clara",
        state="CA",
        postal="95053",
        lat=37.349111,
        lng=-121.935303,
        housenumber="500",
        country="USA",
    ),
    "Mack Sports Complex, Hempstead, New York": SportsballGeocodeTuple(
        city="Hempstead",
        state="NY",
        postal="11549",
        lat=40.719681,
        lng=-73.596865,
        housenumber="245",
        country="USA",
    ),
    "Hulman Center, Terre Haute, Indiana": HULMAN_CENTER,
    "Worthen Arena, Muncie, Indiana": SportsballGeocodeTuple(
        city="Muncie",
        state="IN",
        postal="",
        lat=40.206944,
        lng=-85.406111,
        housenumber="1699",
        country="USA",
    ),
    "Chace Athletic Center , Smithfield, Rhode Island": SportsballGeocodeTuple(
        city="Smithfield",
        state="RI",
        postal="",
        lat=41.921008,
        lng=-71.539639,
        housenumber="",
        country="USA",
    ),
    "Littlejohn Coliseum, Clemson, South Carolina": SportsballGeocodeTuple(
        city="Clemson",
        state="SC",
        postal="29631",
        lat=34.680278,
        lng=-82.846389,
        housenumber="",
        country="USA",
    ),
    "Cotterell Court, Hamilton, New York": SportsballGeocodeTuple(
        city="Hamilton",
        state="NY",
        postal="13346",
        lat=42.814957,
        lng=-75.542754,
        housenumber="13",
        country="USA",
    ),
    "Levien Gym, New York, New York": LEVIEN_GYM,
    "Belk Arena, Davidson, North Carolina": SportsballGeocodeTuple(
        city="Davidson",
        state="NC",
        postal="",
        lat=35.499278,
        lng=-80.840521,
        housenumber="200",
        country="USA",
    ),
    "EagleBank Arena, Fairfax, Virginia": EAGLEBANK_ARENA,
    "GSU Convocation Center, Atlanta, Georgia": GSU_CONVOCATION_CENTER,
    "Lavietes Pavilion, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="02163",
        lat=42.368218,
        lng=-71.125291,
        housenumber="",
        country="USA",
    ),
    "Stabler Arena, Bethlehem, Pennsylvania": SportsballGeocodeTuple(
        city="Bethlehem",
        state="PA",
        postal="18015",
        lat=40.584444,
        lng=-75.356944,
        housenumber="124",
        country="USA",
    ),
    "Prather Coliseum, Natchitoches, Louisiana": SportsballGeocodeTuple(
        city="Natchitoches",
        state="LA",
        postal="71457",
        lat=31.744028,
        lng=-93.095167,
        housenumber="220",
        country="USA",
    ),
    "Ross E.Templeton Center, Clinton, South Carolina": ROSS_E_TEMPLETON_CENTER,
    "Kaplan Arena at William and Mary Hall, Williamsburg, Virginia": SportsballGeocodeTuple(
        city="Williamsburg",
        state="VA",
        postal="23186",
        lat=37.273472,
        lng=-76.719625,
        housenumber="751",
        country="USA",
    ),
    "John J. Lee Ampitheater, New Haven, Connecticut": SportsballGeocodeTuple(
        city="New Haven",
        state="CT",
        postal="06511",
        lat=41.313611,
        lng=-72.930556,
        housenumber="70",
        country="USA",
    ),
    "Beeghly Center, Youngstown, Ohio": SportsballGeocodeTuple(
        city="Youngstown",
        state="OH",
        postal="44555",
        lat=41.108056,
        lng=-80.648889,
        housenumber="1",
        country="USA",
    ),
    "Clune Arena , Colorado Springs, Colorado": SportsballGeocodeTuple(
        city="Colorado Springs",
        state="CO",
        postal="",
        lat=39.014,
        lng=-104.8833,
        housenumber="2168",
        country="USA",
    ),
    "Silvio O. Conte Forum, Chestnut Hill, Massachusetts": SportsballGeocodeTuple(
        city="Chestnut Hill",
        state="MA",
        postal="",
        lat=42.335,
        lng=-71.1675,
        housenumber="",
        country="USA",
    ),
    "Millett Hall, Oxford, Ohio": SportsballGeocodeTuple(
        city="Oxford",
        state="OH",
        postal="45056",
        lat=39.517236,
        lng=-84.734544,
        housenumber="500",
        country="USA",
    ),
    "Mizzou Arena, Columbia, Missouri": SportsballGeocodeTuple(
        city="Columbia",
        state="MS",
        postal="65211",
        lat=38.93237,
        lng=-92.33303,
        housenumber="1",
        country="USA",
    ),
    "Johnson Coliseum, Huntsville, Texas": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="77340",
        lat=30.712778,
        lng=-95.546111,
        housenumber="1964",
        country="USA",
    ),
    "Bender Arena, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.937778,
        lng=-77.09,
        housenumber="4400",
        country="USA",
    ),
    "Moby Arena, Fort Collins, Colorado": MOBY_ARENA,
    "Freedom Hall Civic Center, Johnson City, Tennessee": SportsballGeocodeTuple(
        city="Johnson City",
        state="TN",
        postal="37604",
        lat=36.324444,
        lng=-82.375,
        housenumber="1320",
        country="USA",
    ),
    "McBrayer Arena, Richmond, Kentucky": SportsballGeocodeTuple(
        city="Richmond",
        state="KY",
        postal="40475",
        lat=37.737222,
        lng=-84.301389,
        housenumber="521",
        country="USA",
    ),
    "Hyland Performance Arena, Saint Charles, Missouri": SportsballGeocodeTuple(
        city="Saint Charles",
        state="MO",
        postal="",
        lat=38.78912,
        lng=-90.50352,
        housenumber="",
        country="USA",
    ),
    "CFSB Center, Murray, Kentucky": CFSB_CENTER,
    "Echols Memorial Hall, Norfolk, Virginia": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23504",
        lat=36.847999,
        lng=-76.258157,
        housenumber="700",
        country="USA",
    ),
    "PNC Arena, Raleigh, North Carolina": SportsballGeocodeTuple(
        city="Raleigh",
        state="NC",
        postal="",
        lat=35.803333,
        lng=-78.721944,
        housenumber="1400",
        country="USA",
    ),
    "The Nest, Sacramento, California": THE_NEST,
    "Sam Vadalabene Center , Edwardsville, Illinois": SportsballGeocodeTuple(
        city="Edwardsville",
        state="IL",
        postal="",
        lat=38.795989,
        lng=-89.999883,
        housenumber="35",
        country="USA",
    ),
    "Maples Pavilion, Stanford, California": SportsballGeocodeTuple(
        city="Stanford",
        state="CA",
        postal="",
        lat=37.4296,
        lng=-122.1605,
        housenumber="655",
        country="USA",
    ),
    "Trojan Arena, Troy, Alabama": SportsballGeocodeTuple(
        city="Troy",
        state="AL",
        postal="36082",
        lat=31.802222,
        lng=-85.954722,
        housenumber="5000",
        country="USA",
    ),
    "UCCU Center, Orem, Utah": UCCU_CENTER,
    "Western Hall, Macomb, Illinois": SportsballGeocodeTuple(
        city="Macomb",
        state="IL",
        postal="",
        lat=40.471589,
        lng=-90.685201,
        housenumber="",
        country="USA",
    ),
    "Allen Arena, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.103833,
        lng=-86.798836,
        housenumber="1",
        country="USA",
    ),
    "The Legacy Center, Lake Charles, Louisiana": LEGACY_CENTER,
    "Watsco Center, Coral Gables, Florida": WATSO_CENTER,
    "Peter W. Stott Center, Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="97201",
        lat=45.510987,
        lng=-122.687471,
        housenumber="930",
        country="USA",
    ),
    "Haas Pavilion, Berkeley, California": SportsballGeocodeTuple(
        city="Berkeley",
        state="CA",
        postal="",
        lat=37.8694,
        lng=-122.262,
        housenumber="14",
        country="USA",
    ),
    "Murphy Athletic Center, Murfreesboro, Tennessee": MURPHY_ATHELTIC_CENTER,
    "Adams Center/Dahlberg Arena, Missoula, Montana": DAHLBERG_ARENA,
    "Kiefer Lakefront Arena, New Orleans , Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="",
        lat=30.03,
        lng=-90.050556,
        housenumber="6801",
        country="USA",
    ),
    "Bank of Kentucky Center, Highland Heights, Kentucky": BANK_OF_KENTUCKY_CENTER,
    "Robins Center, Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="23173",
        lat=37.580701,
        lng=-77.538987,
        housenumber="",
        country="USA",
    ),
    "Allen County War Memorial Coliseum, Fort Wayne, Indiana": ALLEN_COUNTY_WAR_MEMORIAL_COLISEUM,
    "Island Federal Credit Union, Stony Brook, New York": STONY_BROOK_ARENA,
    "Cajundome, Lafayette, Louisiana": SportsballGeocodeTuple(
        city="Lafayette",
        state="LA",
        postal="70506",
        lat=30.218444,
        lng=-92.039056,
        housenumber="444",
        country="USA",
    ),
    "Thomas Assembly Center, Ruston, Louisiana": SportsballGeocodeTuple(
        city="Ruston",
        state="LA",
        postal="71272",
        lat=32.5321,
        lng=-92.6584,
        housenumber="1650",
        country="USA",
    ),
    "Worthington Arena, Bozeman, Montana": SportsballGeocodeTuple(
        city="Bozeman",
        state="MT",
        postal="",
        lat=45.6633,
        lng=-111.0506,
        housenumber="1",
        country="USA",
    ),
    "Mabee Center, Tulsa, Oklahoma": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74171",
        lat=36.04789,
        lng=-95.95573,
        housenumber="7777",
        country="USA",
    ),
    "Centrum, Cedar City, Utah": CENTRUM_ARENA,
    "Schoenecker Arena, St. Paul, Minnesota": SportsballGeocodeTuple(
        city="St. Paul",
        state="MN",
        postal="",
        lat=44.9395,
        lng=-93.1945,
        housenumber="",
        country="USA",
    ),
    "Icardo Center, Bakersfield, California": SportsballGeocodeTuple(
        city="Bakersfield",
        state="CA",
        postal="",
        lat=35.3475,
        lng=-119.102778,
        housenumber="",
        country="USA",
    ),
    "Titan Gym, Fullerton, California": SportsballGeocodeTuple(
        city="Fullerton",
        state="CA",
        postal="92834",
        lat=33.883046,
        lng=-117.88609,
        housenumber="800",
        country="USA",
    ),
    "Burns Arena, St. George, Utah": SportsballGeocodeTuple(
        city="St. George",
        state="UT",
        postal="",
        lat=37.101,
        lng=-113.566,
        housenumber="400",
        country="USA",
    ),
    "RIMAC Arena, La Jolla, California": SportsballGeocodeTuple(
        city="La Jolla",
        state="CA",
        postal="",
        lat=32.885278,
        lng=-117.239223,
        housenumber="9860",
        country="USA",
    ),
    "Climate Pledge Arena, Seattle, Washington": CLIMATE_PLEDGE_ARENA,
    "Draddy Gymnasium, Riverdale, New York": SportsballGeocodeTuple(
        city="Riverdale",
        state="NY",
        postal="",
        lat=40.89073,
        lng=-73.900158,
        housenumber="",
        country="USA",
    ),
    "William H. Pitt Center, Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="06825",
        lat=41.219439,
        lng=-73.244628,
        housenumber="5151",
        country="USA",
    ),
    "Alumni Arena, Buffalo, New York": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14221",
        lat=43.0,
        lng=-78.781111,
        housenumber="175",
        country="USA",
    ),
    "Merkert Gymnasium, Easton, Massachusetts": SportsballGeocodeTuple(
        city="Easton",
        state="MA",
        postal="",
        lat=42.0576,
        lng=-71.0789,
        housenumber="",
        country="USA",
    ),
    "John F. Savage Hall, Toledo, Ohio": SAVAGE_ARENA,
    "War Memorial at The Sobrato Center, San Francisco, California": WAR_MEMORIAL_GYMNASIUM,
    "The Jungle, Indianapolis, Indiana": THE_JUNGLE,
    "Lantz Arena, Charleston, Illinois": SportsballGeocodeTuple(
        city="Charleston",
        state="IL",
        postal="61920",
        lat=39.480403,
        lng=-88.178844,
        housenumber="250",
        country="USA",
    ),
    "Friel Court at Beasley Coliseum, Pullman, Washington": BEASLEY_COLISEUM,
    "The Matadome, Northridge, California": SportsballGeocodeTuple(
        city="Northridge",
        state="CA",
        postal="91330",
        lat=34.241974,
        lng=-118.526484,
        housenumber="18111",
        country="USA",
    ),
    "UC Riverside Student Recreation Center, Riverside, California": UCR_STUDENT_REC_CENTER,
    "Finneran Pavilion, Villanova, Pennsylvania": FINNERAN_PAVILION,
    "Allen Fieldhouse, Lawrence, Kansas": SportsballGeocodeTuple(
        city="Lawrence",
        state="KS",
        postal="",
        lat=38.954306,
        lng=-95.252394,
        housenumber="1651",
        country="USA",
    ),
    "CFE Arena, Orlando, Florida": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="",
        lat=28.6068,
        lng=-81.1976,
        housenumber="12777",
        country="USA",
    ),
    "Dale F. Halton Arena, Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28223",
        lat=35.306111,
        lng=-80.734444,
        housenumber="9201",
        country="USA",
    ),
    "A.J. Palumbo Center, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="15282",
        lat=40.4374,
        lng=-79.9879,
        housenumber="600",
        country="USA",
    ),
    "Thomas M. Ryan Center, Kingston, Rhode Island": RYAN_CENTER,
    "Prudential Center, Newark, New Jersey": SportsballGeocodeTuple(
        city="Newark",
        state="NJ",
        postal="",
        lat=40.733611,
        lng=-74.171111,
        housenumber="25",
        country="USA",
    ),
    "Ford Center, Evansville, Indiana": SportsballGeocodeTuple(
        city="Evansville",
        state="IN",
        postal="",
        lat=37.972189,
        lng=-87.567844,
        housenumber="1",
        country="USA",
    ),
    "Super Pit, Denton, Texas": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="76201",
        lat=33.208333,
        lng=-97.153889,
        housenumber="801",
        country="USA",
    ),
    "Athletics-Recreation Center, Valparaiso, Indiana": SportsballGeocodeTuple(
        city="Valparaiso",
        state="IN",
        postal="46383",
        lat=41.464198,
        lng=-87.048338,
        housenumber="1009",
        country="USA",
    ),
    "CSU Fieldhouse, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29406",
        lat=32.980822,
        lng=-80.067125,
        housenumber="9200",
        country="USA",
    ),
    "Hart Recreation Center, Worcester, Massachusetts": HART_RECREATION_CENTER,
    "McAlister Field House, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29409",
        lat=32.798508,
        lng=-79.962573,
        housenumber="171",
        country="USA",
    ),
    "Paul Porter Arena, Boiling Springs, North Carolina": SportsballGeocodeTuple(
        city="Boiling Springs",
        state="NC",
        postal="",
        lat=35.246538,
        lng=-81.669518,
        housenumber="",
        country="USA",
    ),
    "Mullins Center, Amherst, Massachusetts": SportsballGeocodeTuple(
        city="Amherst",
        state="MA",
        postal="01003",
        lat=42.389381,
        lng=-72.533439,
        housenumber="200",
        country="USA",
    ),
    "Richardson Indoor Stadium, Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="29303",
        lat=34.963427,
        lng=-81.93363,
        housenumber="601",
        country="USA",
    ),
    "Chaifetz Arena, St. Louis, Missouri": SportsballGeocodeTuple(
        city="St. Louis",
        state="MO",
        postal="63103",
        lat=38.63246,
        lng=-90.22797,
        housenumber="1",
        country="USA",
    ),
    "Fiserv Forum, Milwaukee, Wisconsin": FISERV_FORUM,
    "WVU Coliseum, Morgantown, West Virginia": SportsballGeocodeTuple(
        city="Morgantown",
        state="WV",
        postal="26505",
        lat=39.649167,
        lng=-79.981111,
        housenumber="",
        country="USA",
    ),
    "Bartow Arena, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.502164,
        lng=-86.809244,
        housenumber="617",
        country="USA",
    ),
    "McKeon Pavilion, Moraga, California": SportsballGeocodeTuple(
        city="Moraga",
        state="CA",
        postal="",
        lat=37.841247,
        lng=-122.106409,
        housenumber="1928",
        country="USA",
    ),
    "KFC Yum! Center, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="",
        lat=38.2575,
        lng=-85.753889,
        housenumber="1",
        country="USA",
    ),
    "DiSanto Field - Cleveland - OH - 44106": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="44106",
        lat=41.513444,
        lng=-81.603639,
        housenumber="1747",
        country="USA",
    ),
    "University Arena, Kalamazoo, Michigan": SportsballGeocodeTuple(
        city="Kalamazoo",
        state="MI",
        postal="",
        lat=42.283372,
        lng=-85.60845,
        housenumber="",
        country="USA",
    ),
    "Gallagher-Iba Arena, Stillwater, Oklahoma": SportsballGeocodeTuple(
        city="Stillwater",
        state="OK",
        postal="74078",
        lat=36.125833,
        lng=-97.065,
        housenumber="1046",
        country="USA",
    ),
    "Arena-Auditorium, Laramie, Wyoming": SportsballGeocodeTuple(
        city="Laramie",
        state="WY",
        postal="82071",
        lat=41.313344,
        lng=-105.569419,
        housenumber="1000",
        country="USA",
    ),
    "DunnâOliver Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "Health & Physical Education Arena, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.43,
        lng=-95.21,
        housenumber="",
        country="USA",
    ),
    "Memorial Hall, Dover, Delaware": SportsballGeocodeTuple(
        city="Dover",
        state="DE",
        postal="",
        lat=39.1876,
        lng=-75.5434,
        housenumber="",
        country="USA",
    ),
    "Franklin Field - Philadelphia - PA - 19104": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.95,
        lng=-75.19,
        housenumber="",
        country="USA",
    ),
    "Texas A&MâCommerce Field House, Commerce, Texas": TEXAS_AM_COMMERCE_FIELD_HOUSE,
    "William J. Nicks Building, Prairie View, Texas": SportsballGeocodeTuple(
        city="Prairie View",
        state="TX",
        postal="77446",
        lat=30.092278,
        lng=-95.993083,
        housenumber="100",
        country="USA",
    ),
    "Matthew Knight Arena, Eugene, Oregon": SportsballGeocodeTuple(
        city="Eugene",
        state="OR",
        postal="97401",
        lat=44.045,
        lng=-123.066,
        housenumber="1390",
        country="USA",
    ),
    "Harry A. Gampel Pavilion, Storrs, Connecticut": SportsballGeocodeTuple(
        city="Storrs",
        state="CT",
        postal="06269",
        lat=41.805292,
        lng=-72.254194,
        housenumber="2095",
        country="USA",
    ),
    "Steinberg Wellness Center, Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.69059,
        lng=-73.979176,
        housenumber="",
        country="USA",
    ),
    "The Palestra, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.951411,
        lng=-75.188606,
        housenumber="235",
        country="USA",
    ),
    "Spiro Sports Center, Staten Island, New York": SportsballGeocodeTuple(
        city="Staten Island",
        state="NY",
        postal="10301",
        lat=40.614966,
        lng=-74.095729,
        housenumber="",
        country="USA",
    ),
    "Pizzitola Sports Center, Providence, Rhode Island": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="02906",
        lat=41.831743,
        lng=-71.398043,
        housenumber="",
        country="USA",
    ),
    "Newman Arena, Ithaca, New York": SportsballGeocodeTuple(
        city="Ithaca",
        state="NY",
        postal="14853",
        lat=42.445794,
        lng=-76.476581,
        housenumber="",
        country="USA",
    ),
    "Al Lawson Center, Tallahassee, Florida": AL_LAWSON_CENTER,
    "Hanner Fieldhouse, Statesboro, Georgia": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="30458",
        lat=32.427778,
        lng=-81.779444,
        housenumber="590",
        country="USA",
    ),
    "Carnesecca Arena, Jamaica, New York": SportsballGeocodeTuple(
        city="Jamaica",
        state="NY",
        postal="",
        lat=40.724167,
        lng=-73.794444,
        housenumber="",
        country="USA",
    ),
    "Pan American Center, Las Cruces, New Mexico": SportsballGeocodeTuple(
        city="Las Cruces",
        state="NM",
        postal="88003",
        lat=32.284,
        lng=-106.7422,
        housenumber="1810",
        country="USA",
    ),
    "Jadwin Gymnasium, Princeton, New Jersey": SportsballGeocodeTuple(
        city="Princeton",
        state="NJ",
        postal="08542",
        lat=40.343449,
        lng=-74.648595,
        housenumber="",
        country="USA",
    ),
    "Matthews Arena, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.341111,
        lng=-71.084444,
        housenumber="238",
        country="USA",
    ),
    "Calihan Hall, Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="48221",
        lat=42.414167,
        lng=-83.135833,
        housenumber="4001",
        country="USA",
    ),
    "Curry Arena, Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28274",
        lat=35.1884989,
        lng=-80.8351236,
        housenumber="2201",
        country="USA",
    ),
    "Events Center, Binghamton, New York": BINGHAMPTON_UNIVERSITY_EVENTS_CENTER,
    "Jeff Farris Center, Conway, Arkansas": FARRIS_CENTER,
    "TD Arena, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29401",
        lat=32.785556,
        lng=-79.934444,
        housenumber="301",
        country="USA",
    ),
    "Betty Engelstad Sioux Center , Grand Forks, North Dakota": SportsballGeocodeTuple(
        city="Grand Forks",
        state="ND",
        postal="58203",
        lat=47.92767,
        lng=-97.07247,
        housenumber="1",
        country="USA",
    ),
    "Reese Court, Cheney, Washington": SportsballGeocodeTuple(
        city="Cheney",
        state="WA",
        postal="",
        lat=47.4914,
        lng=-117.5892,
        housenumber="",
        country="USA",
    ),
    "ICCU Arena, Moscow, Idaho": ICCU_ARENA,
    "Flowers Hall, Florence, Alabama": SportsballGeocodeTuple(
        city="Florence",
        state="AL",
        postal="",
        lat=34.808333,
        lng=-87.683889,
        housenumber="615",
        country="USA",
    ),
    "CBU Events Center, Riverside, California": SportsballGeocodeTuple(
        city="Riverside",
        state="CA",
        postal="",
        lat=33.927501,
        lng=-117.423266,
        housenumber="8431",
        country="USA",
    ),
    "Spokane Veterans Memorial Arena, Spokane, Washington": SportsballGeocodeTuple(
        city="Spokane",
        state="WA",
        postal="",
        lat=47.666,
        lng=-117.423,
        housenumber="720",
        country="USA",
    ),
    "Indiana Farmers Coliseum, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.8275,
        lng=-86.135,
        housenumber="1202",
        country="USA",
    ),
    "Moody Coliseum , Abilene, Texas": SportsballGeocodeTuple(
        city="Abilene",
        state="TX",
        postal="",
        lat=32.470333,
        lng=-99.70925,
        housenumber="",
        country="USA",
    ),
    "Cross Insurance Center, Bangor, Maine": SportsballGeocodeTuple(
        city="Bangor",
        state="ME",
        postal="",
        lat=44.7893,
        lng=-68.7787,
        housenumber="515",
        country="USA",
    ),
    "Klotsche Center, Milwaukee, Wisconsin": SportsballGeocodeTuple(
        city="Milwaukee",
        state="WI",
        postal="53233",
        lat=43.079414,
        lng=-87.879783,
        housenumber="3409",
        country="USA",
    ),
    "Dugan Wellness Center, Corpus Christi, Texas": SportsballGeocodeTuple(
        city="Corpus Christi",
        state="TX",
        postal="78412",
        lat=27.711472,
        lng=-97.324361,
        housenumber="6300",
        country="USA",
    ),
    "Fleming Gymnasium, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.069384,
        lng=-79.81268,
        housenumber="",
        country="USA",
    ),
    "Enterprise Center, St. Louis, Missouri": ENTERPRISE_CENTER,
    "Legacy Arena, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.52378,
        lng=-86.812935,
        housenumber="2100",
        country="USA",
    ),
    "MassMutual Center, Springfield, Massachusetts": SportsballGeocodeTuple(
        city="Springfield",
        state="MA",
        postal="",
        lat=42.102222,
        lng=-72.586944,
        housenumber="1277",
        country="USA",
    ),
    "Sanford Pentagon, Sioux Falls, South Dakota": SportsballGeocodeTuple(
        city="Sioux Falls",
        state="SD",
        postal="",
        lat=43.593056,
        lng=-96.758611,
        housenumber="2210",
        country="USA",
    ),
    "Barclays Center, Brooklyn, New York": BARCLAYS_CENTER,
    "Orleans Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.105833,
        lng=-115.202222,
        housenumber="4500",
        country="USA",
    ),
    "Mohegan Sun Arena, Uncasville, Connecticut": SportsballGeocodeTuple(
        city="Uncasville",
        state="CT",
        postal="",
        lat=41.491111,
        lng=-72.089722,
        housenumber="1",
        country="USA",
    ),
    "Hilliard Gates Sports Center, Fort Wayne, Indiana": SportsballGeocodeTuple(
        city="Fort Wayne",
        state="IN",
        postal="46835",
        lat=41.119,
        lng=-85.1076,
        housenumber="2101",
        country="USA",
    ),
    "XL Center, Hartford, Connecticut": SportsballGeocodeTuple(
        city="Hartford",
        state="CT",
        postal="",
        lat=41.768333,
        lng=-72.676944,
        housenumber="1",
        country="USA",
    ),
    "Spectrum Center, Charlotte, North Carolina": SPECTRUM_CENTRE,
    "Little Caesars Arena, Detroit, Michigan": LITTLE_CAESARS_ARENA,
    "Sprint Center, Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.0975,
        lng=-94.580278,
        housenumber="1407",
        country="USA",
    ),
    "Mississippi Coliseum, Jackson, Mississippi": SportsballGeocodeTuple(
        city="Jackson",
        state="MS",
        postal="",
        lat=32.300126,
        lng=-90.172121,
        housenumber="1207",
        country="USA",
    ),
    "Hytche Athletic Center, Princess Anne, Maryland": SportsballGeocodeTuple(
        city="Princess Anne",
        state="MD",
        postal="",
        lat=38.211184,
        lng=-75.687227,
        housenumber="",
        country="USA",
    ),
    "State Farm Arena, Atlanta, Georgia": STATE_FARM_ARENA,
    "Gainbridge Fieldhouse, Indianapolis, Indiana": GAINBRIDGE_FIELDHOUSE,
    "Mississippi Coast Coliseum, Biloxi, Mississippi": SportsballGeocodeTuple(
        city="Biloxi",
        state="MS",
        postal="39531",
        lat=30.3935,
        lng=-88.9746,
        housenumber="2350",
        country="USA",
    ),
    "Footprint Center, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Simmons Bank Arena, North Little Rock, Arkansas": SIMMONS_BANK_ARENA,
    "FLA Live Arena, Sunrise, Florida": SportsballGeocodeTuple(
        city="Sunrise",
        state="FL",
        postal="",
        lat=26.158333,
        lng=-80.325556,
        housenumber="1",
        country="USA",
    ),
    "Dollar Loan Center, Henderson, Nevada": SportsballGeocodeTuple(
        city="Henderson",
        state="NV",
        postal="",
        lat=36.018977,
        lng=-115.081632,
        housenumber="200",
        country="USA",
    ),
    "Vivint Arena, Salt Lake City, Utah": VIVINT_ARENA,
    "Rock Hill Sports & Event Center, Rock Hill, South Carolina": SportsballGeocodeTuple(
        city="Rock Hill",
        state="SC",
        postal="29730",
        lat=34.9318802,
        lng=-81.0299645,
        housenumber="326",
        country="USA",
    ),
    "David Stopher Gymnasium, Thibodaux, Louisiana": SportsballGeocodeTuple(
        city="Thibodaux",
        state="LA",
        postal="",
        lat=29.79235,
        lng=-90.80135,
        housenumber="",
        country="USA",
    ),
    "Dickies Arena, Fort Worth, Texas": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="",
        lat=32.740891,
        lng=-97.369938,
        housenumber="1911",
        country="USA",
    ),
    "Rolle Activity Center, Flagstaff, Arizona": SportsballGeocodeTuple(
        city="Flagstaff",
        state="AZ",
        postal="86001",
        lat=35.1768307,
        lng=-111.6553593,
        housenumber="",
        country="USA",
    ),
    "Idaho Central Arena, Boise, Idaho": IDAHO_CENTRAL_ARENA,
    "Wellness Center, Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.69059,
        lng=-73.979176,
        housenumber="",
        country="USA",
    ),
    "Baha Mar Convention Center, Nassau": SportsballGeocodeTuple(
        city="Nassau",
        state="",
        postal="",
        lat=25.0703613,
        lng=-77.4001874,
        housenumber="",
        country="Bahamas",
    ),
    "DeGol Arena, Loretto, Pennsylvania": DEGOL_ARENA,
    "MGM Grand Garden Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.104808,
        lng=-115.168614,
        housenumber="3799",
        country="USA",
    ),
    "Imperial Arena at Atlantis Resort, Nassau": IMPERIAL_ARENA,
    "State Farm Field House, Lake Buena Vista, Florida": STATE_FARM_FIELDHOUSE,
    "Los Angeles Memorial Sports Arena": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Boston Garden": BOSTON_GARDENS,
    "Cow Palace - Daly City, California - United States": SportsballGeocodeTuple(
        city="Daly City",
        state="CA",
        postal="",
        lat=37.706667,
        lng=-122.418611,
        housenumber="2600",
        country="USA",
    ),
    "The Forum": THE_FORUM,
    "Spectrum": SPECTRUM,
    "Madison Square Garden - New York City, New York - United States": MADISON_SQUARE_GARDEN,
    "Milwaukee Arena": MILWAUKEE_ARENA,
    "Chicago Stadium": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="",
        lat=41.881667,
        lng=-87.672778,
        housenumber="1800",
        country="USA",
    ),
    "Memorial Coliseum - Portland, Oregon - United States": MEMORIAL_COLISEUM,
    "McNichols Sports Arena": MCNICHOLS_SPORTS_ARENA,
    "Kemper Arena": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.742778,
        lng=-105.0225,
        housenumber="1800",
        country="USA",
    ),
    "Omni Coliseum": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30303",
        lat=33.7575,
        lng=-84.396667,
        housenumber="100",
        country="USA",
    ),
    "Great Western Forum": THE_FORUM,
    "The Palace of Auburn Hills - Auburn Hills, MI - USA": THE_PALACE_OF_AUBURN_HILLS,
    "America West Arena": AMERICA_WEST_ARENA,
    "Quicken Loans Arena - Cleveland, Ohio - United States": QUICKEN_LOANS_ARENA,
    "Pepsi Center - Denver, Colorado, U.S. - United States": PEPSI_CENTRE,
    "Staples Center": STAPLES_CENTRE,
    "American Airlines Arena": AMERICAN_AIRLINES_ARENA,
    "Chesapeake Energy Arena - Oklahoma City, Oklahoma - United States": CHESAPEAKE_ENERGY_ARENA,
    "AT&T Center - San Antonio, Texas - United States": ATT_CENTER,
    "Oakland Arena - Oakland, California - United States": OAKLAND_ARENA,
    "ESPN Wide World of Sports Complex": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "International Amphitheatre": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60609",
        lat=41.816111,
        lng=-87.646111,
        housenumber="4220",
        country="USA",
    ),
    "Lahaina Civic Center, Lahaina, Hawaii": SportsballGeocodeTuple(
        city="Lahaina",
        state="HI",
        postal="",
        lat=20.904995,
        lng=-156.683852,
        housenumber="1840",
        country="USA",
    ),
    "San Jose Civic Auditorium": SAN_JOSE_CIVIC_AUDITORIUM,
    "Suncoast Credit Union Arena, Fort Myers, Florida": SportsballGeocodeTuple(
        city="Fort Myers",
        state="FL",
        postal="33919",
        lat=26.5478,
        lng=-81.8869,
        housenumber="13351",
        country="USA",
    ),
    "The Spectrum - Guildford, Surrey, United Kingdom - United Kingdom": SportsballGeocodeTuple(
        city="Surrey",
        state="",
        postal="",
        lat=51.24844,
        lng=-0.56288,
        housenumber="",
        country="UK",
    ),
    "San Diego Sports Arena": SAN_DIEGO_SPORTS_ARENA,
    "Hertz Arena, Estero, Florida": HERTZ_ARENA,
    "Hard Rock Hotel Riviera Maya, Cancun": SportsballGeocodeTuple(
        city="Cancun",
        state="",
        postal="",
        lat=20.5069801,
        lng=-87.215373,
        housenumber="",
        country="Mexico",
    ),
    "T-Mobile Arena, Las Vegas, Nevada": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="",
        lat=36.102778,
        lng=-115.178333,
        housenumber="3780",
        country="USA",
    ),
    "Ocean Center, Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="",
        lat=29.2287,
        lng=-81.0106,
        housenumber="101",
        country="USA",
    ),
    "John Gray Gymnasium, Grand Cayman": SportsballGeocodeTuple(
        city="Grand Cayman",
        state="",
        postal="",
        lat=19.279316,
        lng=-81.385651,
        housenumber="73",
        country="UK",
    ),
    "Woodling Gym, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.503355,
        lng=-81.671269,
        housenumber="",
        country="USA",
    ),
    "Municipal Auditorium": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.167581,
        lng=-86.782244,
        housenumber="417",
        country="USA",
    ),
    "Elridge Wilburn Blake Sports and Fitness Center, St. Thomas": SportsballGeocodeTuple(
        city="St. Thomas",
        state="USVI",
        postal="",
        lat=18.340096,
        lng=-64.97306,
        housenumber="",
        country="USA",
    ),
    "Market Square Arena": MARKET_SQUARE_ARENA,
    "Chase Center, San Francisco, California": CHASE_CENTER,
    "Reunion Arena": REUNION_ARENA,
    "Walsh Gymnasium, South Orange, New Jersey": SportsballGeocodeTuple(
        city="South Orange",
        state="NJ",
        postal="07079",
        lat=40.74169,
        lng=-74.244921,
        housenumber="",
        country="USA",
    ),
    "Alamodome, San Antonio, Texas": ALAMODOME,
    "Moore Gymnasium, Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="",
        lat=29.210895,
        lng=-81.030977,
        housenumber="",
        country="USA",
    ),
    "Tacoma Dome": SportsballGeocodeTuple(
        city="Tacoma",
        state="WA",
        postal="98421",
        lat=47.236667,
        lng=-122.426667,
        housenumber="2727",
        country="USA",
    ),
    "Royal Farms Arena, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.288611,
        lng=-76.618889,
        housenumber="201",
        country="USA",
    ),
    "Joe Louis Arena - Detroit, Michigan - United States": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.325278,
        lng=-83.051389,
        housenumber="19",
        country="USA",
    ),
    "Arco Arena - Sacramento, California - United States": ARCO_ARENA,
    "Nassau Coliseum, Uniondale, New York": NASSAU_COLISEUM,
    "Bradley Center": BRADLEY_CENTER,
    "Charlotte Coliseum": CHARLOTTE_COLISEUM,
    "Toyota Center, Houston, Texas": TOYOTA_CENTRE,
    "American Airlines Center, Dallas, Texas": AMERICAN_AIRLINES_ARENA,
    "Miami Arena": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="",
        lat=25.781111,
        lng=-80.194722,
        housenumber="721",
        country="USA",
    ),
    "Al McGuire Center, Milwaukee, Wisconsin": SportsballGeocodeTuple(
        city="Milwaukee",
        state="WI",
        postal="53233",
        lat=43.039722,
        lng=-87.926389,
        housenumber="770",
        country="USA",
    ),
    "Orlando Arena": ORLANDO_ARENA,
    "Tokyo Metropolitan Gymnasium": SportsballGeocodeTuple(
        city="Tokyo",
        state="",
        postal="",
        lat=35.679694,
        lng=139.7125,
        housenumber="",
        country="Japan",
    ),
    "Target Center - Minneapolis, Minnesota - United States": TARGET_CENTER,
    "Thomas & Mack Center - Paradise, NV - United States": THOMAS_AND_MACK_CENTER,
    "Delta Center - Salt Lake City, Utah - United States": DELTA_CENTER,
    "Yokohama Arena": SportsballGeocodeTuple(
        city="Kanagawa",
        state="",
        postal="",
        lat=35.512389,
        lng=139.620056,
        housenumber="",
        country="Japan",
    ),
    "Anaheim Convention Center": ANAHEIM_CONVENTION_CENTER,
    "TD Banknorth Garden": TD_GARDEN,
    "Amway Arena": ORLANDO_ARENA,
    "TD Garden - Boston, Massachusetts - United States": TD_GARDEN,
    "American Airlines Center - Dallas, Texas, USA - United States": AMERICAN_AIRLINES_ARENA,
    "FTX Arena": FTX_ARENA,
    "Rose Garden": ROSE_GARDEN,
    "Toyota Center - Kennewick, Washington - United States": TOYOTA_CENTER,
    "Philips Arena": STATE_FARM_ARENA,
    "United Center - Chicago, Illinois - United States": UNITED_CENTER,
    "Wachovia Center": SPECTRUM,
    "New Orleans Arena": CAESARS_SUPERDOME,
    "Ball Arena - Denver, CO - United States": PEPSI_CENTRE,
    "Saitama Super Arena - Saitama, Japan - Japan": SportsballGeocodeTuple(
        city="Saitama",
        state="",
        postal="",
        lat=35.894889,
        lng=139.630831,
        housenumber="8",
        country="Japan",
    ),
    "Rogers Place - Edmonton, Alberta, Canada - Canada": SportsballGeocodeTuple(
        city="Edmonton",
        state="AL",
        postal="",
        lat=53.546944,
        lng=-113.497778,
        housenumber="10220",
        country="Canada",
    ),
    "Etihad Arena - Yas Bay Waterfront, Yas Island, Abu Dhabi - United Arab Emirates": SportsballGeocodeTuple(
        city="Abu Dhabi",
        state="",
        postal="",
        lat=24.4603,
        lng=54.604,
        housenumber="",
        country="UAE",
    ),
    "Gainbridge Fieldhouse - Indianapolis, Indiana - United States": GAINBRIDGE_FIELDHOUSE,
    "Fiserv Forum - Milwaukee, Wisconsin - United States": FISERV_FORUM,
    "Crypto.com Arena - Los Angeles, California, USA - United States": STAPLES_CENTRE,
    "Golden 1 Center - Sacramento, California - United States": GOLDEN_1_CENTER,
    "Moda Center, Portland, Oregon": MODA_CENTER,
    "United Center, Chicago, Illinois": UNITED_CENTER,
    "Rocket Mortgage Fieldhouse, Cleveland, Ohio": ROCKET_MORTGAGE_FIELDHOUSE,
    "FedEx Forum, Memphis, Tennessee": FEDEX_FORUM,
    "Target Center, Minneapolis, Minnesota": TARGET_CENTER,
    "Kia Center, Orlando, Florida": KIA_CENTER,
    "AccorHotels Arena, Paris, France": ACCOR_ARENA,
    "Ball Arena, Denver, Colorado": PEPSI_CENTRE,
    "Crypto.com Arena, Los Angeles, California": STAPLES_CENTRE,
    "Paycom Center, Oklahoma City, Oklahoma": PAYCOM_CENTRE,
    "Golden 1 Center, Sacramento, California": GOLDEN_1_CENTER,
    "Kaseya Center, Miami, Florida": KASEYA_CENTER,
    "Scotiabank Arena, Toronto, Canada": SCOTIABANK_ARENA,
    "Smoothie King Center, New Orleans, Louisiana": CAESARS_SUPERDOME,
    "TD Garden, Boston, Massachusetts": TD_GARDEN,
    "Frost Bank Center, San Antonio, Texas": FROST_BANK_CENTER,
    "Intuit Dome, Inglewood, California": INTUIT_DOME,
    "Delta Center, Salt Lake City, Utah": DELTA_CENTER,
    "AT&T Center, San Antonio, Texas": ATT_CENTER,
    "FTX Arena, Miami, Florida": FTX_ARENA,
    "Vivint Smart Home Arena, Salt Lake City, Utah": VIVINT_ARENA,
    "Chesapeake Energy Arena, Oklahoma City, Oklahoma": CHESAPEAKE_ENERGY_ARENA,
    "The Arena, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "HP Field House, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Mexico City Arena, Mexico City, Mexico": SportsballGeocodeTuple(
        city="Mexico City",
        state="",
        postal="04650",
        lat=19.496309,
        lng=-99.175429,
        housenumber="",
        country="Mexico",
    ),
    "Amway Center, Orlando, Florida": ORLANDO_ARENA,
    "Phoenix Suns Arena, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Quicken Loans Arena, Cleveland, Ohio": QUICKEN_LOANS_ARENA,
    "STAPLES Center, Los Angeles, California": STAPLES_CENTRE,
    "Bankers Life Fieldhouse, Indianapolis, Indiana": GAINBRIDGE_FIELDHOUSE,
    "AmericanAirlines Arena, Miami, Florida": KASEYA_CENTER,
    "Amalie Arena, Tampa, Florida": AMALIE_ARENA,
    "Pepsi Center, Denver, Colorado": PEPSI_CENTRE,
    "Visa Athletic Center, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Dunn–Oliver Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "Talking Stick Resort Arena, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Oracle Arena, Oakland, California": OAKLAND_ARENA,
    "The O2 Arena, London, United Kingdom": O2_ARENA,
    "Air Canada Centre, Toronto, Canada": SCOTIABANK_ARENA,
    "BMO Harris Bradley Center, Milwaukee, Wisconsin": BRADLEY_CENTER,
    "Philips Arena, Atlanta, Georgia": STATE_FARM_ARENA,
    "UW–Milwaukee Panther Arena, Milwaukee, Wisconsin": MILWAUKEE_ARENA,
    "Dreamstyle Arena, Albuquerque, New Mexico": THE_PIT,
    "Tom Gola Arena, Philadelphia, Pennsylvania": JOHN_GLASER_ARENA,
    "Texas A&M–Commerce Field House, Commerce, Texas": TEXAS_AM_COMMERCE_FIELD_HOUSE,
    "Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.333333,
        lng=-83.05,
        housenumber="",
        country="USA",
    ),
    "Rec Hall, University Park, Pennsylvania": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.79578,
        lng=-77.869399,
        housenumber="",
        country="USA",
    ),
    "Dallas, Texas": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="",
        lat=32.779167,
        lng=-96.808889,
        housenumber="",
        country="USA",
    ),
    "The Gabba, Brisbane, Australia": GABBA,
    "Sydney Cricket Ground, Sydney, Australia": SCG,
    "People First Stadium, Gold Coast, Australia": PEOPLE_FIRST_STADIUM,
    "Engie Stadium, Sydney, Australia": ENGIE_STADIUM,
    "Melbourne Cricket Ground, Melbourne, Australia": MCG,
    "GMHBA Stadium, Geelong, Australia": GMHBA_STADIUM,
    "Marvel Stadium, Melbourne, Australia": MARVEL_STADIUM,
    "Adelaide Oval, Adelaide, Australia": ADELAIDE_OVAL,
    "Optus Stadium, Perth, Australia": OPTUS_STADIUM,
    "Wisdom Gymnasium, Stephenville, Texas": WISDOM_GYM,
    "Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="",
        lat=35.227222,
        lng=-80.843056,
        housenumber="",
        country="USA",
    ),
    "Salt Lake City, Utah": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="",
        lat=40.760833,
        lng=-111.891111,
        housenumber="",
        country="USA",
    ),
    "Ferrell Center, Waco, Texas": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="76706",
        lat=31.547903,
        lng=-97.105969,
        housenumber="1900",
        country="USA",
    ),
    "Princeton, New Jersey": SportsballGeocodeTuple(
        city="Princeton",
        state="NJ",
        postal="",
        lat=40.358244,
        lng=-74.666728,
        housenumber="",
        country="USA",
    ),
    "Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.162222,
        lng=-86.774444,
        housenumber="",
        country="USA",
    ),
    "Fort Worth, Texas": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="",
        lat=32.756389,
        lng=-97.3325,
        housenumber="",
        country="USA",
    ),
    "T-Mobile Center, Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MS",
        postal="",
        lat=39.0975,
        lng=-94.580278,
        housenumber="1407",
        country="USA",
    ),
    "Henderson, Nevada": SportsballGeocodeTuple(
        city="Henderson",
        state="NV",
        postal="",
        lat=36.033333,
        lng=-114.983333,
        housenumber="",
        country="USA",
    ),
    "Lake Charles, Louisiana": SportsballGeocodeTuple(
        city="Lake Charles",
        state="LA",
        postal="",
        lat=30.214722,
        lng=-93.208611,
        housenumber="",
        country="USA",
    ),
    "Pensacola Bay Center, Pensacola, Florida": SportsballGeocodeTuple(
        city="Pensacola",
        state="FL",
        postal="32502",
        lat=30.416485,
        lng=-87.209372,
        housenumber="201",
        country="USA",
    ),
    "Rose Hill Gymnasium, Bronx, New York": ROSE_HILL_GYM,
    "Austin, Texas": SportsballGeocodeTuple(
        city="Austin",
        state="TX",
        postal="",
        lat=30.267222,
        lng=-97.743056,
        housenumber="",
        country="USA",
    ),
    "Lundholm Gym, Durham, New Hampshire": SportsballGeocodeTuple(
        city="Durham",
        state="NH",
        postal="03824",
        lat=43.138611,
        lng=-70.938056,
        housenumber="145",
        country="USA",
    ),
    "Clune Arena, Colorado Springs, Colorado": SportsballGeocodeTuple(
        city="Colorado Springs",
        state="CO",
        postal="",
        lat=39.014,
        lng=-104.8833,
        housenumber="2168",
        country="USA",
    ),
    "Donald L. Tucker Civic Center, Tallahassee, Florida": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32301",
        lat=30.437842,
        lng=-84.28669,
        housenumber="505",
        country="USA",
    ),
    "Denny Sanford Premier Center, Sioux Falls, South Dakota": SportsballGeocodeTuple(
        city="Sioux Falls",
        state="SD",
        postal="",
        lat=43.561667,
        lng=-96.75,
        housenumber="1201",
        country="USA",
    ),
    "Joseph J. Gentile Arena, Chicago, Illinois": JOSEPH_J_GENTILES_CENTER,
    "Dunn-Oliver Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "Oklahoma City, Oklahoma": SportsballGeocodeTuple(
        city="Oklahoma City",
        state="OK",
        postal="",
        lat=35.468611,
        lng=-97.521389,
        housenumber="",
        country="USA",
    ),
    "Harrah's Cherokee Center, Asheville, North Carolina": HARRAHS_CHEROKEE_CENTER,
    "Savage Arena, Toledo, Ohio": SAVAGE_ARENA,
    "Pullman, Washington": SportsballGeocodeTuple(
        city="Pullman",
        state="WA",
        postal="",
        lat=46.733333,
        lng=-117.168611,
        housenumber="87",
        country="USA",
    ),
    "Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="",
        lat=41.15,
        lng=-73.266667,
        housenumber="87",
        country="USA",
    ),
    "Talmadge L. Hill Field House, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.3425,
        lng=-76.585,
        housenumber="1700",
        country="USA",
    ),
    "McDougald-McLendon Arena, Durham, North Carolina": MCDOUGALD_MCLENON_ARENA,
    "Athletics Center O''rena, Rochester, Michigan": ATHELTICS_CENTER_ORENA,
    "Nutter Center, Dayton, Ohio": NUTTER_CENTER,
    "Addition Financial Arena, Orlando, Florida": ADDITION_FINANCIAL_ARENA,
    "Colonial Life Arena, Columbia, South Carolina": COLONIAL_LIFE_ARENA,
    "James H. Hilton Coliseum, Ames, Iowa": JAMES_H_HILTON_COLISEUM,
    "Provident Credit Union Event Center, San Jose, California": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95192",
        lat=37.33536,
        lng=-121.87985,
        housenumber="290",
        country="USA",
    ),
    "Denton, Texas": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="",
        lat=33.216389,
        lng=-97.129167,
        housenumber="",
        country="USA",
    ),
    "Coral Gables, Florida": SportsballGeocodeTuple(
        city="Coral Gables",
        state="FL",
        postal="",
        lat=25.716667,
        lng=-80.272222,
        housenumber="",
        country="USA",
    ),
    "Breslin Student Events Center, East Lansing, Michigan": BRESLIN_EVENTS_CENTER,
    "Kingston, Rhode Island": SportsballGeocodeTuple(
        city="Kingston",
        state="KI",
        postal="",
        lat=41.483333,
        lng=-71.533333,
        housenumber="",
        country="USA",
    ),
    "Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.499167,
        lng=-81.694722,
        housenumber="",
        country="USA",
    ),
    "Chase Athletic Center, Smithfield, Rhode Island": CHASE_ATHLETIC_CENTER,
    "Murphy Center, Murfreesboro, Tennessee": MURPHY_ATHELTIC_CENTER,
    "Stephen C. O''Connell Center, Gainesville, Florida": STEPHEN_C_OCONNELL_CENTER,
    "Chesapeake Employers Insurance Arena, Baltimore, Maryland": CHESAPEAKE_ENERGY_ARENA,
    "F. G. Clark Center, Baton Rouge, Louisiana": F_G_CLARK_ACTIVITY_CENTER,
    "Bozeman, Montana": SportsballGeocodeTuple(
        city="Bozeman",
        state="MT",
        postal="",
        lat=45.685556,
        lng=-111.025,
        housenumber="",
        country="USA",
    ),
    "KSU Convocation Center, Kennesaw, Georgia": KSU_CONVOCATION_CENTER,
    "Fredrick C. Hobdy Assembly Center, Grambling, Louisiana": FREDRICK_C_HOBDY_ASSEMBLY_CENTER,
    "Walkup Skydome, Flagstaff, Arizona": WALKUP_SKYDOME,
    "Dahlberg Arena, Missoula, Montana": DAHLBERG_ARENA,
    "Great Southern Bank Arena, Springfield, Missouri": GREAT_SOUTHERN_BANK_ARENA,
    "Banterra Center, Carbondale, Illinois": SportsballGeocodeTuple(
        city="Carbondale",
        state="IL",
        postal="",
        lat=37.708333,
        lng=-89.218611,
        housenumber="",
        country="USA",
    ),
    "McCann Arena, Poughkeepsie, New York": MCCANN_ARENA,
    "CU Events Center, Boulder, Colorado": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="",
        lat=40.0047,
        lng=-105.2606,
        housenumber="950",
        country="USA",
    ),
    "Coleman Coliseum, Tuscaloosa, Alabama": COLEMAN_COLISEUM,
    "Neville Arena, Auburn, Alabama": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="36849",
        lat=32.60253,
        lng=-85.49301,
        housenumber="250",
        country="USA",
    ),
    "University Credit Union Pavilion, Moraga, California": SportsballGeocodeTuple(
        city="Moraga",
        state="CA",
        postal="",
        lat=37.841247,
        lng=-122.106409,
        housenumber="1928",
        country="USA",
    ),
    "Bernard Johnson Coliseum, Huntsville, Texas": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="77340",
        lat=30.712778,
        lng=-95.546111,
        housenumber="1964",
        country="USA",
    ),
    "Amica Mutual Pavilion, Providence, Rhode Island": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="",
        lat=41.823611,
        lng=-71.418333,
        housenumber="1",
        country="USA",
    ),
    "George Gervin GameAbove Center, Ypsilanti, Michigan": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="48197",
        lat=42.254444,
        lng=-83.647222,
        housenumber="799",
        country="USA",
    ),
    "Binghamton, New York": SportsballGeocodeTuple(
        city="Binghamton",
        state="NY",
        postal="",
        lat=42.098889,
        lng=-75.910833,
        housenumber="",
        country="USA",
    ),
    "McKenzie Arena, Chattanooga, Tennessee": SportsballGeocodeTuple(
        city="Chattanooga",
        state="TN",
        postal="37403",
        lat=35.050382,
        lng=-85.30091,
        housenumber="720",
        country="USA",
    ),
    "Timmons Arena, Greenville, South Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="SC",
        postal="29613",
        lat=34.9179345,
        lng=-82.437289,
        housenumber="3300",
        country="USA",
    ),
    "Betty Engelstad Sioux Center, Grand Forks, North Dakota": SportsballGeocodeTuple(
        city="Grand Forks",
        state="ND",
        postal="58203",
        lat=47.92767,
        lng=-97.07247,
        housenumber="1",
        country="USA",
    ),
    "Ross E. Templeton Center, Clinton, South Carolina": ROSS_E_TEMPLETON_CENTER,
    "PPG Paints Arena, Pittsburgh, Pennsylvania": PPG_PAINTS_ARENA,
    "Levien Gymnasium, New York, New York": LEVIEN_GYM,
    "Simon Skjodt Assembly Hall, Bloomington, Indiana": SportsballGeocodeTuple(
        city="Bloomington",
        state="IN",
        postal="47408",
        lat=39.1808334,
        lng=-86.522222,
        housenumber="1001",
        country="USA",
    ),
    "Crisler Center, Ann Arbor, Michigan": CRISLER_CENTER,
    "Jersey Mike's Arena, New Brunswick, New Jersey": JERSEY_MIKES_ARENA,
    "Fertitta Center, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77004",
        lat=29.724722,
        lng=-95.346944,
        housenumber="3875",
        country="USA",
    ),
    "UMPC Cooper Fieldhouse, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="15282",
        lat=40.4374,
        lng=-79.9879,
        housenumber="600",
        country="USA",
    ),
    "Davey Whitney Complex, Alcorn State, Mississippi": SportsballGeocodeTuple(
        city="Alcorn State",
        state="MS",
        postal="",
        lat=31.873225,
        lng=-91.13318,
        housenumber="",
        country="USA",
    ),
    "John J. Lee Amphitheater, New Haven, Connecticut": SportsballGeocodeTuple(
        city="New Haven",
        state="CT",
        postal="06511",
        lat=41.313611,
        lng=-72.930556,
        housenumber="70",
        country="USA",
    ),
    "Hynes Athletic Center, New Rochelle, New York": HYNES_ATHELTIC_CENTER,
    "The Sandy and John Black Pavilion at Ole Miss, Oxford, Mississippi": OLE_MISS,
    "Moscow, Idaho": SportsballGeocodeTuple(
        city="Moscow",
        state="ID",
        postal="",
        lat=46.741667,
        lng=-117.0,
        housenumber="",
        country="USA",
    ),
    "Ocean Bank Convocation Center, Miami, Florida": OCEAN_BANK_CONVOCATION_CENTER,
    "Island Federal Credit Union Arena, Stony Brook, New York": STONY_BROOK_ARENA,
    "Phoenix, Arizona": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="",
        lat=33.448333,
        lng=-112.073889,
        housenumber="",
        country="USA",
    ),
    "Evansville, Indiana": SportsballGeocodeTuple(
        city="Evansville",
        state="IN",
        postal="",
        lat=37.977222,
        lng=-87.550556,
        housenumber="",
        country="USA",
    ),
    "America First Event Center, Cedar City, Utah": SportsballGeocodeTuple(
        city="Cedar City",
        state="UT",
        postal="84720",
        lat=37.675556,
        lng=-113.073056,
        housenumber="351",
        country="USA",
    ),
    "St. Paul, Minnesota": SportsballGeocodeTuple(
        city="St. Paul",
        state="MN",
        postal="",
        lat=44.947778,
        lng=-93.103889,
        housenumber="",
        country="USA",
    ),
    "Jenny Craig Pavilion, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.7745,
        lng=-117.1837,
        housenumber="5998",
        country="USA",
    ),
    "George M. Holmes Convocation Center, Boone, North Carolina": HOLMES_CENTER,
    "Farris Center, Conway, Arkansas": FARRIS_CENTER,
    "HTC Center, Conway, South Carolina": HTC_CENTER,
    "Atlanta, Georgia": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="",
        lat=33.748889,
        lng=-84.39,
        housenumber="",
        country="USA",
    ),
    "UNF Arena, Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32224",
        lat=30.2734,
        lng=-81.5079,
        housenumber="11852",
        country="USA",
    ),
    "Strahan Arena, San Marcos, Texas": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="78666",
        lat=29.888611,
        lng=-97.932778,
        housenumber="601",
        country="USA",
    ),
    "Wellness and Events Center, Newark, New Jersey": WELLNESS_AND_EVENTS_CENTER,
    "Gersten Pavilion, Los Angeles, California": GERSTEN_PAVILION,
    "Rothman Center, Teaneck, New Jersey": BOGOTA_SAVINGS_BANK_CENTER,
    "Corbett Sports Center, Greensboro, North Carolina": CORBETT_SPORTS_CENTER,
    "Easton, Massachusetts": SportsballGeocodeTuple(
        city="Easton",
        state="MA",
        postal="",
        lat=42.024444,
        lng=-71.129167,
        housenumber="",
        country="USA",
    ),
    "University Credit Union Center, Davis, California": SportsballGeocodeTuple(
        city="Davis",
        state="CA",
        postal="95616",
        lat=38.541667,
        lng=-121.759444,
        housenumber="1",
        country="USA",
    ),
    "Buccaneer Field House, Charleston, South Carolina": BUCCANEER_FIELDHOUSE,
    "Credit Union 1 Arena, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60607",
        lat=41.874722,
        lng=-87.656111,
        housenumber="525",
        country="USA",
    ),
    "E. A. Diddle Arena, Bowling Green, Kentucky": EA_DIDDLE_ARENA,
    "JMA Wireless Dome, Syracuse, New York": JMA_WIRELESS_DOME,
    "Truist Arena, Highland Heights, Kentucky": TRUIST_ARENA,
    "Kress Events Center, Green Bay, Wisconsin": SportsballGeocodeTuple(
        city="Green Bay",
        state="WI",
        postal="",
        lat=44.530069,
        lng=-87.915967,
        housenumber="",
        country="USA",
    ),
    "OceanFirst Bank Center, West Long Branch, New Jersey": SportsballGeocodeTuple(
        city="West Long Branch",
        state="NJ",
        postal="07764",
        lat=40.279475,
        lng=-74.007583,
        housenumber="400",
        country="USA",
    ),
    "Alex G. Spanos Center, Stockton, California": AG_SPANOS_CENTER,
    "War Memorial Gymnasium, San Francisco, California": WAR_MEMORIAL_GYMNASIUM,
    "First National Bank Arena, Jonesboro, Arkansas": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AR",
        postal="72401",
        lat=35.845422,
        lng=-90.670319,
        housenumber="217",
        country="USA",
    ),
    "Frost Arena, Brookings, South Dakota": SportsballGeocodeTuple(
        city="Brookings",
        state="SD",
        postal="57007",
        lat=44.317984,
        lng=-96.779058,
        housenumber="1165",
        country="USA",
    ),
    "Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KT",
        postal="",
        lat=38.256111,
        lng=-85.751389,
        housenumber="",
        country="USA",
    ),
    "Saint Charles, Missouri": SportsballGeocodeTuple(
        city="Saint Charles",
        state="MO",
        postal="",
        lat=38.789,
        lng=-90.514,
        housenumber="",
        country="USA",
    ),
    "Cam Henderson Center, Huntington, West Virginia": HENDERSON_CENTER,
    "Ted Constant Convocaation Center, Norfolk, Virginia": TED_CONSTANT_CONVOCATION_CENTER,
    "Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.65,
        lng=-73.95,
        housenumber="",
        country="USA",
    ),
    "Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="",
        lat=41.881944,
        lng=-87.627778,
        housenumber="",
        country="USA",
    ),
    "Alabama A&M Events Center, Huntsville, Alabama": SportsballGeocodeTuple(
        city="Huntsville",
        state="AL",
        postal="35810",
        lat=34.781139,
        lng=-86.580528,
        housenumber="",
        country="USA",
    ),
    "Vadalabene Center, Edwardsville, Illinois": SportsballGeocodeTuple(
        city="Edwardsville",
        state="IL",
        postal="",
        lat=38.795989,
        lng=-89.999883,
        housenumber="35",
        country="USA",
    ),
    "Corpus Christi, Texas": SportsballGeocodeTuple(
        city="Corpus Christi",
        state="TX",
        postal="",
        lat=27.742778,
        lng=-97.401944,
        housenumber="",
        country="USA",
    ),
    "Island Federal Credit Union Arena, New York, NY, USA": STONY_BROOK_ARENA,
    "Subiaco Oval, Perth, Australia": DOMAIN_STADIUM,
    "University of Tasmania Stadium, Launceston, Australia": UTAS_STADIUM,
    "Mars Stadium, Ballarat, Australia": MARS_STADIUM,
    "Savannah, Georgia": SportsballGeocodeTuple(
        city="Savannah",
        state="GA",
        postal="",
        lat=32.081111,
        lng=-81.091111,
        housenumber="",
        country="USA",
    ),
    "Blundstone Arena, Hobart, Australia": BLUNDSTONE_ARENA,
    "Akron, Ohio": SportsballGeocodeTuple(
        city="Akron",
        state="OH",
        postal="",
        lat=41.080556,
        lng=-81.522222,
        housenumber="",
        country="USA",
    ),
    "Michelob Ultra Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.090678,
        lng=-115.178981,
        housenumber="3950",
        country="USA",
    ),
    "Sioux Falls, South Dakota": SportsballGeocodeTuple(
        city="Sioux Falls",
        state="SD",
        postal="",
        lat=43.536389,
        lng=-96.731667,
        housenumber="",
        country="USA",
    ),
    "TIO Traeger Park, Alice Springs, Australia": TIO_STADIUM,
    "Springfield, Massachusetts": SportsballGeocodeTuple(
        city="Springfield",
        state="MA",
        postal="",
        lat=42.101389,
        lng=-72.590278,
        housenumber="",
        country="USA",
    ),
    "Elmont, New York": SportsballGeocodeTuple(
        city="Elmont",
        state="NY",
        postal="",
        lat=40.701667,
        lng=-73.7025,
        housenumber="",
        country="USA",
    ),
    "Manuka Oval, Canberra, Australia": MANUKA_OVAL,
    "Tulsa, Oklahoma": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="",
        lat=36.131389,
        lng=-95.937222,
        housenumber="",
        country="USA",
    ),
    "Sunrise, Florida": SportsballGeocodeTuple(
        city="Sunrise",
        state="FL",
        postal="",
        lat=26.157222,
        lng=-80.286111,
        housenumber="",
        country="USA",
    ),
    "Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.081944,
        lng=-115.124722,
        housenumber="",
        country="USA",
    ),
    "Niceville, Florida": SportsballGeocodeTuple(
        city="Niceville",
        state="FL",
        postal="",
        lat=30.516111,
        lng=-86.471667,
        housenumber="",
        country="USA",
    ),
    "Jiangwan Stadium, Shanghai, China": JIANGWAN_STADIUM,
    "Ondrej Nepela Arena, Bratislava, Slovakia": SportsballGeocodeTuple(
        city="Bratislava",
        state="",
        postal="",
        lat=48.16,
        lng=17.135833,
        housenumber="9",
        country="Slovakia",
    ),
    "Cazaly's Stadium, Cairns, Australia": CAZALYS_STADIUM,
    "San Juan Capistrano, California": SportsballGeocodeTuple(
        city="San Juan Capistrano",
        state="CA",
        postal="",
        lat=33.499444,
        lng=-117.661667,
        housenumber="",
        country="USA",
    ),
    "Giants Stadium, East Rutherford, NJ, USA": METLIFE_STADIUM,
    "TIO Stadium, Darwin, Australia": TIO_STADIUM,
    "Fort Myers, Florida": SportsballGeocodeTuple(
        city="Fort Myers",
        state="FL",
        postal="",
        lat=26.616667,
        lng=-81.833333,
        housenumber="",
        country="USA",
    ),
    "Thunderdome Stadium, Nonthaburi, Thailand": SportsballGeocodeTuple(
        city="Nonthaburi",
        state="",
        postal="",
        lat=13.917989,
        lng=100.547411,
        housenumber="",
        country="Thailand",
    ),
    "Norwood Oval, Norwood, Australia": NORWOOD_OVAL,
    "Angel Stadium of Anaheim, Anaheim, CA, USA": SportsballGeocodeTuple(
        city="Anaheim",
        state="CA",
        postal="",
        lat=33.800278,
        lng=-117.882778,
        housenumber="2000",
        country="USA",
    ),
    "Riverway Stadium, Townsville, Australia": RIVERWAY_STADIUM,
    "Adelaide Hills, Mount Barker, Australia": ADELAIDE_HILLS,
    "Marrara Oval, Darwin, Australia": TIO_STADIUM,
    "Accor Stadium, Sydney, Australia": ENGIE_STADIUM,
    "Spotland Stadium, Rochdale, England": SportsballGeocodeTuple(
        city="Rochdale",
        state="",
        postal="OL11 5DR",
        lat=53.620833,
        lng=-2.18,
        housenumber="",
        country="UK",
    ),
    "TD Garden, Boston, MA, USA": TD_GARDEN,
    "Spectrum Center, Charlotte, NC, USA": SPECTRUM_CENTRE,
    "Capital One Arena, Washington, DC, USA": CAPITAL_ONE_ARENA,
    "State Farm Arena, Atlanta, GA, USA": STATE_FARM_ARENA,
    "Barclays Center, New York, NY, USA": BARCLAYS_CENTER,
    "Little Caesars Arena, Detroit, MI, USA": LITTLE_CAESARS_ARENA,
    "Paycom Center, Oklahoma, OK, USA": PAYCOM_CENTRE,
    "Footprint Center, Phoenix, AZ, USA": AMERICA_WEST_ARENA,
    "American Airlines Center, Dallas, TX, USA": AMERICAN_AIRLINES_ARENA,
    "Crypto.com Arena, Los Angeles, CA, USA": STAPLES_CENTRE,
    "Kia Center, Orlando, FL, USA": KIA_CENTER,
    "United Center, Chicago, IL, USA": UNITED_CENTER,
    "FedExForum, Memphis, TN, USA": FEDEX_FORUM,
    "Target Center, Minneapolis, MN, USA": TARGET_CENTER,
    "Madison Square Garden, New York, NY, USA": MADISON_SQUARE_GARDEN,
    "Golden 1 Center, Sacramento, CA, USA": GOLDEN_1_CENTER,
    "Intuit Dome, Inglewood, CA, USA": INTUIT_DOME,
    "Smoothie King Center, New Orleans, LA, USA": CAESARS_SUPERDOME,
    "Moda Center, Portland, OR, USA": MODA_CENTER,
    "Ball Arena, Denver, CO, USA": PEPSI_CENTRE,
    "Delta Center, Salt Lake City, UT, USA": DELTA_CENTER,
    "Toyota Center, Houston, TX, USA": TOYOTA_CENTRE,
    "Fiserv Forum, Milwaukee, WI, USA": FISERV_FORUM,
    "Wells Fargo Center, Philadelphia, PA, USA": SPECTRUM,
    "Scotiabank Arena, Toronto, ON, Canada": SCOTIABANK_ARENA,
    "Rocket Mortgage FieldHouse, Cleveland, OH, USA": ROCKET_MORTGAGE_FIELDHOUSE,
    "Chase Center, San Francisco, CA, USA": CHASE_CENTER,
    "Frost Bank Center, San Antonio, TX, USA": FROST_BANK_CENTER,
    "Gainbridge Fieldhouse, Indianapolis, IN, USA": GAINBRIDGE_FIELDHOUSE,
    "Kaseya Center, Miami, FL, USA": KASEYA_CENTER,
    "Accor Arena, Paris, France": ACCOR_ARENA,
    "ARCO Arena, Sacramento, CA, USA": ARCO_ARENA,
    "AdventHealth Arena, Orlando, FL, USA": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Oracle Arena, Oakland, CA, USA": OAKLAND_ARENA,
    "Intuit Dome - Inglewood, California, U.S. - United States": INTUIT_DOME,
    "Rogers Arena - Vancouver, BC - Canada": ROGERS_ARENA,
    "Rocket Mortgage FieldHouse - Cleveland, Ohio - United States": ROCKET_MORTGAGE_FIELDHOUSE,
    "Paycom Center - Oklahoma City, Oklahoma - United States": PAYCOM_CENTRE,
    "Spectrum Center - Charlotte, North Carolina - United States": SPECTRUM_CENTRE,
    "Little Caesars Arena - Detroit, Michigan - United States": LITTLE_CAESARS_ARENA,
    "Stan Sheriff Center - Honolulu, Hawaii - United States": STAN_SHERIFF_CENTER,
    "Kia Center - Orlando, Florida - United States": KIA_CENTER,
    "Scotiabank Arena - Toronto, Ontario - Canada": SCOTIABANK_ARENA,
    "Climate Pledge Arena - Seattle, Washington - United States": CLIMATE_PLEDGE_ARENA,
    "Wells Fargo Center - Philadelphia, PA - United States": SPECTRUM,
    "State Farm Arena - Atlanta, Georgia - United States": STATE_FARM_ARENA,
    "Bell Centre": SportsballGeocodeTuple(
        city="Montreal",
        state="QC",
        postal="",
        lat=45.496111,
        lng=-73.569444,
        housenumber="1909",
        country="CA",
    ),
    "Footprint Center - Phoenix, Arizona - United States": AMERICA_WEST_ARENA,
    "Smoothie King Center - New Orleans, Louisiana, USA - United States": CAESARS_SUPERDOME,
    "Kaseya Center - Miami, Florida - United States": KASEYA_CENTER,
    "Frost Bank Center - San Antonio, Texas - United States": FROST_BANK_CENTER,
    "Moda Center - Portland, Oregon - United States": MODA_CENTER,
    "BOK Center - Tulsa, Oklahoma - United States": BOK_CENTER,
    "Capital One Arena - Washington DC, USA - United States": CAPITAL_ONE_ARENA,
    "The Palace of Auburn Hills, Auburn Hills, MI, USA": THE_PALACE_OF_AUBURN_HILLS,
    "BMO Harris Bradley Center, Milwaukee, WI, USA": BRADLEY_CENTER,
    "State Farm Field House, Orlando, FL, USA": STATE_FARM_FIELDHOUSE,
    "Panjin Jinxiu Stadium, Panjin, China": SportsballGeocodeTuple(
        city="Panjin",
        state="",
        postal="",
        lat=41.110278,
        lng=122.071667,
        housenumber="",
        country="China",
    ),
    "Oriole Park at Camden Yards, Baltimore, MD, USA": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.2838194,
        lng=-76.6242531,
        housenumber="",
        country="USA",
    ),
    "ESPN Wide World of Sports Complex, Bay Lake, FL, USA": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Amalie Arena, Tampa, FL, USA": AMALIE_ARENA,
    "Toyota Stadium, Frisco, TX, USA": TOYOTA_STADIUM,
    "Visa Athletic Center, Orlando, FL, USA": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "The Arena (WWOS), Orlando, FL, USA": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "PayPal Park, San Jose, CA, USA": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="",
        lat=37.351389,
        lng=-121.925,
        housenumber="1123",
        country="USA",
    ),
    "Moody Center, Austin, TX, USA": MOODY_CENTER,
    "Robert F. Kennedy Memorial Stadium, Washington, DC, USA": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.89,
        lng=-76.972,
        housenumber="2400",
        country="USA",
    ),
    "West Hartford, Connecticut": SportsballGeocodeTuple(
        city="West Hartford",
        state="CT",
        postal="",
        lat=41.767778,
        lng=-72.753889,
        housenumber="",
        country="USA",
    ),
    "Verizon Center, Washington, District of Columbia": CAPITAL_ONE_ARENA,
    "The Palace of Auburn Hills, Auburn Hills, Michigan": THE_PALACE_OF_AUBURN_HILLS,
    "Wells Fargo Arena, Des Moines, Iowa": SportsballGeocodeTuple(
        city="Des Moines",
        state="IO",
        postal="",
        lat=41.592667,
        lng=-93.621139,
        housenumber="233",
        country="USA",
    ),
    "Lake Buena Vista, Florida": SportsballGeocodeTuple(
        city="Lake Buena Vista",
        state="FL",
        postal="",
        lat=28.3775,
        lng=-81.526111,
        housenumber="",
        country="USA",
    ),
    "Place Bell, Laval": SportsballGeocodeTuple(
        city="Laval",
        state="QC",
        postal="",
        lat=45.5558,
        lng=-73.7218,
        housenumber="1950",
        country="CA",
    ),
    "Estero, Florida": SportsballGeocodeTuple(
        city="Estero",
        state="FL",
        postal="",
        lat=26.427778,
        lng=-81.795,
        housenumber="",
        country="USA",
    ),
    "McDonough Field House, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="",
        lat=42.6970529,
        lng=-73.6817757,
        housenumber="",
        country="USA",
    ),
    "Uncasville, Connecticut": SportsballGeocodeTuple(
        city="Uncasville",
        state="CT",
        postal="",
        lat=41.434542,
        lng=-72.109799,
        housenumber="",
        country="USA",
    ),
    "Sacramento, California": SportsballGeocodeTuple(
        city="Sacramento",
        state="CA",
        postal="",
        lat=38.581667,
        lng=-121.494444,
        housenumber="",
        country="USA",
    ),
    "Jersey Mike''s Arena, New Brunswick, New Jersey": JERSEY_MIKES_ARENA,
    "Ford Center at the Star, Frisco, Texas": FORD_CENTER_AT_THE_STAR,
    "Willett Hall, Farmville, Virginia": SportsballGeocodeTuple(
        city="Farmville",
        state="VA",
        postal="",
        lat=37.2975,
        lng=-78.3955,
        housenumber="23909",
        country="USA",
    ),
    "Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.768611,
        lng=-86.158056,
        housenumber="",
        country="USA",
    ),
    "Milwaukee, Wisconsin": SportsballGeocodeTuple(
        city="Milwaukee",
        state="WI",
        postal="",
        lat=43.05,
        lng=-87.95,
        housenumber="",
        country="USA",
    ),
    "GSU Sports Arena, Atlanta, Georgia": GSU_CONVOCATION_CENTER,
    "High Point, North Carolina": SportsballGeocodeTuple(
        city="High Point",
        state="NC",
        postal="",
        lat=35.991111,
        lng=-79.993611,
        housenumber="",
        country="USA",
    ),
    "Winfield Dunn Center, Clarksville, Tennessee": SportsballGeocodeTuple(
        city="Clarksville",
        state="TN",
        postal="",
        lat=36.536111,
        lng=-87.356944,
        housenumber="",
        country="USA",
    ),
    "Harry A. Campel Pavilion, Storrs, Connecticut": SportsballGeocodeTuple(
        city="Storrs",
        state="CT",
        postal="06269",
        lat=41.805292,
        lng=-72.254194,
        housenumber="2095",
        country="USA",
    ),
    "Santa Cruz, California": SportsballGeocodeTuple(
        city="Santa Cruz",
        state="CA",
        postal="",
        lat=36.971944,
        lng=-122.026389,
        housenumber="",
        country="USA",
    ),
    "South Padre Island, Texas": SportsballGeocodeTuple(
        city="South Padre Island",
        state="TX",
        postal="",
        lat=26.111944,
        lng=-97.169722,
        housenumber="",
        country="USA",
    ),
    "Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.762778,
        lng=-95.383056,
        housenumber="",
        country="USA",
    ),
    "Wichita, Kansas": SportsballGeocodeTuple(
        city="Wichita",
        state="KS",
        postal="",
        lat=29.762778,
        lng=-95.383056,
        housenumber="",
        country="USA",
    ),
    "Jackson, Mississippi": SportsballGeocodeTuple(
        city="Jackson",
        state="MS",
        postal="",
        lat=29.762778,
        lng=-95.383056,
        housenumber="",
        country="USA",
    ),
    "Union, New Jersey": SportsballGeocodeTuple(
        city="Union",
        state="NJ",
        postal="",
        lat=40.695266,
        lng=-74.269078,
        housenumber="",
        country="USA",
    ),
    "Lucas Oil Stadium, Indianapolis, IN, USA": LUCAS_OIL_STADIUM,
    "NRG Stadium, Houston, TX, USA": NRG_STADIUM,
    "State Farm Stadium, Glendale, AZ, USA": STATE_FARM_STADIUM,
    "Caesars Superdome, New Orleans, LA, USA": CAESARS_SUPERDOME,
    "U.S. Bank Stadium, Minneapolis, MN, USA": US_BANK_STADIUM,
    "Time Warner Cable Arena, Charlotte, North Carolina": SPECTRUM_CENTRE,
    "The O2 Arena, London": O2_ARENA,
    "People's United Center, Hamden, Connecticut": SportsballGeocodeTuple(
        city="Hamden",
        state="CT",
        postal="06518",
        lat=41.413833,
        lng=-72.911157,
        housenumber="305",
        country="USA",
    ),
    "Taylorsville, Utah": SportsballGeocodeTuple(
        city="Taylorsville",
        state="UT",
        postal="",
        lat=40.655,
        lng=-111.949444,
        housenumber="",
        country="USA",
    ),
    "Flagstaff, Arizona": SportsballGeocodeTuple(
        city="Flagstaff",
        state="AZ",
        postal="",
        lat=35.180556,
        lng=-111.62,
        housenumber="",
        country="USA",
    ),
    "Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.52,
        lng=-122.681944,
        housenumber="",
        country="USA",
    ),
    "Laie, Hawaii": SportsballGeocodeTuple(
        city="Laie",
        state="HI",
        postal="",
        lat=21.648611,
        lng=-157.925556,
        housenumber="",
        country="USA",
    ),
    "Copper Box Arena, London": SportsballGeocodeTuple(
        city="London",
        state="",
        postal="",
        lat=51.5444,
        lng=-0.0201,
        housenumber="",
        country="UK",
    ),
    "Imperial Arena at Atlantis Resort, Paradise Island": IMPERIAL_ARENA,
    "Anaheim, California": SportsballGeocodeTuple(
        city="Anaheim",
        state="CA",
        postal="",
        lat=33.836111,
        lng=-117.889722,
        housenumber="",
        country="USA",
    ),
    "Lahaina, Hawaii": SportsballGeocodeTuple(
        city="Lahaina",
        state="HI",
        postal="",
        lat=20.873889,
        lng=-156.6775,
        housenumber="",
        country="USA",
    ),
    "Edinburg, Texas": SportsballGeocodeTuple(
        city="Edinburg",
        state="TX",
        postal="",
        lat=26.304167,
        lng=-98.163889,
        housenumber="",
        country="USA",
    ),
    "Spokane, Washington": SportsballGeocodeTuple(
        city="Spokane",
        state="WA",
        postal="",
        lat=47.658889,
        lng=-117.425,
        housenumber="",
        country="USA",
    ),
    "Montego Bay Convention Centre, Montego Bay": SportsballGeocodeTuple(
        city="Montego Bay",
        state="",
        postal="",
        lat=18.5198974,
        lng=-77.8204727,
        housenumber="",
        country="Jamaica",
    ),
    "National Basketball Arena, South Dublin": SportsballGeocodeTuple(
        city="South Dublin",
        state="",
        postal="",
        lat=53.292222,
        lng=-6.334444,
        housenumber="",
        country="Ireland",
    ),
    "Generoso Pope Athletic Complex, Brooklyn Heights, New York": GENEROSO_POPE_ATHELTIC_COMPLEX,
    "Youngstown, Ohio": SportsballGeocodeTuple(
        city="Youngstown",
        state="OH",
        postal="",
        lat=41.1,
        lng=-80.65,
        housenumber="",
        country="USA",
    ),
    "Kansas City, Kansas": SportsballGeocodeTuple(
        city="Kansas City",
        state="KS",
        postal="",
        lat=39.106667,
        lng=-94.676389,
        housenumber="",
        country="USA",
    ),
    "San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.715,
        lng=-117.1625,
        housenumber="",
        country="USA",
    ),
    "Sleep Train Arena, Sacramento, California": ARCO_ARENA,
    "CONSOL Energy Center, Pittsburgh, Pennsylvania": PPG_PAINTS_ARENA,
    "UNT Coliseum, Denton, Texas": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="76201",
        lat=33.208333,
        lng=-97.153889,
        housenumber="801",
        country="USA",
    ),
    "The Center, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.952,
        lng=-75.164,
        housenumber="",
        country="USA",
    ),
    "Grand Canyon University Arena, Phoenix, Arizona": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="85017",
        lat=33.510152,
        lng=-112.128884,
        housenumber="3300",
        country="USA",
    ),
    "Wolstein Center, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.499167,
        lng=-81.676944,
        housenumber="2000",
        country="USA",
    ),
    "Elmore Gymnasium, Normal, Alabama": ELMORE_GYMNASIUM,
    "Teague Special Events Center, Abilene, Texas": SportsballGeocodeTuple(
        city="Abilene",
        state="TX",
        postal="79601",
        lat=32.4712266,
        lng=-99.7083714,
        housenumber="1600",
        country="USA",
    ),
    "BB&T Arena, Highland Heights, Kentucky": TRUIST_ARENA,
    "Webster Bank Arena, Bridgeport, Connecticut": SportsballGeocodeTuple(
        city="Bridgeport",
        state="CT",
        postal="79601",
        lat=41.1732,
        lng=-73.187,
        housenumber="600",
        country="USA",
    ),
    "Scottrade Center, St. Louis, Missouri": ENTERPRISE_CENTER,
    "U.S. Cellular Center, Asheville, North Carolina": HARRAHS_CHEROKEE_CENTER,
    "Entertainment & Sports Arena, Washington, District of Columbia": CAREFIRST_ARENA,
    "St. Elizabeths East Entertainment & Sports Arena, Washington, District of Columbia": CAREFIRST_ARENA,
    "Ford Center at The Star, Frisco, Texas": FORD_CENTER_AT_THE_STAR,
    "Rocket Mortgage FieldHouse, Cleveland, Ohio": ROCKET_MORTGAGE_FIELDHOUSE,
    "Boardwalk Hall, Atlantic City, New Jersey": SportsballGeocodeTuple(
        city="Atlantic City",
        state="NJ",
        postal="",
        lat=39.355,
        lng=-74.438611,
        housenumber="2301",
        country="USA",
    ),
    "Norfolk Scope, Norfolk, Virginia": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23510",
        lat=36.853275,
        lng=-76.286722,
        housenumber="201",
        country="USA",
    ),
    "Beasley Coliseum, Pullman, Washington": BEASLEY_COLISEUM,
    "KeyBank Center, Buffalo, New York": KEYBANK_CENTER,
    "Times Union Center , Albany, New York": TIMES_UNION_CENTER,
    "Dunkin Donuts Center, Providence, Rhode Island": DUNKIN_DONUTS_CENTER,
    "CenturyLink Center Omaha, Omaha, Nebraska": CHI_HEALTH_CENTER,
    "Ryan Center, Kingston, Rhode Island": RYAN_CENTER,
    "Pope Physical Education Center, Brooklyn Heights, New York": GENEROSO_POPE_ATHELTIC_COMPLEX,
    "Eastwood High School Gym, El Paso, Texas": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="",
        lat=31.7718,
        lng=-106.3547,
        housenumber="2430",
        country="USA",
    ),
    "Millis Center, High Point, North Carolina": SportsballGeocodeTuple(
        city="High Point",
        state="NC",
        postal="27262",
        lat=35.973456,
        lng=-79.995706,
        housenumber="922",
        country="USA",
    ),
    "George Bisacca Court at Alumni Hall, Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="",
        lat=41.159854,
        lng=-73.256646,
        housenumber="",
        country="USA",
    ),
    "Life University Gym, Marietta, Georgia": SportsballGeocodeTuple(
        city="Marietta",
        state="GA",
        postal="30062",
        lat=33.9313785,
        lng=-84.5223277,
        housenumber="1269",
        country="USA",
    ),
    "Robert A. Mott Gymnasium, San Luis Obispo, California": ROBERT_A_MOTT_GYMNASIUM,
    "John J. Moore Athletic Center, Jersey City, New Jersey": SportsballGeocodeTuple(
        city="Jersey City",
        state="NJ",
        postal="07305",
        lat=40.7129524,
        lng=-74.0891177,
        housenumber="110",
        country="USA",
    ),
    "Cowan Spectrum, Moscow, Idaho": KIBBIE_DOME,
    "Elmore Health Science Building , Normal, Alabama": ELMORE_GYMNASIUM,
    "McDonough Gymnasium, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="20057",
        lat=38.9075,
        lng=-77.0775,
        housenumber="",
        country="USA",
    ),
    "M.O. Campbell Center, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77032",
        lat=29.932222,
        lng=-95.359722,
        housenumber="1865",
        country="USA",
    ),
    "Alumni Recreation Center, Loudonville, New York": SportsballGeocodeTuple(
        city="Loudonville",
        state="NY",
        postal="12211",
        lat=42.7174,
        lng=-73.7487,
        housenumber="515",
        country="USA",
    ),
    "Max Worthington Arena, Bozeman, Montana": SportsballGeocodeTuple(
        city="Bozeman",
        state="MT",
        postal="",
        lat=45.6633,
        lng=-111.0506,
        housenumber="1",
        country="USA",
    ),
    "Alumni Hall (RI), Providence, Rhode Island": ALUMNI_HALL,
    "Michelob Ulta Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.090678,
        lng=-115.178981,
        housenumber="3950",
        country="USA",
    ),
    "Leonard E. Merrell Center, Katy, Texas": MERRELL_CENTER,
    "Bridgestone Arena, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.159167,
        lng=-86.778611,
        housenumber="501",
        country="USA",
    ),
    "Comerica, Frisco, Texas": SportsballGeocodeTuple(
        city="Frisco",
        state="TX",
        postal="",
        lat=33.101026,
        lng=-96.819624,
        housenumber="2601",
        country="USA",
    ),
    "Lucas Oil Stadium, Indianapolis, Indiana": LUCAS_OIL_STADIUM,
    "Connolly Center, Seattle, Washington": REDHAWK_CENTER,
    "Chase Family Arena, Hartford, Connecticut": CHASE_FAMILY_ARENA,
    "Virgin Islands Sport & Fitness Center , St. Thomas": VIRGIN_ISLANDS_SPORT_AND_FITNESS_CENTER,
    "Virgin Islands Sport & Fitness Center, St. Thomas": VIRGIN_ISLANDS_SPORT_AND_FITNESS_CENTER,
    "McArthur Gymnasium, St. Petersburg, Florida": SportsballGeocodeTuple(
        city="St. Petersburg",
        state="FL",
        postal="",
        lat=27.717097,
        lng=-82.688406,
        housenumber="",
        country="USA",
    ),
    "St. Petersburg, Florida": SportsballGeocodeTuple(
        city="St. Petersburg",
        state="FL",
        postal="",
        lat=27.773056,
        lng=-82.64,
        housenumber="",
        country="USA",
    ),
    "Anaheim Convention Center, Anaheim, California": ANAHEIM_CONVENTION_CENTER,
    "CenturyLink Center, Omaha, Nebraska": CHI_HEALTH_CENTER,
    "Hawkins Arena, Macon, Georgia": SportsballGeocodeTuple(
        city="Macon",
        state="GA",
        postal="31207",
        lat=32.829722,
        lng=-83.651944,
        housenumber="1730",
        country="USA",
    ),
    "Frank Erwin Center, Austin, Texas": SportsballGeocodeTuple(
        city="Austin",
        state="TX",
        postal="",
        lat=30.277,
        lng=-97.7322,
        housenumber="1701",
        country="USA",
    ),
    "BankUnited Center, Coral Gables, Florida": WATSO_CENTER,
    "Binghamton University Events Center, Vestal, New York": BINGHAMPTON_UNIVERSITY_EVENTS_CENTER,
    "US Airways Center, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "EnergySolutions Arena, Salt Lake City, Utah": DELTA_CENTER,
    "Kaiser Permanente Arena, Santa Cruz, California": SportsballGeocodeTuple(
        city="Santa Cruz",
        state="CA",
        postal="",
        lat=36.968611,
        lng=-122.023611,
        housenumber="",
        country="USA",
    ),
    "Rip Griffin Center, Lubbock, Texas": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="",
        lat=33.57186,
        lng=-101.93188,
        housenumber="",
        country="USA",
    ),
    "Hampton Convocation Center, Hampton, Virginia": HAMPTON_CONVOCATION_CENTER,
    "Ability360 Sports & Fitness Center, Phoenix, Arizona": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="85034",
        lat=33.4451355,
        lng=-111.9737363,
        housenumber="5031",
        country="USA",
    ),
    "Lawrence Joel Veterans Memorial Coliseum, Winston-Salem, North Carolina": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="27105",
        lat=36.127866,
        lng=-80.257628,
        housenumber="2825",
        country="USA",
    ),
    "Indiana Convention Center, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.765278,
        lng=-86.1625,
        housenumber="100",
        country="USA",
    ),
    "Cabot Center Gym, Boston, Massachusetts": CABOT_CENTER,
    "Holt Arena, Pocatello, Idaho": ICCU_ARENA,
    "Sun Dome, Tampa, Florida": YUENGLING_CENTER,
    "Covelli Centre, Youngstown, Ohio": SportsballGeocodeTuple(
        city="Youngstown",
        state="OH",
        postal="44503",
        lat=41.096145,
        lng=-80.647943,
        housenumber="229",
        country="USA",
    ),
    "Burton Coliseum, Lake Charles, Louisiana": SportsballGeocodeTuple(
        city="Lake Charles",
        state="LA",
        postal="70607",
        lat=30.136989,
        lng=-93.211476,
        housenumber="7001",
        country="USA",
    ),
    "Bert Ogden Arena, Edinburg, Texas": SportsballGeocodeTuple(
        city="Edinburg",
        state="TX",
        postal="78539",
        lat=26.256568,
        lng=-98.164631,
        housenumber="4900",
        country="USA",
    ),
    "Reynolds Coliseum, Raleigh, North Carolina": REYNOLDS_COLISEUM,
    "Walter E. Washington Convention Center, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.9051,
        lng=-77.023,
        housenumber="801",
        country="USA",
    ),
    "Germain Arena, Estero, Florida": HERTZ_ARENA,
    "Mabee Fieldhouse, Kansas City, Kansas": SportsballGeocodeTuple(
        city="Kansas City",
        state="KS",
        postal="64145",
        lat=38.911069,
        lng=-94.5921775,
        housenumber="11901",
        country="USA",
    ),
    "CenturyLink Arena, Boise, Idaho": IDAHO_CENTRAL_ARENA,
    "Lynchburg, Virginia": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="",
        lat=37.403611,
        lng=-79.17,
        housenumber="",
        country="USA",
    ),
    "New Orleans Arena, New Orleans, Louisiana": CAESARS_SUPERDOME,
    "Lowell, Massachusetts": SportsballGeocodeTuple(
        city="Lowell",
        state="MA",
        postal="",
        lat=42.639444,
        lng=-71.314722,
        housenumber="",
        country="USA",
    ),
    "Swinney Recreation Center, Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="64110",
        lat=39.03555,
        lng=-94.57876,
        housenumber="5030",
        country="USA",
    ),
    "Chase Family Arena at Reich Family Pavilion, Hartford, Connecticut": CHASE_FAMILY_ARENA,
    "Rose Garden Arena, Portland, Oregon": ROSE_GARDEN,
    "JMU Convocation Center, Harrisonburg, Virginia": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="",
        lat=38.431892,
        lng=-78.868854,
        housenumber="",
        country="USA",
    ),
    "Denver, Colorado": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="",
        lat=39.7392,
        lng=-104.9849,
        housenumber="",
        country="USA",
    ),
    "Wells Fargo Arena, Tempe, Arizona": DESERT_FINANCIAL_ARENA,
    "Times Union Center, Albany, New York": TIMES_UNION_CENTER,
    "Louis Brown Athletic Center, New Brunswick, New Jersey": JERSEY_MIKES_ARENA,
    "Carmichael Arena, Chapel Hill, North Carolina": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="27599",
        lat=35.909526,
        lng=-79.045408,
        housenumber="310",
        country="USA",
    ),
    "Harrisonburg, Virginia": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="",
        lat=38.449444,
        lng=-78.868889,
        housenumber="",
        country="USA",
    ),
    "76ers Fieldhouse, Wilmington, Delaware": SportsballGeocodeTuple(
        city="Wilmington",
        state="DE",
        postal="",
        lat=39.727582,
        lng=-75.554497,
        housenumber="401",
        country="USA",
    ),
    "Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="",
        lat=40.439722,
        lng=-79.976389,
        housenumber="",
        country="USA",
    ),
    "Prescott Valley, Arizona": SportsballGeocodeTuple(
        city="Prescott Valley",
        state="AZ",
        postal="",
        lat=34.61,
        lng=-112.315833,
        housenumber="",
        country="USA",
    ),
    "Vines Center, Lynchburg, Virginia": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="24502",
        lat=37.349068,
        lng=-79.180998,
        housenumber="1971",
        country="USA",
    ),
    "HP Field House, Orlando, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Tsongas Center, Lowell, Massachusetts": SportsballGeocodeTuple(
        city="Lowell",
        state="MA",
        postal="",
        lat=42.650228,
        lng=-71.313248,
        housenumber="300",
        country="USA",
    ),
    "The Arena, Niceville, Florida": SportsballGeocodeTuple(
        city="Niceville",
        state="FL",
        postal="",
        lat=30.5394,
        lng=-86.4756,
        housenumber="300",
        country="USA",
    ),
    "Las Vegas, Nevada": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="",
        lat=36.167222,
        lng=-115.148611,
        housenumber="",
        country="USA",
    ),
    "Fort Wayne, Indiana": SportsballGeocodeTuple(
        city="Fort Wayne",
        state="IN",
        postal="",
        lat=41.088889,
        lng=-85.161389,
        housenumber="",
        country="USA",
    ),
    "Portland, Maine": SportsballGeocodeTuple(
        city="Portland",
        state="ME",
        postal="",
        lat=43.66,
        lng=-70.255,
        housenumber="",
        country="USA",
    ),
    "Gateway Christian Academy, Bimini": SportsballGeocodeTuple(
        city="",
        state="Bimini",
        postal="",
        lat=25.7433101,
        lng=-79.2883217,
        housenumber="",
        country="Bahamas",
    ),
    "Orlando, Florida": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="",
        lat=28.54,
        lng=-81.38,
        housenumber="",
        country="USA",
    ),
    "Kissimmee, Florida": SportsballGeocodeTuple(
        city="Kissimmee",
        state="FL",
        postal="",
        lat=28.304167,
        lng=-81.412778,
        housenumber="",
        country="USA",
    ),
    "Alaska Airlines Center, Anchorage, Alaska": SportsballGeocodeTuple(
        city="Anchorage",
        state="AL",
        postal="",
        lat=61.188056,
        lng=-149.812222,
        housenumber="3550",
        country="USA",
    ),
    "Baoshan Sports Center, Shanghai": SportsballGeocodeTuple(
        city="Shanghai",
        state="",
        postal="",
        lat=31.395225,
        lng=121.491842,
        housenumber="",
        country="China",
    ),
    "New Brunswick, New Jersey": SportsballGeocodeTuple(
        city="New Brunswick",
        state="NJ",
        postal="",
        lat=40.486678,
        lng=-74.444414,
        housenumber="",
        country="USA",
    ),
    "SIU Arena, Carbondale, Illinois": SIU_ARENA,
    "Boise, Idaho": SportsballGeocodeTuple(
        city="Boise",
        state="ID",
        postal="",
        lat=43.615833,
        lng=-116.201667,
        housenumber="",
        country="USA",
    ),
    "Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.099722,
        lng=-94.578333,
        housenumber="",
        country="USA",
    ),
    "Power Balance Pavilion, Sacramento, California": ARCO_ARENA,
    "Conseco Fieldhouse, Indianapolis, Indiana": GAINBRIDGE_FIELDHOUSE,
    "Von Braun Center, Hunstville, Alabama": SportsballGeocodeTuple(
        city="Huntsville",
        state="AL",
        postal="",
        lat=34.72699,
        lng=-86.590887,
        housenumber="700",
        country="USA",
    ),
    "Bradley Center, Milwaukee, Wisconsin": BRADLEY_CENTER,
    "Toyota Center, Kennewick, Washington": TOYOTA_CENTER,
    "Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="",
        lat=34.05,
        lng=-118.25,
        housenumber="700",
        country="USA",
    ),
    "Staples Center, Los Angeles, California": STAPLES_CENTRE,
    "Newark, New Jersey": SportsballGeocodeTuple(
        city="Newark",
        state="NJ",
        postal="",
        lat=40.735556,
        lng=-74.172222,
        housenumber="700",
        country="USA",
    ),
    "SSE Arena, Belfast": SportsballGeocodeTuple(
        city="Belfast",
        state="",
        postal="BT3 9QQ",
        lat=54.604167,
        lng=-5.915,
        housenumber="2",
        country="UK",
    ),
    "Pocatello, Idaho": SportsballGeocodeTuple(
        city="Pocatello",
        state="ID",
        postal="",
        lat=42.862222,
        lng=-112.450556,
        housenumber="",
        country="USA",
    ),
    "Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.603889,
        lng=-122.33,
        housenumber="",
        country="USA",
    ),
    "Amway Arena, Orlando, Florida": ORLANDO_ARENA,
    "Oklahoma City Arena, Oklahoma City, Oklahoma": PAYCOM_CENTRE,
    "Izod Center, East Rutherford, New Jersey": SportsballGeocodeTuple(
        city="East Rutherford",
        state="NJ",
        postal="",
        lat=40.811667,
        lng=-74.0675,
        housenumber="50",
        country="USA",
    ),
    "Wachovia Center, Philadelphia, Pennsylvania": SPECTRUM,
    "Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.289444,
        lng=-76.615278,
        housenumber="",
        country="USA",
    ),
    "Coraopolis, Pennsylvania": SportsballGeocodeTuple(
        city="Coraopolis",
        state="PA",
        postal="",
        lat=40.515817,
        lng=-80.162792,
        housenumber="",
        country="USA",
    ),
    "Tiger Arena, Savannah, Georgia": SportsballGeocodeTuple(
        city="Savannah",
        state="GA",
        postal="",
        lat=32.02376,
        lng=-81.0658,
        housenumber="",
        country="USA",
    ),
    "TD Banknorth Garden, Boston, Massachusetts": TD_GARDEN,
    "ARCO Arena (II), Sacramento, California": ARCO_ARENA,
    "Ford Center, Oklahoma City, Oklahoma": PAYCOM_CENTRE,
    "Nashville Municipal Auditorium, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.10,
        lng=-86.46,
        housenumber="417",
        country="USA",
    ),
    "Rosemont, Illinois": SportsballGeocodeTuple(
        city="Rosemont",
        state="IL",
        postal="",
        lat=41.990833,
        lng=-87.873889,
        housenumber="",
        country="USA",
    ),
    "Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.05,
        lng=-79.49,
        housenumber="",
        country="USA",
    ),
    "Elon, North Carolina": SportsballGeocodeTuple(
        city="Elon",
        state="NC",
        postal="",
        lat=36.126667,
        lng=-79.495556,
        housenumber="",
        country="USA",
    ),
    "Charlotte Bobcats Arena, Charlotte, North Carolina": SPECTRUM_CENTRE,
    "Mercedes-Benz Arena, Shanghai": SportsballGeocodeTuple(
        city="Shanghai",
        state="",
        postal="",
        lat=31.91,
        lng=121.48,
        housenumber="",
        country="China",
    ),
    "KeyArena at Seattle Center, Seattle, Washington": CLIMATE_PLEDGE_ARENA,
    "Rocket Arena, Cleveland, Ohio": ROCKET_MORTGAGE_FIELDHOUSE,
    "Continental Airlines Arena, East Rutherford, New Jersey": SportsballGeocodeTuple(
        city="East Rutherford",
        state="NJ",
        postal="",
        lat=40.811667,
        lng=-74.0675,
        housenumber="50",
        country="USA",
    ),
    "Brooks Gym, Johnson City, Tennessee": SportsballGeocodeTuple(
        city="Johnson City",
        state="TN",
        postal="37614",
        lat=36.3025963,
        lng=-82.3703615,
        housenumber="1127",
        country="USA",
    ),
    "Qubein Center, High Point, North Carolina": SportsballGeocodeTuple(
        city="High Point",
        state="NC",
        postal="27262",
        lat=35.978333,
        lng=-79.996667,
        housenumber="1050",
        country="USA",
    ),
    "America West Arena, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "SBC Center, San Antonio, Texas": FROST_BANK_CENTER,
    "Gund Arena, Cleveland, Ohio": ROCKET_MORTGAGE_FIELDHOUSE,
    "MCI Center, Washington, District of Columbia": CAPITAL_ONE_ARENA,
    "Oakland Arena, Oakland, California": OAKLAND_ARENA,
    "TD Waterhouse Centre, Orlando, Florida": ORLANDO_ARENA,
    "LLoyd Noble Center, Norman, Oklahoma": LLOYD_NOBLE_CENTER,
    "Pete Maravich Assembly Center, Baton Rouge, Louisiana": PETE_MARAVICH_ASSEMBLY_CENTER,
    "FleetCenter, Boston, Massachusetts": TD_GARDEN,
    "Charlotte Coliseum, Charlotte, North Carolina": CHARLOTTE_COLISEUM,
    "Pyramid Arena, Memphis, Tennessee": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="",
        lat=35.155556,
        lng=-90.051944,
        housenumber="1",
        country="USA",
    ),
    "The Arena in Oakland, Oakland, California": OAKLAND_ARENA,
    "Cox Pavilion, Las Vegas, Nevada": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="",
        lat=36.104167,
        lng=-115.143056,
        housenumber="",
        country="USA",
    ),
    "Renaissance Coliseum, Peoria, Illinois": SportsballGeocodeTuple(
        city="Peoria",
        state="IL",
        postal="",
        lat=40.699167,
        lng=-89.617778,
        housenumber="",
        country="USA",
    ),
    "First Union Center, Philadelphia, Pennsylvania": SPECTRUM,
    "Compaq Center, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.730278,
        lng=-95.435,
        housenumber="3700",
        country="USA",
    ),
    "Reunion Arena, Dallas, Texas": REUNION_ARENA,
    "General Motors Place, Vancouver, Canada": ROGERS_ARENA,
    "Merrell Center, Katy, Texas": MERRELL_CENTER,
    "Nassau Veterans Memorial Coliseum, Uniondale, New York": NASSAU_COLISEUM,
    "McNichols Sports Arena, Denver, Colorado": MCNICHOLS_SPORTS_ARENA,
    "Freedom Hall, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="",
        lat=38.200294,
        lng=-85.741886,
        housenumber="937",
        country="USA",
    ),
    "HemisFair Arena, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="78203",
        lat=29.420134,
        lng=-98.483299,
        housenumber="601",
        country="USA",
    ),
    "Market Square Arena, Indianapolis, Indiana": MARKET_SQUARE_ARENA,
    "Hampton Coliseum, Hampton, Virginia": SportsballGeocodeTuple(
        city="Hampton",
        state="VA",
        postal="23666",
        lat=37.034725,
        lng=-76.381339,
        housenumber="1000",
        country="USA",
    ),
    "St. Louis Arena, St. Louis, Missouri": ENTERPRISE_CENTER,
    "Richmond Coliseum, Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="23219",
        lat=37.544705,
        lng=-77.434484,
        housenumber="601",
        country="USA",
    ),
    "Salt Palace, Salt Lake City, Utah": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="",
        lat=40.766944,
        lng=-111.895,
        housenumber="100",
        country="USA",
    ),
    "Cincinnati Riverfront Coliseum, Cincinnati, Ohio": PAYCOR_STADIUM,
    "Hulman Civic-University Center, Terre Haute, Indiana": HULMAN_CENTER,
    "San Diego Sports Arena, San Diego, California": SAN_DIEGO_SPORTS_ARENA,
    "Denver Auditorium Arena, Denver, Colorado": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="80204",
        lat=39.744444,
        lng=-104.9975,
        housenumber="1323",
        country="USA",
    ),
    "Mid-South Coliseum, Memphis, Tennessee": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="38104",
        lat=35.118395,
        lng=-89.980366,
        housenumber="996",
        country="USA",
    ),
    "Memorial Coliseum, Lexington, Kentucky": SportsballGeocodeTuple(
        city="Lexington",
        state="KT",
        postal="40508",
        lat=38.0394636,
        lng=-84.5004952,
        housenumber="",
        country="USA",
    ),
    "Indiana State Fair Coliseum, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.8275,
        lng=-86.135,
        housenumber="1202",
        country="USA",
    ),
    "Golden Hall, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="92101",
        lat=32.7507735,
        lng=-117.1008248,
        housenumber="9",
        country="USA",
    ),
    "Tuscaloosa, Alabama": SportsballGeocodeTuple(
        city="Tuscaloosa",
        state="AL",
        postal="",
        lat=33.209722,
        lng=-87.569167,
        housenumber="",
        country="USA",
    ),
    "Lubbock, Texas": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="",
        lat=33.585,
        lng=-101.845,
        housenumber="",
        country="USA",
    ),
    "Chestnut Hill, Massachusetts": SportsballGeocodeTuple(
        city="Chestnut Hill",
        state="MA",
        postal="",
        lat=42.330556,
        lng=-71.166111,
        housenumber="",
        country="USA",
    ),
    "Minneapolis, Minnesota": SportsballGeocodeTuple(
        city="Minneapolis",
        state="MN",
        postal="",
        lat=44.981944,
        lng=-93.269167,
        housenumber="",
        country="USA",
    ),
    "Ann Arbor, Michigan": SportsballGeocodeTuple(
        city="Ann Arbor",
        state="MI",
        postal="",
        lat=42.281389,
        lng=-83.748333,
        housenumber="",
        country="USA",
    ),
    "Norman, Oklahoma": SportsballGeocodeTuple(
        city="Norman",
        state="OK",
        postal="",
        lat=35.220833,
        lng=-97.443611,
        housenumber="",
        country="USA",
    ),
    "Greenville, South Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="SC",
        postal="",
        lat=34.844444,
        lng=-82.385556,
        housenumber="",
        country="USA",
    ),
    "Storrs, Connecticut": SportsballGeocodeTuple(
        city="Storrs",
        state="CT",
        postal="",
        lat=41.808333,
        lng=-72.249444,
        housenumber="",
        country="USA",
    ),
    "Muncie, Indiana": SportsballGeocodeTuple(
        city="Muncie",
        state="IN",
        postal="",
        lat=40.196667,
        lng=-85.375,
        housenumber="",
        country="USA",
    ),
    "Bowling Green, Ohio": SportsballGeocodeTuple(
        city="Bowling Green",
        state="OH",
        postal="",
        lat=41.373889,
        lng=-83.650833,
        housenumber="",
        country="USA",
    ),
    "Annapolis, Maryland": SportsballGeocodeTuple(
        city="Annapolis",
        state="MD",
        postal="",
        lat=38.973056,
        lng=-76.501111,
        housenumber="",
        country="USA",
    ),
    "Providence, Rhode Island": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="",
        lat=41.823611,
        lng=-71.422222,
        housenumber="",
        country="USA",
    ),
    "St. Bonaventure, New York": SportsballGeocodeTuple(
        city="St. Bonaventure",
        state="NY",
        postal="",
        lat=42.080278,
        lng=-78.475,
        housenumber="",
        country="USA",
    ),
    "Pensacola, Florida": SportsballGeocodeTuple(
        city="Pensacola",
        state="FL",
        postal="",
        lat=30.421308,
        lng=-87.216914,
        housenumber="",
        country="USA",
    ),
    "Johnson City, Tennessee": SportsballGeocodeTuple(
        city="Johnson City",
        state="TN",
        postal="",
        lat=36.333333,
        lng=-82.366667,
        housenumber="",
        country="USA",
    ),
    "Hamilton, New York": SportsballGeocodeTuple(
        city="Hamilton",
        state="NY",
        postal="",
        lat=42.829167,
        lng=-75.552778,
        housenumber="",
        country="USA",
    ),
    "Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.904722,
        lng=-77.016389,
        housenumber="",
        country="USA",
    ),
    "New Britain, Connecticut": SportsballGeocodeTuple(
        city="New Britain",
        state="CT",
        postal="",
        lat=41.675,
        lng=-72.787222,
        housenumber="",
        country="USA",
    ),
    "Cincinnati, Ohio": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="",
        lat=39.1,
        lng=-84.5125,
        housenumber="",
        country="USA",
    ),
    "Teaneck, New Jersey": SportsballGeocodeTuple(
        city="Teaneck",
        state="NJ",
        postal="",
        lat=40.890317,
        lng=-74.011478,
        housenumber="",
        country="USA",
    ),
    "Bronx, New York": SportsballGeocodeTuple(
        city="Bronx",
        state="NY",
        postal="",
        lat=40.837222,
        lng=-73.886111,
        housenumber="",
        country="USA",
    ),
    "Fairfax, Virginia": SportsballGeocodeTuple(
        city="Fairfax",
        state="VA",
        postal="",
        lat=38.8525,
        lng=-77.304167,
        housenumber="",
        country="USA",
    ),
    "Oxford, Ohio": SportsballGeocodeTuple(
        city="Oxford",
        state="OH",
        postal="",
        lat=39.5075,
        lng=-84.746667,
        housenumber="",
        country="USA",
    ),
    "Raleigh, North Carolina": SportsballGeocodeTuple(
        city="Raleigh",
        state="NC",
        postal="",
        lat=35.854167,
        lng=-78.761944,
        housenumber="",
        country="USA",
    ),
    "DeKalb, Illinois": SportsballGeocodeTuple(
        city="DeKalb",
        state="IL",
        postal="",
        lat=41.931389,
        lng=-88.750278,
        housenumber="",
        country="USA",
    ),
    "Natchitoches, Louisiana": SportsballGeocodeTuple(
        city="Natchitoches",
        state="LA",
        postal="",
        lat=31.693056,
        lng=-93.095,
        housenumber="",
        country="USA",
    ),
    "Athens, Ohio": SportsballGeocodeTuple(
        city="Athens",
        state="OH",
        postal="",
        lat=39.329167,
        lng=-82.096111,
        housenumber="",
        country="USA",
    ),
    "Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.952778,
        lng=-75.163611,
        housenumber="",
        country="USA",
    ),
    "South Bend, Indiana": SportsballGeocodeTuple(
        city="South Bend",
        state="IN",
        postal="",
        lat=41.676389,
        lng=-86.269444,
        housenumber="",
        country="USA",
    ),
    "Laramie, Wyoming": SportsballGeocodeTuple(
        city="Laramie",
        state="WY",
        postal="",
        lat=41.311111,
        lng=-105.593611,
        housenumber="",
        country="USA",
    ),
    "College Station, Texas": SportsballGeocodeTuple(
        city="College Station",
        state="TX",
        postal="",
        lat=30.601389,
        lng=-96.314444,
        housenumber="",
        country="USA",
    ),
    "Ames, Iowa": SportsballGeocodeTuple(
        city="Ames",
        state="IO",
        postal="",
        lat=42.034722,
        lng=-93.62,
        housenumber="",
        country="USA",
    ),
    "San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="",
        lat=29.425,
        lng=-98.493889,
        housenumber="",
        country="USA",
    ),
    "West Lafayette, Indiana": SportsballGeocodeTuple(
        city="West Lafayette",
        state="IN",
        postal="",
        lat=40.443333,
        lng=-86.923611,
        housenumber="",
        country="USA",
    ),
    "Lexington, Kentucky": SportsballGeocodeTuple(
        city="Lexington",
        state="KT",
        postal="",
        lat=38.046389,
        lng=-84.496944,
        housenumber="",
        country="USA",
    ),
    "Tucson, Arizona": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="",
        lat=32.221667,
        lng=-110.926389,
        housenumber="",
        country="USA",
    ),
    "Starkville, Mississippi": SportsballGeocodeTuple(
        city="Starkville",
        state="MS",
        postal="",
        lat=33.4625,
        lng=-88.82,
        housenumber="",
        country="USA",
    ),
    "Smithfield, Rhode Island": SportsballGeocodeTuple(
        city="Smithfield",
        state="RI",
        postal="",
        lat=41.9,
        lng=-71.533333,
        housenumber="",
        country="USA",
    ),
    "Dayton, Ohio": SportsballGeocodeTuple(
        city="Dayton",
        state="OH",
        postal="",
        lat=39.759444,
        lng=-84.191667,
        housenumber="",
        country="USA",
    ),
    "Greenville, North Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="NC",
        postal="",
        lat=35.594444,
        lng=-77.376111,
        housenumber="",
        country="USA",
    ),
    "Orono, Maine": SportsballGeocodeTuple(
        city="Orono",
        state="ME",
        postal="",
        lat=44.883333,
        lng=-68.672222,
        housenumber="",
        country="USA",
    ),
    "Columbus, Ohio": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="",
        lat=39.962222,
        lng=-83.000556,
        housenumber="",
        country="USA",
    ),
    "Reno, Nevada": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="",
        lat=39.527222,
        lng=-119.821944,
        housenumber="",
        country="USA",
    ),
    "San Jose, California": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="",
        lat=37.336111,
        lng=-121.890556,
        housenumber="",
        country="USA",
    ),
    "Columbia, South Carolina": SportsballGeocodeTuple(
        city="Columbia",
        state="SC",
        postal="",
        lat=34.000556,
        lng=-81.034722,
        housenumber="",
        country="USA",
    ),
    "Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.5175,
        lng=-86.809444,
        housenumber="",
        country="USA",
    ),
    "Buffalo, New York": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="",
        lat=42.886389,
        lng=-78.878056,
        housenumber="",
        country="USA",
    ),
    "Boca Raton, Florida": SportsballGeocodeTuple(
        city="Boca Raton",
        state="FL",
        postal="",
        lat=26.368611,
        lng=-80.1,
        housenumber="",
        country="USA",
    ),
    "Easton, Pennsylvania": SportsballGeocodeTuple(
        city="Easton",
        state="PA",
        postal="",
        lat=40.688333,
        lng=-75.216389,
        housenumber="",
        country="USA",
    ),
    "Highland Heights, Kentucky": SportsballGeocodeTuple(
        city="Highland Heights",
        state="KT",
        postal="",
        lat=39.035556,
        lng=-84.456667,
        housenumber="",
        country="USA",
    ),
    "Rochester, Michigan": SportsballGeocodeTuple(
        city="Rochester",
        state="MI",
        postal="",
        lat=42.680556,
        lng=-83.133889,
        housenumber="",
        country="USA",
    ),
    "Toledo, Ohio": SportsballGeocodeTuple(
        city="Toledo",
        state="OH",
        postal="",
        lat=41.652778,
        lng=-83.537778,
        housenumber="",
        country="USA",
    ),
    "Burlington, Vermont": SportsballGeocodeTuple(
        city="Burlington",
        state="VT",
        postal="",
        lat=44.475833,
        lng=-73.211944,
        housenumber="",
        country="USA",
    ),
    "Blacksburg, Virginia": SportsballGeocodeTuple(
        city="Blacksburg",
        state="VI",
        postal="",
        lat=37.23,
        lng=-80.417778,
        housenumber="",
        country="USA",
    ),
    "Kalamazoo, Michigan": SportsballGeocodeTuple(
        city="Kalamazoo",
        state="MI",
        postal="",
        lat=42.29,
        lng=-85.585833,
        housenumber="",
        country="USA",
    ),
    "Colorado Springs, Colorado": SportsballGeocodeTuple(
        city="Colorado Springs",
        state="CO",
        postal="",
        lat=38.833889,
        lng=-104.825278,
        housenumber="",
        country="USA",
    ),
    "Fort Collins, Colorado": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="",
        lat=40.559167,
        lng=-105.078056,
        housenumber="",
        country="USA",
    ),
    "Eugene, Oregon": SportsballGeocodeTuple(
        city="Eugene",
        state="OR",
        postal="",
        lat=44.056389,
        lng=-123.1175,
        housenumber="",
        country="USA",
    ),
    "Charlottesville, Virginia": SportsballGeocodeTuple(
        city="Charlottesville",
        state="VI",
        postal="",
        lat=38.0299,
        lng=-78.479,
        housenumber="",
        country="USA",
    ),
    "Fresno, California": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="",
        lat=36.75,
        lng=-119.766667,
        housenumber="",
        country="USA",
    ),
    "War Memorial Coliseum, Fort Wayne, Indiana": ALLEN_COUNTY_WAR_MEMORIAL_COLISEUM,
    "Peterson Gym, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.7742,
        lng=-117.0768,
        housenumber="5340",
        country="USA",
    ),
    "St. Paul Civic Center, St. Paul, Minnesota": SportsballGeocodeTuple(
        city="St. Paul",
        state="MN",
        postal="55102",
        lat=39.4285806,
        lng=-85.6296931,
        housenumber="143",
        country="USA",
    ),
    "Riverdale, New York": SportsballGeocodeTuple(
        city="Riverdale",
        state="NY",
        postal="",
        lat=40.894,
        lng=-73.913,
        housenumber="",
        country="USA",
    ),
    "North Andover, Massachusetts": SportsballGeocodeTuple(
        city="North Andover",
        state="MA",
        postal="",
        lat=42.698611,
        lng=-71.135556,
        housenumber="",
        country="USA",
    ),
    "Niagara University, New York": SportsballGeocodeTuple(
        city="Niagara University",
        state="NY",
        postal="",
        lat=43.138,
        lng=-79.037,
        housenumber="",
        country="USA",
    ),
    "Wilmington, North Carolina": SportsballGeocodeTuple(
        city="Wilmington",
        state="NC",
        postal="",
        lat=34.21,
        lng=-77.886667,
        housenumber="",
        country="USA",
    ),
    "Jersey City, New Jersey": SportsballGeocodeTuple(
        city="Jersey City",
        state="NJ",
        postal="",
        lat=40.71,
        lng=-74.06,
        housenumber="",
        country="USA",
    ),
    "Orangeburg, South Carolina": SportsballGeocodeTuple(
        city="Orangeburg",
        state="SC",
        postal="",
        lat=33.491944,
        lng=-80.855278,
        housenumber="",
        country="USA",
    ),
    "Pine Bluff, Arkansas": SportsballGeocodeTuple(
        city="Pine Bluff",
        state="AR",
        postal="",
        lat=34.228333,
        lng=-92.0,
        housenumber="",
        country="USA",
    ),
    "Grambling, Louisiana": SportsballGeocodeTuple(
        city="Grambling",
        state="LA",
        postal="",
        lat=32.5275,
        lng=-92.713889,
        housenumber="",
        country="USA",
    ),
    "Murfreesboro, Tennessee": SportsballGeocodeTuple(
        city="Murfreesboro",
        state="TN",
        postal="",
        lat=35.846111,
        lng=-86.391944,
        housenumber="",
        country="USA",
    ),
    "Itta Bena, Mississippi": SportsballGeocodeTuple(
        city="Itta Bena",
        state="MS",
        postal="",
        lat=33.4975,
        lng=-90.324444,
        housenumber="",
        country="USA",
    ),
    "Huntsville, Texas": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="",
        lat=30.722222,
        lng=-95.553333,
        housenumber="",
        country="USA",
    ),
    "Baton Rouge, Louisiana": SportsballGeocodeTuple(
        city="Baton Rouge",
        state="LA",
        postal="",
        lat=30.4475,
        lng=-91.178611,
        housenumber="",
        country="USA",
    ),
    "Bowling Green, Kentucky": SportsballGeocodeTuple(
        city="Bowling Green",
        state="KT",
        postal="",
        lat=36.981667,
        lng=-86.444444,
        housenumber="",
        country="USA",
    ),
    "Davis, California": SportsballGeocodeTuple(
        city="Davis",
        state="CA",
        postal="",
        lat=38.553889,
        lng=-121.738056,
        housenumber="",
        country="USA",
    ),
    "ExploreAsheville.com Arena, Asheville, North Carolina": HARRAHS_CHEROKEE_CENTER,
    "St. Louis, Missouri": SportsballGeocodeTuple(
        city="St. Louis",
        state="MS",
        postal="",
        lat=38.627222,
        lng=-90.197778,
        housenumber="",
        country="USA",
    ),
    "Dover, Delaware": SportsballGeocodeTuple(
        city="Dover",
        state="DE",
        postal="",
        lat=39.158056,
        lng=-75.524444,
        housenumber="",
        country="USA",
    ),
    "Moon, Pennsylvania": SportsballGeocodeTuple(
        city="Moon",
        state="PA",
        postal="",
        lat=40.516667,
        lng=-80.233333,
        housenumber="",
        country="USA",
    ),
    "Fair Park, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.4968,
        lng=-86.8714,
        housenumber="",
        country="USA",
    ),
    "Broadview Center, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="12222",
        lat=42.681667,
        lng=-73.828333,
        housenumber="1400",
        country="USA",
    ),
    "Newark, Delaware": SportsballGeocodeTuple(
        city="Newark",
        state="DE",
        postal="",
        lat=39.683611,
        lng=-75.749722,
        housenumber="",
        country="USA",
    ),
    "Hempstead, New York": SportsballGeocodeTuple(
        city="Hempstead",
        state="NY",
        postal="",
        lat=40.704722,
        lng=-73.617222,
        housenumber="",
        country="USA",
    ),
    "Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.360278,
        lng=-71.057778,
        housenumber="",
        country="USA",
    ),
    "Lewisburg, Pennsylvania": SportsballGeocodeTuple(
        city="Lewisburg",
        state="PA",
        postal="",
        lat=40.963889,
        lng=-76.888056,
        housenumber="",
        country="USA",
    ),
    "Miami, Florida": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="",
        lat=25.766667,
        lng=-80.2,
        housenumber="",
        country="USA",
    ),
    "Terre Haute, Indiana": SportsballGeocodeTuple(
        city="Terre Haute",
        state="IN",
        postal="",
        lat=39.469722,
        lng=-87.389722,
        housenumber="",
        country="USA",
    ),
    "Ruston, Louisiana": SportsballGeocodeTuple(
        city="Ruston",
        state="LA",
        postal="",
        lat=32.529722,
        lng=-92.640556,
        housenumber="",
        country="USA",
    ),
    "Poughkeepsie, New York": SportsballGeocodeTuple(
        city="Poughkeepsie",
        state="NY",
        postal="",
        lat=41.703889,
        lng=-73.93,
        housenumber="",
        country="USA",
    ),
    "Springfield, Missouri": SportsballGeocodeTuple(
        city="Springfield",
        state="MS",
        postal="",
        lat=37.215278,
        lng=-93.298333,
        housenumber="",
        country="USA",
    ),
    "West Long Branch, New Jersey": SportsballGeocodeTuple(
        city="West Long Branch",
        state="NJ",
        postal="",
        lat=40.287904,
        lng=-74.020019,
        housenumber="",
        country="USA",
    ),
    "Emmitsburg, Maryland": SportsballGeocodeTuple(
        city="Emmitsburg",
        state="MD",
        postal="",
        lat=39.704167,
        lng=-77.321111,
        housenumber="",
        country="USA",
    ),
    "Florence, Alabama": SportsballGeocodeTuple(
        city="Florence",
        state="AL",
        postal="",
        lat=34.83035,
        lng=-87.665419,
        housenumber="",
        country="USA",
    ),
    "Lawrenceville, New Jersey": SportsballGeocodeTuple(
        city="Lawrenceville",
        state="NJ",
        postal="",
        lat=40.302787,
        lng=-74.738004,
        housenumber="",
        country="USA",
    ),
    "Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="",
        lat=42.6525,
        lng=-73.757222,
        housenumber="",
        country="USA",
    ),
    "Carbondale, Illinois": SportsballGeocodeTuple(
        city="Carbondale",
        state="IL",
        postal="",
        lat=37.722222,
        lng=-89.258333,
        housenumber="",
        country="USA",
    ),
    "Staten Island, New York": SportsballGeocodeTuple(
        city="Staten Island",
        state="NY",
        postal="",
        lat=40.583333,
        lng=-74.15,
        housenumber="",
        country="USA",
    ),
    "Abilene, Texas": SportsballGeocodeTuple(
        city="Abilene",
        state="TX",
        postal="",
        lat=32.45,
        lng=-99.75,
        housenumber="",
        country="USA",
    ),
    "Green Bay, Wisconsin": SportsballGeocodeTuple(
        city="Green Bay",
        state="WI",
        postal="",
        lat=44.513333,
        lng=-88.015833,
        housenumber="",
        country="USA",
    ),
    "Las Cruces, New Mexico": SportsballGeocodeTuple(
        city="Las Cruces",
        state="NM",
        postal="",
        lat=32.314444,
        lng=-106.778889,
        housenumber="",
        country="USA",
    ),
    "Stephenville, Texas": SportsballGeocodeTuple(
        city="Stephenville",
        state="TX",
        postal="",
        lat=32.209722,
        lng=-98.2375,
        housenumber="",
        country="USA",
    ),
    "Orem, Utah": SportsballGeocodeTuple(
        city="Orem",
        state="UT",
        postal="",
        lat=40.290556,
        lng=-111.729722,
        housenumber="",
        country="USA",
    ),
    "Bakersfield, California": SportsballGeocodeTuple(
        city="Bakersfield",
        state="CA",
        postal="",
        lat=35.373333,
        lng=-119.018889,
        housenumber="",
        country="USA",
    ),
    "Northridge, California": SportsballGeocodeTuple(
        city="Northridge",
        state="CA",
        postal="",
        lat=34.228056,
        lng=-118.535833,
        housenumber="",
        country="USA",
    ),
    "Irvine, California": SportsballGeocodeTuple(
        city="Irvine",
        state="CA",
        postal="",
        lat=33.669444,
        lng=-117.823056,
        housenumber="",
        country="USA",
    ),
    "St. George, Utah": SportsballGeocodeTuple(
        city="St. George",
        state="UT",
        postal="",
        lat=37.075,
        lng=-113.576667,
        housenumber="",
        country="USA",
    ),
    "Long Beach, California": SportsballGeocodeTuple(
        city="Long Beach",
        state="CA",
        postal="",
        lat=33.768333,
        lng=-118.195556,
        housenumber="",
        country="USA",
    ),
    "El Paso, Texas": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="",
        lat=31.759167,
        lng=-106.488611,
        housenumber="",
        country="USA",
    ),
    "San Luis Obispo, California": SportsballGeocodeTuple(
        city="San Luis Obispo",
        state="CA",
        postal="",
        lat=35.274167,
        lng=-120.663056,
        housenumber="",
        country="USA",
    ),
    "Fullerton, California": SportsballGeocodeTuple(
        city="Fullerton",
        state="CA",
        postal="",
        lat=33.88,
        lng=-117.928611,
        housenumber="",
        country="USA",
    ),
    "Riverside, California": SportsballGeocodeTuple(
        city="Riverside",
        state="CA",
        postal="",
        lat=33.948056,
        lng=-117.396111,
        housenumber="",
        country="USA",
    ),
    "La Jolla, California": SportsballGeocodeTuple(
        city="La Jolla",
        state="CA",
        postal="",
        lat=32.84,
        lng=-117.276944,
        housenumber="",
        country="USA",
    ),
    "Indiana Assembly Hall, Bloomington, Indiana": INDIANA_ASSEMBLY_HALL,
    "Anderson High School Wigwam, Anderson, Indiana": SportsballGeocodeTuple(
        city="Anderson",
        state="IN",
        postal="",
        lat=40.103056,
        lng=-85.685833,
        housenumber="1229",
        country="USA",
    ),
    "Miami-Dade Junior College North, Miami, Florida": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="",
        lat=25.777778,
        lng=-80.190556,
        housenumber="1229",
        country="USA",
    ),
    "Miami Beach Convention Hall, Miami Beach, Florida": MIAMI_BEACH_CONVENTION_CENTER,
    "Tucson Community Center, Tucson, Arizona": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="",
        lat=32.218333,
        lng=-110.974167,
        housenumber="260",
        country="USA",
    ),
    "Pittsburgh Civic Arena, Pittsburgh, Pennsylvania": CIVIC_ARENA,
    "Curtis Hixon Hall, Tampa, Florida": SportsballGeocodeTuple(
        city="Tampa",
        state="FL",
        postal="",
        lat=27.949167,
        lng=-82.461944,
        housenumber="",
        country="USA",
    ),
    "Winston-Salem Memorial Coliseum, Winston-Salem, North Carolina": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="",
        lat=36.1262,
        lng=-80.2581,
        housenumber="",
        country="USA",
    ),
    "Uniontown High School, Uniontown, Pennsylvania": SportsballGeocodeTuple(
        city="Uniontown",
        state="PA",
        postal="",
        lat=39.89632,
        lng=-79.72016,
        housenumber="",
        country="USA",
    ),
    "Island Garden, West Hempstead, New York": SportsballGeocodeTuple(
        city="West Hempstead",
        state="NY",
        postal="",
        lat=40.707222,
        lng=-73.656667,
        housenumber="",
        country="USA",
    ),
    "Roanoke Civic Center, Roanoke, Virginia": SportsballGeocodeTuple(
        city="Roanoke",
        state="VA",
        postal="24016",
        lat=37.280171,
        lng=-79.935669,
        housenumber="710",
        country="USA",
    ),
    "Maple Leaf Gardens, Toronto, Canada": SportsballGeocodeTuple(
        city="Toronto",
        state="ON",
        postal="",
        lat=43.662222,
        lng=-79.380278,
        housenumber="60",
        country="CA",
    ),
    "Utah State Spectrum, Logan, Utah": SMITH_SPECTRUM,
    "Bayfront Arena, St. Petersburg, Florida": SportsballGeocodeTuple(
        city="St. Petersburg",
        state="FL",
        postal="",
        lat=27.766583,
        lng=-82.631694,
        housenumber="400",
        country="USA",
    ),
    "Richmond Arena, Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="",
        lat=37.569855,
        lng=-77.462411,
        housenumber="400",
        country="USA",
    ),
    "Mt. Pleasant, Michigan": SportsballGeocodeTuple(
        city="Mt. Pleasant",
        state="MI",
        postal="",
        lat=43.597778,
        lng=-84.7675,
        housenumber="",
        country="USA",
    ),
    "Conway, Arkansas": SportsballGeocodeTuple(
        city="Conway",
        state="AR",
        postal="",
        lat=35.087222,
        lng=-92.453333,
        housenumber="",
        country="USA",
    ),
    "Kent, Ohio": SportsballGeocodeTuple(
        city="Kent",
        state="OH",
        postal="",
        lat=41.149167,
        lng=-81.360833,
        housenumber="",
        country="USA",
    ),
    "Hofstra Physical Fitness Center, Hempstead, New York": SportsballGeocodeTuple(
        city="Hempstead",
        state="NY",
        postal="",
        lat=40.7216566,
        lng=-73.5998583,
        housenumber="",
        country="USA",
    ),
    "Jacksonville Coliseum, Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32202",
        lat=30.324596,
        lng=-81.640901,
        housenumber="1145",
        country="USA",
    ),
    "Moby Gym, Ft. Collins, Colorado": MOBY_ARENA,
    "Salem Civic Center, Salem, Virginia": SportsballGeocodeTuple(
        city="Salem",
        state="VA",
        postal="",
        lat=37.283889,
        lng=-80.040833,
        housenumber="",
        country="USA",
    ),
    "Tarrant County Convention Center, Ft. Worth, Texas": SportsballGeocodeTuple(
        city="Ft. Worth",
        state="TX",
        postal="76102",
        lat=32.749,
        lng=-97.3277,
        housenumber="12",
        country="USA",
    ),
    "Lubbock Municipal Coliseum, Lubbock, Texas": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="79409",
        lat=33.59,
        lng=-101.8775,
        housenumber="2720",
        country="USA",
    ),
    "Dorton Arena, Raleigh, North Carolina": DORTON_ARENA,
    "J.S. Dorton Arena, Raleigh, North Carolina": DORTON_ARENA,
    "West Palm Beach Auditorium, West Palm Beach, Florida": SportsballGeocodeTuple(
        city="West Palm Beach",
        state="FL",
        postal="33401",
        lat=26.723611,
        lng=-80.082222,
        housenumber="1610",
        country="USA",
    ),
    "Sikeston Field House, Sikeston, Missouri": SportsballGeocodeTuple(
        city="Sikeston",
        state="MS",
        postal="63801",
        lat=36.87943,
        lng=-89.57209,
        housenumber="200",
        country="USA",
    ),
    "Swenson Gym, Ogden, Utah": SportsballGeocodeTuple(
        city="Ogden",
        state="UT",
        postal="",
        lat=41.190833,
        lng=-111.941944,
        housenumber="1356",
        country="USA",
    ),
    "Los Angeles Memorial Sports Arena, Los Angeles, California": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Auburn, Alabama": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="",
        lat=32.597778,
        lng=-85.480833,
        housenumber="",
        country="USA",
    ),
    "Chapel Hill, North Carolina": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="",
        lat=35.927222,
        lng=-79.039167,
        housenumber="",
        country="USA",
    ),
    "Knoxville, Tennessee": SportsballGeocodeTuple(
        city="Knoxville",
        state="TN",
        postal="",
        lat=35.9617,
        lng=-83.9232,
        housenumber="",
        country="USA",
    ),
    "Gainesville, Florida": SportsballGeocodeTuple(
        city="Gainesville",
        state="FL",
        postal="",
        lat=29.651997,
        lng=-82.324992,
        housenumber="",
        country="USA",
    ),
    "Tempe, Arizona": SportsballGeocodeTuple(
        city="Tempe",
        state="AZ",
        postal="",
        lat=33.412778,
        lng=-111.943056,
        housenumber="",
        country="USA",
    ),
    "Manhattan, Kansas": SportsballGeocodeTuple(
        city="Manhattan",
        state="KS",
        postal="",
        lat=39.188611,
        lng=-96.604722,
        housenumber="",
        country="USA",
    ),
    "Clemson, South Carolina": SportsballGeocodeTuple(
        city="Clemson",
        state="SC",
        postal="",
        lat=34.685,
        lng=-82.814722,
        housenumber="",
        country="USA",
    ),
    "Madison, Wisconsin": SportsballGeocodeTuple(
        city="Madison",
        state="WI",
        postal="",
        lat=43.074722,
        lng=-89.384167,
        housenumber="",
        country="USA",
    ),
    "College Park, Maryland": SportsballGeocodeTuple(
        city="College Park",
        state="MD",
        postal="",
        lat=38.996667,
        lng=-76.9275,
        housenumber="",
        country="USA",
    ),
    "Columbia, Missouri": SportsballGeocodeTuple(
        city="Columbia",
        state="MS",
        postal="",
        lat=38.9475,
        lng=-92.326667,
        housenumber="",
        country="USA",
    ),
    "Provo, Utah": SportsballGeocodeTuple(
        city="Provo",
        state="UT",
        postal="",
        lat=40.244444,
        lng=-111.660833,
        housenumber="",
        country="USA",
    ),
    "Lawrence, Kansas": SportsballGeocodeTuple(
        city="Lawrence",
        state="KS",
        postal="",
        lat=38.959722,
        lng=-95.264167,
        housenumber="",
        country="USA",
    ),
    "Fayetteville, Arkansas": SportsballGeocodeTuple(
        city="Fayetteville",
        state="AR",
        postal="",
        lat=36.0625,
        lng=-94.1575,
        housenumber="",
        country="USA",
    ),
    "Buies Creek, North Carolina": SportsballGeocodeTuple(
        city="Buies Creek",
        state="NC",
        postal="",
        lat=35.408056,
        lng=-78.741389,
        housenumber="",
        country="USA",
    ),
    "Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="",
        lat=32.783333,
        lng=-79.931944,
        housenumber="",
        country="USA",
    ),
    "Ithaca, New York": SportsballGeocodeTuple(
        city="Ithaca",
        state="NY",
        postal="",
        lat=42.443333,
        lng=-76.5,
        housenumber="",
        country="USA",
    ),
    "Bloomington, Indiana": SportsballGeocodeTuple(
        city="Bloomington",
        state="IN",
        postal="",
        lat=39.162222,
        lng=-86.522222,
        housenumber="",
        country="USA",
    ),
    "Kennesaw, Georgia": SportsballGeocodeTuple(
        city="Kennesaw",
        state="GA",
        postal="",
        lat=34.023333,
        lng=-84.615278,
        housenumber="",
        country="USA",
    ),
    "Amherst, Massachusetts": SportsballGeocodeTuple(
        city="Amherst",
        state="MA",
        postal="",
        lat=42.383333,
        lng=-72.516667,
        housenumber="",
        country="USA",
    ),
    "Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="",
        lat=37.540833,
        lng=-77.436667,
        housenumber="",
        country="USA",
    ),
    "Syracuse, New York": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="",
        lat=43.046944,
        lng=-76.144444,
        housenumber="",
        country="USA",
    ),
    "Morgantown, West Virginia": SportsballGeocodeTuple(
        city="Morgantown",
        state="WV",
        postal="",
        lat=39.633611,
        lng=-79.950556,
        housenumber="",
        country="USA",
    ),
    "Omaha, Nebraska": SportsballGeocodeTuple(
        city="Omaha",
        state="NB",
        postal="",
        lat=41.258611,
        lng=-95.9375,
        housenumber="",
        country="USA",
    ),
    "Santa Barbara, California": SportsballGeocodeTuple(
        city="Santa Barbara",
        state="CA",
        postal="",
        lat=34.416667,
        lng=-119.7,
        housenumber="",
        country="USA",
    ),
    "Stony Brook, New York": SportsballGeocodeTuple(
        city="Stony Brook",
        state="NY",
        postal="",
        lat=40.906389,
        lng=-73.128333,
        housenumber="",
        country="USA",
    ),
    "Winston-Salem, North Carolina": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="",
        lat=36.102778,
        lng=-80.260833,
        housenumber="",
        country="USA",
    ),
    "Hanover, New Hampshire": SportsballGeocodeTuple(
        city="Hanover",
        state="NH",
        postal="",
        lat=43.702222,
        lng=-72.289444,
        housenumber="",
        country="USA",
    ),
    "Davidson, North Carolina": SportsballGeocodeTuple(
        city="Davidson",
        state="NC",
        postal="",
        lat=35.500556,
        lng=-80.846944,
        housenumber="",
        country="USA",
    ),
    "Ypsilanti, Michigan": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="",
        lat=42.242778,
        lng=-83.618333,
        housenumber="",
        country="USA",
    ),
    "Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="",
        lat=29.210833,
        lng=-81.022778,
        housenumber="",
        country="USA",
    ),
    "Richmond, Kentucky": SportsballGeocodeTuple(
        city="Richmond",
        state="KT",
        postal="",
        lat=37.731111,
        lng=-84.293889,
        housenumber="",
        country="USA",
    ),
    "Jacksonville, Alabama": SportsballGeocodeTuple(
        city="Jacksonville",
        state="AL",
        postal="",
        lat=33.815833,
        lng=-85.760556,
        housenumber="",
        country="USA",
    ),
    "Stillwater, Oklahoma": SportsballGeocodeTuple(
        city="Stillwater",
        state="OK",
        postal="",
        lat=36.116,
        lng=-97.059,
        housenumber="",
        country="USA",
    ),
    "Arlington, Texas": SportsballGeocodeTuple(
        city="Arlington",
        state="TX",
        postal="",
        lat=32.705,
        lng=-97.122778,
        housenumber="",
        country="USA",
    ),
    "Boulder, Colorado": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="",
        lat=40.015,
        lng=-105.2705,
        housenumber="",
        country="USA",
    ),
    "Tallahassee, Florida": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="",
        lat=30.438333,
        lng=-84.280556,
        housenumber="",
        country="USA",
    ),
    "New Rochelle, New York": SportsballGeocodeTuple(
        city="New Rochelle",
        state="NY",
        postal="",
        lat=40.908611,
        lng=-73.781944,
        housenumber="",
        country="USA",
    ),
    "Logan, Utah": SportsballGeocodeTuple(
        city="Logan",
        state="UT",
        postal="",
        lat=41.763889,
        lng=-111.8725,
        housenumber="",
        country="USA",
    ),
    "Prairie View, Texas": SportsballGeocodeTuple(
        city="Prairie View",
        state="TX",
        postal="",
        lat=30.082222,
        lng=-95.991667,
        housenumber="",
        country="USA",
    ),
    "Bangor, Maine": SportsballGeocodeTuple(
        city="Bangor",
        state="ME",
        postal="",
        lat=44.803056,
        lng=-68.7675,
        housenumber="",
        country="USA",
    ),
    "Louisville Convention Center, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KT",
        postal="",
        lat=38.254194,
        lng=-85.755111,
        housenumber="",
        country="USA",
    ),
    "Long Beach Arena, Long Beach, California": SportsballGeocodeTuple(
        city="Long Beach",
        state="CA",
        postal="",
        lat=33.763889,
        lng=-118.188333,
        housenumber="",
        country="USA",
    ),
    "Uline Arena, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.905,
        lng=-77.003056,
        housenumber="",
        country="USA",
    ),
    "Selland Arena, Fresno, California": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="",
        lat=36.733093,
        lng=-119.78271,
        housenumber="700",
        country="USA",
    ),
    "Reid Gymnasium, Cullowhee, North Carolina": SportsballGeocodeTuple(
        city="Cullowhee",
        state="NC",
        postal="",
        lat=35.3102321,
        lng=-83.1838092,
        housenumber="",
        country="USA",
    ),
    "Levitt Arena, Wichita, Kansas": CHARLES_KOCH_ARENA,
    "Community Arena, Steubenville, Ohio": SportsballGeocodeTuple(
        city="Steubenville",
        state="OH",
        postal="",
        lat=40.369477,
        lng=-80.662254,
        housenumber="",
        country="USA",
    ),
    "Dinner Key Auditorium, Miami, Florida": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="33133",
        lat=25.728391,
        lng=-80.236465,
        housenumber="2700",
        country="USA",
    ),
    "Oakland-Alameda County Coliseum Arena, Oakland, California": OAKLAND_ARENA,
    "Loyola Field House, New Orleans, Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="",
        lat=29.937556,
        lng=-90.119944,
        housenumber="",
        country="USA",
    ),
    "Metropolitan Sports Center, Bloomington, Minnesota": SportsballGeocodeTuple(
        city="Bloomington",
        state="MN",
        postal="55420",
        lat=44.858333,
        lng=-93.24,
        housenumber="7901",
        country="USA",
    ),
    "Sam Houston Coliseum, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.761453,
        lng=-95.369546,
        housenumber="",
        country="USA",
    ),
    "Long Island Arena, Commack, New York": SportsballGeocodeTuple(
        city="Commack",
        state="NY",
        postal="",
        lat=40.838333,
        lng=-73.283333,
        housenumber="",
        country="USA",
    ),
    "St. Paul Auditorium, St. Paul, Minnesota": SportsballGeocodeTuple(
        city="St. Paul",
        state="MN",
        postal="",
        lat=44.944853,
        lng=-93.099445,
        housenumber="175",
        country="USA",
    ),
    "East Lansing, Michigan": SportsballGeocodeTuple(
        city="East Lansing",
        state="MI",
        postal="",
        lat=42.748056,
        lng=-84.483611,
        housenumber="",
        country="USA",
    ),
    "Honolulu, Hawaii": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="",
        lat=21.306944,
        lng=-157.858333,
        housenumber="",
        country="USA",
    ),
    "Lincoln, Nebraska": SportsballGeocodeTuple(
        city="Lincoln",
        state="NB",
        postal="",
        lat=40.809167,
        lng=-96.678056,
        housenumber="",
        country="USA",
    ),
    "New Orleans, Louisiana": NEW_ORLEANS_CITY,
    "San Jose Civic Auditorium, San Jose, California": SAN_JOSE_CIVIC_AUDITORIUM,
    "Blackham Coliseum, Lafeyette, Louisiana": SportsballGeocodeTuple(
        city="Lafeyette",
        state="LA",
        postal="70506",
        lat=30.210554,
        lng=-92.033122,
        housenumber="444",
        country="USA",
    ),
    "Duluth Arena Auditorium, Duluth, Minnesota": SportsballGeocodeTuple(
        city="Duluth",
        state="MN",
        postal="55802",
        lat=46.781389,
        lng=-92.098056,
        housenumber="350",
        country="USA",
    ),
    "Baltimore Civic Center, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.288611,
        lng=-76.618889,
        housenumber="201",
        country="USA",
    ),
    "Melbourne Cricket Ground, Melbourne, Austrália": MCG,
    "Marvel Stadium, Melbourne, Austrália": MARVEL_STADIUM,
    "Adelaide Oval, Adelaide, Austrália": ADELAIDE_OVAL,
    "The Gabba, Brisbane, Austrália": GABBA,
    "Detroit Olympia, Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.354444,
        lng=-83.100556,
        housenumber="5920",
        country="USA",
    ),
    "Convention Hall, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.947368,
        lng=-75.195043,
        housenumber="3400",
        country="USA",
    ),
    "Miami Beach Auditorium, Miami Beach, Florida": MIAMI_BEACH_CONVENTION_CENTER,
    "Kiel Auditorium, St. Louis, Missouri": SportsballGeocodeTuple(
        city="St. Louis",
        state="MS",
        postal="63103",
        lat=38.627972,
        lng=-90.201782,
        housenumber="1401",
        country="USA",
    ),
    "Onondaga War Memorial, Syracuse, New York": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="",
        lat=43.044722,
        lng=-76.148333,
        housenumber="515",
        country="USA",
    ),
    "New York, New York": SportsballGeocodeTuple(
        city="New York",
        state="NY",
        postal="",
        lat=40.712778,
        lng=-74.006111,
        housenumber="",
        country="USA",
    ),
    "69th Regiment Armory, New York, New York": SportsballGeocodeTuple(
        city="New York",
        state="NY",
        postal="",
        lat=40.741389,
        lng=-73.984167,
        housenumber="68",
        country="USA",
    ),
    "Boston Garden, Boston, Massachusetts": BOSTON_GARDENS,
    "Madison Square Garden (III), New York, New York": MADISON_SQUARE_GARDEN,
    "West Point, New York": SportsballGeocodeTuple(
        city="West Point",
        state="NY",
        postal="",
        lat=41.395,
        lng=-73.955,
        housenumber="",
        country="USA",
    ),
    "Bethlehem, Pennsylvania": SportsballGeocodeTuple(
        city="Bethlehem",
        state="PA",
        postal="",
        lat=40.626111,
        lng=-75.375556,
        housenumber="",
        country="USA",
    ),
    "Memphis, Tennessee": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="",
        lat=35.1175,
        lng=-89.971111,
        housenumber="",
        country="USA",
    ),
    "Champaign, Illinois": SportsballGeocodeTuple(
        city="Champaign",
        state="IL",
        postal="",
        lat=40.116389,
        lng=-88.243611,
        housenumber="",
        country="USA",
    ),
    "Iowa City, Iowa": SportsballGeocodeTuple(
        city="Iowa City",
        state="IO",
        postal="",
        lat=41.66,
        lng=-91.53,
        housenumber="",
        country="USA",
    ),
    "Cedar City, Utah": SportsballGeocodeTuple(
        city="Cedar City",
        state="UT",
        postal="",
        lat=37.6775,
        lng=-113.095278,
        housenumber="",
        country="USA",
    ),
    "Oxford, Mississippi": SportsballGeocodeTuple(
        city="Oxford",
        state="MS",
        postal="",
        lat=34.372222,
        lng=-89.508056,
        housenumber="",
        country="USA",
    ),
    "Massimino Court, West Palm Beach, Florida": SportsballGeocodeTuple(
        city="West Palm Beach",
        state="FL",
        postal="33409",
        lat=26.7163158,
        lng=-80.1098274,
        housenumber="2300",
        country="USA",
    ),
    "Brookshire Grocery Arena, Bossier City, Louisiana": BROOKSHIRE_GROCERY_ARENA,
    "Roberto Clemente Coliseum, San Juan": SportsballGeocodeTuple(
        city="San Juan",
        state="PR",
        postal="",
        lat=18.4159,
        lng=-66.0754,
        housenumber="",
        country="USA",
    ),
    "Trojan Fieldhouse, Little Rock, Arkansas": SportsballGeocodeTuple(
        city="Little Rock",
        state="AR",
        postal="37210",
        lat=36.1407945,
        lng=-86.7555075,
        housenumber="410",
        country="USA",
    ),
    "George Q. Cannon Activities Center, Laie, Hawaii": SportsballGeocodeTuple(
        city="Laie",
        state="HI",
        postal="96762",
        lat=21.641036,
        lng=-157.9224658,
        housenumber="55",
        country="USA",
    ),
    "The Arena at Northwest Florida State College, Niceville, Florida": SportsballGeocodeTuple(
        city="Niceville",
        state="FL",
        postal="",
        lat=30.5394,
        lng=-86.4756,
        housenumber="",
        country="USA",
    ),
    "South Point Arena, Enterprise, Nevada": SportsballGeocodeTuple(
        city="Enterprise",
        state="NV",
        postal="89183",
        lat=36.011426,
        lng=-115.1753,
        housenumber="9777",
        country="USA",
    ),
    "McGonigle Hall, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19121",
        lat=39.981029,
        lng=-75.158033,
        housenumber="1800",
        country="USA",
    ),
    "Municipal Auditorium, Columbus, Georgia": SportsballGeocodeTuple(
        city="Columbus",
        state="GA",
        postal="",
        lat=32.5029979,
        lng=-84.9441475,
        housenumber="",
        country="USA",
    ),
    "IUPUI Gymnasium, Indianapolis, Indiana": THE_JUNGLE,
    "Daniel Lynch '38 Gymnasium, Brooklyn, New York": GENEROSO_POPE_ATHELTIC_COMPLEX,
    "TD Bank Sports Center, Hamden, Connecticut": TD_BANK_SPORTS_CENTER,
    "University of Tasmania Stadium, Launceston, Austrália": UTAS_STADIUM,
    "Optus Stadium, Perth, Austrália": OPTUS_STADIUM,
    "San Francisco, California": SportsballGeocodeTuple(
        city="San Francisco",
        state="CA",
        postal="",
        lat=37.783333,
        lng=-122.416667,
        housenumber="",
        country="USA",
    ),
    "Villanova, Pennsylvania": SportsballGeocodeTuple(
        city="Villanova",
        state="PA",
        postal="",
        lat=40.037222,
        lng=-75.349167,
        housenumber="",
        country="USA",
    ),
    "Normal, Illinois": SportsballGeocodeTuple(
        city="Normal",
        state="IL",
        postal="",
        lat=40.512222,
        lng=-88.988611,
        housenumber="",
        country="USA",
    ),
    "Troy, Alabama": SportsballGeocodeTuple(
        city="Troy",
        state="AL",
        postal="",
        lat=31.808889,
        lng=-85.97,
        housenumber="",
        country="USA",
    ),
    "Fargo, North Dakota": SportsballGeocodeTuple(
        city="Fargo",
        state="ND",
        postal="",
        lat=46.873333,
        lng=-96.827222,
        housenumber="",
        country="USA",
    ),
    "Savannah Civic Center, Savannah, Georgia": SportsballGeocodeTuple(
        city="Savannah",
        state="GA",
        postal="31401",
        lat=32.0769645,
        lng=-81.0995252,
        housenumber="301",
        country="USA",
    ),
    "Barossa Park, Lyndoch, Australia": BAROSSA_PARK,
    "Peoria, Illinois": SportsballGeocodeTuple(
        city="Peoria",
        state="IL",
        postal="",
        lat=40.692778,
        lng=-89.590556,
        housenumber="",
        country="USA",
    ),
    "Lenovo Center, Raleigh, North Carolina": LENOVO_CENTER,
    "Durham, North Carolina": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="",
        lat=35.978611,
        lng=-78.9,
        housenumber="",
        country="USA",
    ),
    "South Orange, New Jersey": SportsballGeocodeTuple(
        city="South Orange",
        state="NJ",
        postal="",
        lat=40.748811,
        lng=-74.261512,
        housenumber="",
        country="USA",
    ),
    "Foster Pavilion, Waco, Texas": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="",
        lat=31.556698,
        lng=-97.121613,
        housenumber="",
        country="USA",
    ),
    "Santa Clara, California": SportsballGeocodeTuple(
        city="Santa Clara",
        state="CA",
        postal="",
        lat=37.354444,
        lng=-121.969167,
        housenumber="",
        country="USA",
    ),
    "Stanford, California": SportsballGeocodeTuple(
        city="Stanford",
        state="CA",
        postal="",
        lat=37.4225,
        lng=-122.165278,
        housenumber="",
        country="USA",
    ),
    "Intrust Bank Arena, Wichita, Kansas": SportsballGeocodeTuple(
        city="Wichita",
        state="KS",
        postal="",
        lat=37.683056,
        lng=-97.331389,
        housenumber="500",
        country="USA",
    ),
    "Chattanooga, Tennessee": SportsballGeocodeTuple(
        city="Chattanooga",
        state="TN",
        postal="",
        lat=35.045556,
        lng=-85.267222,
        housenumber="",
        country="USA",
    ),
    "Norfolk, Virginia": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="",
        lat=36.846944,
        lng=-76.285278,
        housenumber="",
        country="USA",
    ),
    "Des Moines, Iowa": SportsballGeocodeTuple(
        city="Des Moines",
        state="IA",
        postal="",
        lat=41.590833,
        lng=-93.620833,
        housenumber="",
        country="USA",
    ),
    "Conway, South Carolina": SportsballGeocodeTuple(
        city="Conway",
        state="SC",
        postal="",
        lat=33.838056,
        lng=-79.056111,
        housenumber="",
        country="USA",
    ),
    "Macomb, Illinois": SportsballGeocodeTuple(
        city="Macomb",
        state="IL",
        postal="",
        lat=40.470833,
        lng=-90.680833,
        housenumber="",
        country="USA",
    ),
    "Stockton, California": SportsballGeocodeTuple(
        city="Stockton",
        state="CA",
        postal="",
        lat=37.975556,
        lng=-121.300833,
        housenumber="",
        country="USA",
    ),
    "Jonesboro, Arkansas": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AR",
        postal="",
        lat=35.811111,
        lng=-90.696944,
        housenumber="",
        country="USA",
    ),
    "Alcorn State, Mississippi": SportsballGeocodeTuple(
        city="Alcorn State",
        state="MI",
        postal="",
        lat=31.8769,
        lng=-91.1411,
        housenumber="",
        country="USA",
    ),
    "Evanston, Illinois": SportsballGeocodeTuple(
        city="Evanston",
        state="IL",
        postal="",
        lat=42.046389,
        lng=-87.694722,
        housenumber="",
        country="USA",
    ),
    "Missoula, Montana": SportsballGeocodeTuple(
        city="Missoula",
        state="MT",
        postal="",
        lat=46.892778,
        lng=-114.021667,
        housenumber="",
        country="USA",
    ),
    "Cheney, Washington": SportsballGeocodeTuple(
        city="Cheney",
        state="WA",
        postal="",
        lat=47.488611,
        lng=-117.578611,
        housenumber="",
        country="USA",
    ),
    "Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="",
        lat=30.336944,
        lng=-81.661389,
        housenumber="",
        country="USA",
    ),
    "Nacogdoches, Texas": SportsballGeocodeTuple(
        city="Nacogdoches",
        state="TX",
        postal="",
        lat=31.63,
        lng=-94.628611,
        housenumber="",
        country="USA",
    ),
    "Commerce, Texas": SportsballGeocodeTuple(
        city="Commerce",
        state="TX",
        postal="",
        lat=33.245,
        lng=-95.894444,
        housenumber="",
        country="USA",
    ),
    "Beaumont, Texas": SportsballGeocodeTuple(
        city="Beaumont",
        state="TX",
        postal="",
        lat=30.08,
        lng=-94.126667,
        housenumber="",
        country="USA",
    ),
    "Greeley, Colorado": SportsballGeocodeTuple(
        city="Greeley",
        state="CO",
        postal="",
        lat=40.423333,
        lng=-104.709167,
        housenumber="",
        country="USA",
    ),
    "Ogden, Utah": SportsballGeocodeTuple(
        city="Ogden",
        state="UT",
        postal="",
        lat=41.227778,
        lng=-111.968333,
        housenumber="",
        country="USA",
    ),
    "University Park, Pennsylvania": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="",
        lat=40.806667,
        lng=-77.880278,
        housenumber="",
        country="USA",
    ),
    "Barossa Park": BAROSSA_PARK,
    "Moraga, California": SportsballGeocodeTuple(
        city="Moraga",
        state="CA",
        postal="",
        lat=37.835,
        lng=-122.129722,
        housenumber="",
        country="USA",
    ),
    "Hammond, Louisiana": SportsballGeocodeTuple(
        city="Hammond",
        state="LA",
        postal="",
        lat=30.5025,
        lng=-90.475,
        housenumber="",
        country="USA",
    ),
    "Macon, Georgia": SportsballGeocodeTuple(
        city="Macon",
        state="GA",
        postal="",
        lat=32.834722,
        lng=-83.651667,
        housenumber="",
        country="USA",
    ),
    "Radford, Virginia": SportsballGeocodeTuple(
        city="Radford",
        state="VA",
        postal="",
        lat=37.1275,
        lng=-80.569444,
        housenumber="",
        country="USA",
    ),
    "Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="",
        lat=34.946667,
        lng=-81.9275,
        housenumber="",
        country="USA",
    ),
    "Rock Hill, South Carolina": SportsballGeocodeTuple(
        city="Rock Hill",
        state="SC",
        postal="",
        lat=34.946667,
        lng=-81.9275,
        housenumber="",
        country="USA",
    ),
    "Montgomery, Alabama": SportsballGeocodeTuple(
        city="Montgomery",
        state="AL",
        postal="",
        lat=32.3675,
        lng=-86.3,
        housenumber="",
        country="USA",
    ),
    "Elma Roane Fieldhouse, Memphis, Tennessee": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="38152",
        lat=35.118369,
        lng=-89.935675,
        housenumber="495",
        country="USA",
    ),
    "Murray, Kentucky": SportsballGeocodeTuple(
        city="Murray",
        state="KY",
        postal="",
        lat=36.609444,
        lng=-88.315556,
        housenumber="",
        country="USA",
    ),
    "Grand Forks, North Dakota": SportsballGeocodeTuple(
        city="Grand Forks",
        state="ND",
        postal="",
        lat=47.921264,
        lng=-97.088339,
        housenumber="",
        country="USA",
    ),
    "Cookeville, Tennessee": SportsballGeocodeTuple(
        city="Cookeville",
        state="TN",
        postal="",
        lat=36.164167,
        lng=-85.504167,
        housenumber="",
        country="USA",
    ),
    "Malibu, California": SportsballGeocodeTuple(
        city="Malibu",
        state="CA",
        postal="",
        lat=34.035,
        lng=-118.695,
        housenumber="",
        country="USA",
    ),
    "Boiling Springs, North Carolina": SportsballGeocodeTuple(
        city="Boiling Springs",
        state="NC",
        postal="",
        lat=35.251944,
        lng=-81.663611,
        housenumber="",
        country="USA",
    ),
    "Lexington, Virginia": SportsballGeocodeTuple(
        city="Lexington",
        state="VA",
        postal="",
        lat=37.783889,
        lng=-79.442778,
        housenumber="",
        country="USA",
    ),
    "Buccaneer Fieldhouse, Charleston, South Carolina": BUCCANEER_FIELDHOUSE,
    "Charleston, Illinois": SportsballGeocodeTuple(
        city="Charleston",
        state="IL",
        postal="",
        lat=39.484167,
        lng=-88.178056,
        housenumber="",
        country="USA",
    ),
    "Worcester, Massachusetts": SportsballGeocodeTuple(
        city="Worcester",
        state="MA",
        postal="",
        lat=42.271389,
        lng=-71.798889,
        housenumber="",
        country="USA",
    ),
    "Joan Perry Brock Center, Farmville, Virginia": SportsballGeocodeTuple(
        city="Farmville",
        state="VA",
        postal="",
        lat=37.298333,
        lng=-78.395556,
        housenumber="405",
        country="USA",
    ),
    "Princess Anne, Maryland": SportsballGeocodeTuple(
        city="Princess Anne",
        state="MD",
        postal="",
        lat=38.209722,
        lng=-75.695,
        housenumber="",
        country="USA",
    ),
    "The Sandy and John Black Pavilion at Ole Miss, University, Mississippi": OLE_MISS,
    "Joel and Diane Bloom Wellness and Events Center, Newark, New Jersey": WELLNESS_AND_EVENTS_CENTER,
    "Asheville, North Carolina": SportsballGeocodeTuple(
        city="Asheville",
        state="NC",
        postal="",
        lat=35.595556,
        lng=-82.551944,
        housenumber="",
        country="USA",
    ),
    "Clinton, South Carolina": SportsballGeocodeTuple(
        city="Clinton",
        state="SC",
        postal="",
        lat=34.471389,
        lng=-81.875,
        housenumber="",
        country="USA",
    ),
    "Edwardsville, Illinois": SportsballGeocodeTuple(
        city="Edwardsville",
        state="IL",
        postal="",
        lat=38.803889,
        lng=-89.958333,
        housenumber="",
        country="USA",
    ),
    "DeLand, Florida": SportsballGeocodeTuple(
        city="DeLand",
        state="FL",
        postal="",
        lat=29.0225,
        lng=-81.286389,
        housenumber="",
        country="USA",
    ),
    "Martin, Tennessee": SportsballGeocodeTuple(
        city="Martin",
        state="TN",
        postal="",
        lat=36.341944,
        lng=-88.851667,
        housenumber="",
        country="USA",
    ),
    "The Coliseum, Carrollton, Georgia": SportsballGeocodeTuple(
        city="Carrollton",
        state="GA",
        postal="",
        lat=33.5761,
        lng=-85.1039,
        housenumber="",
        country="USA",
    ),
    "Williamsburg, Virginia": SportsballGeocodeTuple(
        city="Williamsburg",
        state="VA",
        postal="",
        lat=37.270833,
        lng=-76.706944,
        housenumber="",
        country="USA",
    ),
    "Cedar Falls, Iowa": SportsballGeocodeTuple(
        city="Cedar Falls",
        state="IA",
        postal="",
        lat=42.52352,
        lng=-92.446402,
        housenumber="",
        country="USA",
    ),
    "Towson, Maryland": SportsballGeocodeTuple(
        city="Towson",
        state="MD",
        postal="",
        lat=39.393056,
        lng=-76.609444,
        housenumber="",
        country="USA",
    ),
    "Vermillon, South Dakota": SportsballGeocodeTuple(
        city="Vermillon",
        state="SD",
        postal="",
        lat=42.781389,
        lng=-96.925278,
        housenumber="",
        country="USA",
    ),
    "Francis A. Levien Gymnasium, New York, New York": LEVIEN_GYM,
    "Tampa, Florida": SportsballGeocodeTuple(
        city="Tampa",
        state="FL",
        postal="",
        lat=27.9475,
        lng=-82.458611,
        housenumber="",
        country="USA",
    ),
    "Berkeley, California": SportsballGeocodeTuple(
        city="Berkeley",
        state="CA",
        postal="",
        lat=37.871667,
        lng=-122.272778,
        housenumber="",
        country="USA",
    ),
    "Barossa Oval - Australia": BAROSSA_PARK,
    "Civic Arena, Pittsburgh, Pennsylvania": CIVIC_ARENA,
    "Verizon Arena, North Little Rock, Arkansas": SIMMONS_BANK_ARENA,
    "BB&T Center, Sunrise, Florida": SportsballGeocodeTuple(
        city="Sunrise",
        state="FL",
        postal="",
        lat=26.158333,
        lng=-80.325556,
        housenumber="1",
        country="USA",
    ),
    "BOK Center, Tulsa, Oklahoma": BOK_CENTER,
    "Alamodome, San Antonio, TX, USA": ALAMODOME,
    "KeyArena, Seattle, Washington": CLIMATE_PLEDGE_ARENA,
    "Naples, Florida": SportsballGeocodeTuple(
        city="Naples",
        state="FL",
        postal="",
        lat=26.136111,
        lng=-81.794444,
        housenumber="",
        country="USA",
    ),
    "Henrico Sports & Events Center, Henrico, Virginia": SportsballGeocodeTuple(
        city="Henrico",
        state="VA",
        postal="23059",
        lat=37.6771948,
        lng=-77.4528141,
        housenumber="1",
        country="USA",
    ),
    "College Park, Georgia": SportsballGeocodeTuple(
        city="College Park",
        state="GA",
        postal="",
        lat=33.6175,
        lng=-84.4675,
        housenumber="",
        country="USA",
    ),
    "Ralston, Nebraska": SportsballGeocodeTuple(
        city="Ralston",
        state="NB",
        postal="",
        lat=41.200556,
        lng=-96.035556,
        housenumber="",
        country="USA",
    ),
    "Bill Greehey Arena, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="78228",
        lat=29.451858,
        lng=-98.5643022,
        housenumber="1",
        country="USA",
    ),
    "Hartsell Arena, Pensacola, Florida": SportsballGeocodeTuple(
        city="Pensacola",
        state="FL",
        postal="32504",
        lat=30.4793276,
        lng=-87.1995723,
        housenumber="",
        country="USA",
    ),
    "Kerr Fitness Center, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="15237",
        lat=40.5691309,
        lng=-80.01166,
        housenumber="9000",
        country="USA",
    ),
    "Titan Field House, Melbourne, Florida": SportsballGeocodeTuple(
        city="Melbourne",
        state="FL",
        postal="3865",
        lat=28.16992,
        lng=-80.66588,
        housenumber="32935",
        country="USA",
    ),
    "H&HP Complex, Lake Charles, Louisiana": LEGACY_CENTER,
    "Bill Harris Arena, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="35208",
        lat=33.495,
        lng=-86.874,
        housenumber="2331",
        country="USA",
    ),
    "Rochester, New York": SportsballGeocodeTuple(
        city="Rochester",
        state="NY",
        postal="",
        lat=43.165556,
        lng=-77.616111,
        housenumber="",
        country="USA",
    ),
    "North Little Rock, Arkansas": SportsballGeocodeTuple(
        city="North Little Rock",
        state="AR",
        postal="",
        lat=34.780833,
        lng=-92.256944,
        housenumber="",
        country="USA",
    ),
    "Taco Bell Arena, Boise, Idaho": EXTRAMILE_ARENA,
    "Kent, Washington": SportsballGeocodeTuple(
        city="Kent",
        state="WA",
        postal="",
        lat=47.382778,
        lng=-122.226944,
        housenumber="",
        country="USA",
    ),
    "Magness Arena, Denver, Colorado": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="",
        lat=39.682106,
        lng=-104.961592,
        housenumber="2240",
        country="USA",
    ),
    "ESPN Wide World of Sports, Orlando, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Scotiabank Arena, Toronto": SCOTIABANK_ARENA,
    "Chaparral Center, Midland, Texas": SportsballGeocodeTuple(
        city="Midland",
        state="TX",
        postal="",
        lat=32.028,
        lng=-102.103,
        housenumber="2240",
        country="USA",
    ),
    "U.S. Bank Stadium, Minneapolis, Minnesota": US_BANK_STADIUM,
    "Honda Center, Anaheim, California": SportsballGeocodeTuple(
        city="Anaheim",
        state="CA",
        postal="",
        lat=33.807778,
        lng=-117.876667,
        housenumber="2695",
        country="USA",
    ),
    "NJIT Wellness and Events Center, Newark, New Jersey": WELLNESS_AND_EVENTS_CENTER,
    "McGrath-Phillips Arena, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60604",
        lat=41.923901,
        lng=-87.653167,
        housenumber="2323",
        country="USA",
    ),
    "Nationwide Arena, Columbus, Ohio": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="",
        lat=39.969283,
        lng=-83.006111,
        housenumber="200",
        country="USA",
    ),
    "Jacksonville Veteran's Memorial Arena, Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32202",
        lat=30.325769,
        lng=-81.645069,
        housenumber="300",
        country="USA",
    ),
    "James T. Valvano Arena, Raleigh, North Carolina": REYNOLDS_COLISEUM,
    "North Charleston Coliseum, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29418",
        lat=32.8656,
        lng=-80.0224,
        housenumber="5001",
        country="USA",
    ),
    "Fiserv Forum,": FISERV_FORUM,
    "First Horizon Coliseum, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.0596,
        lng=-79.8257,
        housenumber="1921",
        country="USA",
    ),
    "North Athletic Complex, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="",
        lat=40.519083,
        lng=-80.212405,
        housenumber="",
        country="USA",
    ),
    "Georgetown, Kentucky": SportsballGeocodeTuple(
        city="Georgetown",
        state="KY",
        postal="",
        lat=38.209722,
        lng=-84.56,
        housenumber="",
        country="USA",
    ),
    "Gold Dome, Shreveport, Louisiana": SportsballGeocodeTuple(
        city="Shreveport",
        state="LA",
        postal="71134",
        lat=32.480921,
        lng=-93.729818,
        housenumber="2911",
        country="USA",
    ),
    "American Airlines Arena, Miami, Florida": KASEYA_CENTER,
    "Vancouver Convention Centre,": VANCOUVER_CONVENTION_CENTER,
    "Vancouver Convention Centre, Vancouver": VANCOUVER_CONVENTION_CENTER,
    "Kendal Isaacs Gymnasium, Nassau": KENDALL_ISAACS_GYMNASIUM,
    "Kendal Isaacs Gymnasium, Nassau, The Bahamas": KENDALL_ISAACS_GYMNASIUM,
    "Otter Sports Center, Marina, California": SportsballGeocodeTuple(
        city="Marina",
        state="CA",
        postal="93933",
        lat=36.6544526,
        lng=-121.8081741,
        housenumber="2050",
        country="USA",
    ),
    "SimpliFi Arena at Stan Sheriff Center, Honolulu, Hawaii": SportsballGeocodeTuple(
        city="Marina",
        state="CA",
        postal="93933",
        lat=36.6544526,
        lng=-121.8081741,
        housenumber="2050",
        country="USA",
    ),
    "ShoWare Center, Kent, Washington": SportsballGeocodeTuple(
        city="Kent",
        state="WA",
        postal="",
        lat=47.388333,
        lng=-122.24,
        housenumber="625",
        country="USA",
    ),
    "Schar Center,": SCHAR_CENTER,
    "Fort Bliss, El Paso, Texas": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="",
        lat=31.801847,
        lng=-106.424608,
        housenumber="",
        country="USA",
    ),
    "Huntington, West Virginia": SportsballGeocodeTuple(
        city="Huntington",
        state="WV",
        postal="",
        lat=38.41925,
        lng=-82.445153,
        housenumber="",
        country="USA",
    ),
    "St. John Arena, Columbus, Ohio": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="43210",
        lat=40.005278,
        lng=-83.018889,
        housenumber="410",
        country="USA",
    ),
    "Delmar-Tusa Fieldhouse, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77092",
        lat=29.802778,
        lng=-95.456944,
        housenumber="2020",
        country="USA",
    ),
    "Reno Events Center, Reno, Nevada": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="",
        lat=39.5309,
        lng=-119.8125,
        housenumber="400",
        country="USA",
    ),
    "E.J. Wade Arena at Stuart C. Siegel Center, Richmond, Virginia": STUART_SIEGEL_CENTER,
    "Allstate Arena, Rosemont, Illinois": SportsballGeocodeTuple(
        city="Rosemont",
        state="IL",
        postal="",
        lat=42.005278,
        lng=-87.887778,
        housenumber="400",
        country="USA",
    ),
    "KeyArena at Seattle Center , Seattle, Washington": CLIMATE_PLEDGE_ARENA,
    "Municipal Auditorium, Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.098353,
        lng=-94.586416,
        housenumber="301",
        country="USA",
    ),
    "Hattiesburg, Mississippi": SportsballGeocodeTuple(
        city="Hattiesburg",
        state="MS",
        postal="",
        lat=31.315833,
        lng=-89.308611,
        housenumber="",
        country="USA",
    ),
    "Hampton University Convocation Center, Hampton, Virginia": HAMPTON_CONVOCATION_CENTER,
    "Alumni Gym, Elon, North Carolina": SportsballGeocodeTuple(
        city="Elon",
        state="NC",
        postal="",
        lat=36.109018,
        lng=-79.506705,
        housenumber="",
        country="USA",
    ),
    "Jack and Ruth Ann Hill Convocation Center, Statesboro, Georgia": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="30458",
        lat=32.40625,
        lng=-81.783056,
        housenumber="284",
        country="USA",
    ),
    "CONSOL Enegery Center, Pittsburgh, Pennsylvania": PPG_PAINTS_ARENA,
    "Chase Center - San Francisco, California, USA - United States": CHASE_CENTER,
    "San Marcos, Texas": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="",
        lat=29.879444,
        lng=-97.938889,
        housenumber="",
        country="USA",
    ),
    "Retriever Activities Center, Baltimore, Maryland": RETRIEVER_ACTIVITIES_CENTER,
    "Memorial Coliseum, Portland, Oregon": MEMORIAL_COLISEUM,
    "Charles L. Sewall Center, Coraopolis, Pennsylvania": SportsballGeocodeTuple(
        city="Coraopolis",
        state="PA",
        postal="",
        lat=40.520212,
        lng=-80.21476,
        housenumber="",
        country="USA",
    ),
    "The Pavilion, Villanova, Pennsylvania": FINNERAN_PAVILION,
    "Scheels Arena, Fargo, North Dakota": SCHEELS_ARENA,
    "DakotaDome , Vermillion, South Dakota": SportsballGeocodeTuple(
        city="Vermillion",
        state="SD",
        postal="",
        lat=42.791111,
        lng=-96.927778,
        housenumber="1101",
        country="USA",
    ),
    "Benjamin Johnson Arena, Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="",
        lat=34.960278,
        lng=-81.932778,
        housenumber="",
        country="USA",
    ),
    "Hartford, Connecticut": SportsballGeocodeTuple(
        city="Hartford",
        state="CT",
        postal="",
        lat=41.7625,
        lng=-72.674167,
        housenumber="",
        country="USA",
    ),
    "Quest MultiSport, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60612",
        lat=41.8733479,
        lng=-87.6923655,
        housenumber="2641",
        country="USA",
    ),
    "ICI Center (Embry-Riddle), Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="32114",
        lat=29.1886,
        lng=-81.0487,
        housenumber="1",
        country="USA",
    ),
    "South Point Arena, Las Vegas, Nevada": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="89183",
        lat=36.0112358,
        lng=-115.1752286,
        housenumber="9777",
        country="USA",
    ),
    "Abrams Physical Fitness Center, Fort Hood, Texas": SportsballGeocodeTuple(
        city="Fort Hood",
        state="TX",
        postal="76544",
        lat=31.1382238,
        lng=-97.7772131,
        housenumber="",
        country="USA",
    ),
    "CenturyLink Center (LA), Bossier City, Louisiana": BROOKSHIRE_GROCERY_ARENA,
    "Dothan Civic Center, Dothan, Alabama": SportsballGeocodeTuple(
        city="Dothan",
        state="AL",
        postal="",
        lat=31.224722,
        lng=-85.39,
        housenumber="",
        country="USA",
    ),
    "Stockton Arena, Stockton, California": SportsballGeocodeTuple(
        city="Stockton",
        state="CA",
        postal="95203",
        lat=37.9561651,
        lng=-121.2960735,
        housenumber="248",
        country="USA",
    ),
    "Le Moyne Events Center, Syracuse, New York": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="13214",
        lat=43.0502,
        lng=-76.0848,
        housenumber="500",
        country="USA",
    ),
    "Bloch Arena, Honolulu, Hawaii": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="96818",
        lat=21.3477415,
        lng=-157.9412764,
        housenumber="224",
        country="USA",
    ),
    "Charleston Civic Center, Charleston, West Virginia": SportsballGeocodeTuple(
        city="Charleston",
        state="WV",
        postal="25301",
        lat=38.35519,
        lng=-81.64152,
        housenumber="200",
        country="USA",
    ),
    "Kezar Pavillion, San Francisco, California": KEZAR_STADIUM,
    "H.E.B. Center at Cedar Park, Cedar Park, Texas": SportsballGeocodeTuple(
        city="Cedar Park",
        state="TX",
        postal="",
        lat=30.5414,
        lng=-97.8202,
        housenumber="2100",
        country="USA",
    ),
    "Tom Golisano Field House, Ave Maria, Florida": SportsballGeocodeTuple(
        city="Ave Maria",
        state="FL",
        postal="34142",
        lat=26.3396049,
        lng=-81.4410362,
        housenumber="4810",
        country="USA",
    ),
    "Tuba City HS Gym, Tuba City, Arizona": SportsballGeocodeTuple(
        city="Tuba City",
        state="AZ",
        postal="86045",
        lat=36.126661,
        lng=-111.223479,
        housenumber="",
        country="USA",
    ),
    "Lakeland Center, Lakeland, Florida": SportsballGeocodeTuple(
        city="Lakeland",
        state="FL",
        postal="33815",
        lat=28.041053,
        lng=-81.963619,
        housenumber="701",
        country="USA",
    ),
    "'Iolani School Gym, Honolulu, Hawaii": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="96826",
        lat=21.2865,
        lng=-157.824567,
        housenumber="563",
        country="USA",
    ),
    "Mercyhurst Athletic Center, Erie, Pennsylvania": SportsballGeocodeTuple(
        city="Erie",
        state="PA",
        postal="",
        lat=42.1046,
        lng=-80.0556,
        housenumber="",
        country="USA",
    ),
    "Monroe, Louisiana": SportsballGeocodeTuple(
        city="Monroe",
        state="LA",
        postal="",
        lat=32.509444,
        lng=-92.118333,
        housenumber="",
        country="USA",
    ),
    "Bison Sports Arena, Fargo, North Dakota": SCHEELS_ARENA,
    "F&M Bank Arena, Clarksville, Tennessee": SportsballGeocodeTuple(
        city="Clarksville",
        state="TN",
        postal="",
        lat=36.529444,
        lng=-87.359722,
        housenumber="101",
        country="USA",
    ),
    "C.M. Tad Smith Coliseum, University, Mississippi": SportsballGeocodeTuple(
        city="University",
        state="MS",
        postal="38677",
        lat=34.362197,
        lng=-89.539303,
        housenumber="",
        country="USA",
    ),
    "Verties Sails Gymnasium, Memphis, Tennessee": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="38107",
        lat=35.1565496,
        lng=-89.9896643,
        housenumber="",
        country="USA",
    ),
    "Thibodaux, Louisiana": SportsballGeocodeTuple(
        city="Thibodaux",
        state="LA",
        postal="",
        lat=29.792222,
        lng=-90.82,
        housenumber="",
        country="USA",
    ),
    "New Orleans , Louisiana": NEW_ORLEANS_CITY,
    "First Bank & Trust Arena, Brookings, South Dakota": SportsballGeocodeTuple(
        city="Brookings",
        state="SD",
        postal="57007",
        lat=44.317984,
        lng=-96.779058,
        housenumber="1165",
        country="USA",
    ),
    "Cambria County War Memorial Arena, Johnstown, Pennsylvania": SportsballGeocodeTuple(
        city="Johnstown",
        state="PA",
        postal="15901",
        lat=40.32296,
        lng=-78.922654,
        housenumber="326",
        country="USA",
    ),
    "Petco Park, San Diego, California": PETCO_PARK,
    "Esby Gym, Glassboro, New Jersey": SportsballGeocodeTuple(
        city="Glassboro",
        state="NJ",
        postal="08028",
        lat=39.7106001,
        lng=-75.1186627,
        housenumber="300",
        country="USA",
    ),
    "Boone, North Carolina": SportsballGeocodeTuple(
        city="Boone",
        state="NC",
        postal="",
        lat=36.211111,
        lng=-81.666944,
        housenumber="",
        country="USA",
    ),
    "FedExForum - Memphis, Tennessee - United States": FEDEX_FORUM,
    "Kia Center, Orlando, FL, EUA": KIA_CENTER,
    "Davis Field House, Greenville, South Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="SC",
        postal="",
        lat=34.8725,
        lng=-82.361944,
        housenumber="",
        country="USA",
    ),
    "Rimrock Auto Arena at MetraPark, Billings, Montana": SportsballGeocodeTuple(
        city="Billings",
        state="MT",
        postal="59101",
        lat=45.800103,
        lng=-108.477201,
        housenumber="308",
        country="USA",
    ),
    "Corvallis, Oregon": SportsballGeocodeTuple(
        city="Corvallis",
        state="OR",
        postal="",
        lat=44.569722,
        lng=-123.278333,
        housenumber="",
        country="USA",
    ),
    "Mabee Center, Liberty, Missouri": SportsballGeocodeTuple(
        city="Liberty",
        state="MO",
        postal="64068",
        lat=39.24962892,
        lng=-94.4087267,
        housenumber="924",
        country="USA",
    ),
    "Durham, New Hampshire": SportsballGeocodeTuple(
        city="Durham",
        state="NH",
        postal="",
        lat=43.133889,
        lng=-70.926389,
        housenumber="",
        country="USA",
    ),
    "Morehead, Kentucky": SportsballGeocodeTuple(
        city="Morehead",
        state="KY",
        postal="",
        lat=38.190833,
        lng=-83.4475,
        housenumber="",
        country="USA",
    ),
    "Hart Center Arena, Worcester, Massachusetts": HART_RECREATION_CENTER,
    "Regional Special Events Center, Murray, Kentucky": CFSB_CENTER,
    "M&T Bank Arena, Hamden, Connecticut": TD_BANK_SPORTS_CENTER,
    "Cape Girardeau, Missouri": SportsballGeocodeTuple(
        city="Cape Girardeau",
        state="MO",
        postal="",
        lat=37.310833,
        lng=-89.559722,
        housenumber="",
        country="USA",
    ),
    "Memorial Center, Johnson City, Tennessee": SportsballGeocodeTuple(
        city="Johnson City",
        state="TN",
        postal="37601",
        lat=36.3037181,
        lng=-82.3707852,
        housenumber="",
        country="USA",
    ),
    "New Haven, Connecticut": SportsballGeocodeTuple(
        city="New Haven",
        state="CT",
        postal="",
        lat=41.308333,
        lng=-72.925,
        housenumber="",
        country="USA",
    ),
    "Ralston Arena, Ralston, Nebraska": SportsballGeocodeTuple(
        city="Ralston",
        state="NB",
        postal="",
        lat=41.206944,
        lng=-96.026944,
        housenumber="7300",
        country="USA",
    ),
    "Butler Hancock Sports Pavilion, Greeley, Colorado": BANK_OF_COLORADO_ARENA,
    "Avron B. Fogelman Arena, New Orleans, Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="70118",
        lat=29.938611,
        lng=-90.120556,
        housenumber="",
        country="USA",
    ),
    "Georgia Dome, Atlanta, Georgia": GEORGIA_DOME,
    "Pritchard Gymnasium, Stony Brook, New York": SportsballGeocodeTuple(
        city="Stony Brook",
        state="NY",
        postal="11790",
        lat=40.917238,
        lng=-73.124638,
        housenumber="",
        country="USA",
    ),
    "Agganis Arena, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="02215",
        lat=42.352231,
        lng=-71.117792,
        housenumber="925",
        country="USA",
    ),
    "Valparaiso, Indiana": SportsballGeocodeTuple(
        city="Valparaisos",
        state="IN",
        postal="",
        lat=41.476111,
        lng=-87.040278,
        housenumber="",
        country="USA",
    ),
    "Asheville Civic Center, Asheville, North Carolina": HARRAHS_CHEROKEE_CENTER,
    "RBC Center, Raleigh, North Carolina": LENOVO_CENTER,
    "1st Mariner Arena, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.288611,
        lng=-76.618889,
        housenumber="201",
        country="USA",
    ),
    "ASU Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "K.L. Johnson HPER Complex, Pine Bluff, Arkansas": SportsballGeocodeTuple(
        city="Pine Bluff",
        state="AR",
        postal="71601",
        lat=34.243825,
        lng=-92.017429,
        housenumber="1401",
        country="USA",
    ),
    "Qwest Center OMAHA, Omaha, Nebraska": CHI_HEALTH_CENTER,
    "Solomon Court at Cabot Center, Boston, Massachusetts": CABOT_CENTER,
    "University, Mississippi": SportsballGeocodeTuple(
        city="University",
        state="MS",
        postal="",
        lat=34.365556,
        lng=-89.537778,
        housenumber="",
        country="USA",
    ),
    "Centrum Arena, Cedar City, Utah": CENTRUM_ARENA,
    "Mount Pleasant, Michigan": SportsballGeocodeTuple(
        city="Mount Pleasant",
        state="MI",
        postal="",
        lat=43.597778,
        lng=-84.7675,
        housenumber="",
        country="USA",
    ),
    "Hampton, Virginia": SportsballGeocodeTuple(
        city="Hampton",
        state="VI",
        postal="",
        lat=37.026389,
        lng=-76.344444,
        housenumber="",
        country="USA",
    ),
    "Albuquerque, New Mexico": SportsballGeocodeTuple(
        city="Albuquerque",
        state="NM",
        postal="",
        lat=35.084444,
        lng=-106.650278,
        housenumber="",
        country="USA",
    ),
    "The Bank of Kentucky Center, Highland Heights, Kentucky": BANK_OF_KENTUCKY_CENTER,
    "Little Rock, Arkansas": SportsballGeocodeTuple(
        city="Little Rock",
        state="AR",
        postal="",
        lat=34.744444,
        lng=-92.288056,
        housenumber="",
        country="USA",
    ),
    "Bridgeport, Connecticut": SportsballGeocodeTuple(
        city="Bridgeport",
        state="CT",
        postal="",
        lat=41.186389,
        lng=-73.195556,
        housenumber="",
        country="USA",
    ),
    "Consol Energy Center, Pittsburgh, Pennsylvania": PPG_PAINTS_ARENA,
    "Loretto, Pennsylvania": SportsballGeocodeTuple(
        city="Loretto",
        state="PA",
        postal="",
        lat=40.506389,
        lng=-78.636111,
        housenumber="",
        country="USA",
    ),
    "Vermillion, South Dakota": SportsballGeocodeTuple(
        city="Vermillion",
        state="SD",
        postal="",
        lat=42.781389,
        lng=-96.925278,
        housenumber="",
        country="USA",
    ),
    "Ninja Stadium, Bellerive, Australia": BLUNDSTONE_ARENA,
    "Hornets Nest, Sacramento, California": THE_NEST,
    "Patriot Center, Fairfax, Virginia": EAGLEBANK_ARENA,
    "Carolina First Arena, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="",
        lat=32.789444,
        lng=-79.929444,
        housenumber="",
        country="USA",
    ),
    "Road Town": SportsballGeocodeTuple(
        city="Road Town",
        state="",
        postal="",
        lat=18.431389,
        lng=-64.623056,
        housenumber="",
        country="British Virgin Islands",
    ),
    "D.J. Sokol Arena, Omaha, Nebraska": SportsballGeocodeTuple(
        city="Omaha",
        state="NB",
        postal="",
        lat=41.266146,
        lng=-95.940471,
        housenumber="",
        country="USA",
    ),
    "Enterprise, Nevada": SportsballGeocodeTuple(
        city="Enterprise",
        state="NV",
        postal="",
        lat=36.031389,
        lng=-115.198056,
        housenumber="",
        country="USA",
    ),
    "Templeton Center, Clinton, South Carolina": ROSS_E_TEMPLETON_CENTER,
    "Tupelo, Mississippi": SportsballGeocodeTuple(
        city="Tupelo",
        state="MS",
        postal="",
        lat=34.259722,
        lng=-88.725833,
        housenumber="",
        country="USA",
    ),
    "HSBC Arena, Buffalo, New York": KEYBANK_CENTER,
    "New UCF Arena, Orlando, Florida": ADDITION_FINANCIAL_ARENA,
    "McKay Events Center, Orem, Utah": UCCU_CENTER,
    "Mobile, Alabama": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="",
        lat=30.6675,
        lng=-88.101111,
        housenumber="",
        country="USA",
    ),
    "Assembly Hall, Champaign, Illinois": STATE_FARM_CENTER,
    "Harbor Yard, Bridgeport, Connecticut": HARBOR_YARD,
    "Arena at Harbor Yard, Bridgeport, Connecticut": HARBOR_YARD,
    "Alltel Pavilion at the Stuart C. Siegel Center, Richmond, Virginia": STUART_SIEGEL_CENTER,
    "US Century Bank Arena, Miami, Florida": OCEAN_BANK_CONVOCATION_CENTER,
    "Chase Arena at Reich Family Pavilion, West Hartford, Connecticut": CHASE_FAMILY_ARENA,
    "University Center, Macon, Georgia": SportsballGeocodeTuple(
        city="Macon",
        state="GA",
        postal="",
        lat=32.829167,
        lng=-83.648611,
        housenumber="",
        country="USA",
    ),
    "The Pit/Bob King Court, Albuquerque, New Mexico": THE_PIT,
    "UTPA Fieldhouse, Edinburg, Texas": UTRGV_FIELDHOUSE,
    "Cowboy's Stadium, Arlington, Texas": ATT_STADIUM,
    "Rabobank Arena, Bakersfield, California": SportsballGeocodeTuple(
        city="Bakersfield",
        state="CA",
        postal="",
        lat=35.37208,
        lng=-119.013723,
        housenumber="1001",
        country="USA",
    ),
    "UCR Student Rec Center, Riverside, California": UCR_STUDENT_REC_CENTER,
    "Maurice Stokes Athletic Center, Loretto, Pennsylvania": DEGOL_ARENA,
    "RAC Arena, Baltimore, Maryland": RETRIEVER_ACTIVITIES_CENTER,
    "Alfond Arena, Orono, Maine": SportsballGeocodeTuple(
        city="Orono",
        state="ME",
        postal="04473",
        lat=44.904539,
        lng=-68.673617,
        housenumber="",
        country="USA",
    ),
    "The Milk House, Lake Buena Vista, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Sullivan Arena, Anchorage, Alaska": SportsballGeocodeTuple(
        city="Anchorage",
        state="AL",
        postal="04473",
        lat=61.205556,
        lng=-149.8725,
        housenumber="1600",
        country="USA",
    ),
    "Rose Arena, Mount Pleasant, Michigan": SportsballGeocodeTuple(
        city="Mount Pleasant",
        state="MI",
        postal="",
        lat=43.580888,
        lng=-84.773941,
        housenumber="",
        country="USA",
    ),
    "Towson Center, Towson, Maryland": SportsballGeocodeTuple(
        city="Towson",
        state="MD",
        postal="21252",
        lat=39.386375,
        lng=-76.616238,
        housenumber="7500",
        country="USA",
    ),
    "Multipurpose Center and Teaching Gym, Tallahassee, Florida": AL_LAWSON_CENTER,
    "Puerto Vallarta International Convention Center, Puerto Vallarta": SportsballGeocodeTuple(
        city="Puerto Vallarta",
        state="",
        postal="",
        lat=20.6799474,
        lng=-105.2334998,
        housenumber="",
        country="Mexico",
    ),
    "Bank of America Arena, Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.652,
        lng=-122.302,
        housenumber="3870",
        country="USA",
    ),
    "Comcast Center, College Park, Maryland": XFINITY_CENTER,
    "Atlantis Resort Arena, Nassau": IMPERIAL_ARENA,
    "United Spirit Arena, Lubbock, Texas": UNITED_SUPERMARKETS_ARENA,
    "Aventura Spa Palace Resort, Riviera Maya": SportsballGeocodeTuple(
        city="Playa del Carmen",
        state="QR",
        postal="77710",
        lat=20.5069801,
        lng=-87.215373,
        housenumber="72",
        country="Mexico",
    ),
    "U.S. Cellular Arena, Milwaukee, Wisconsin": MILWAUKEE_ARENA,
    "Friel Court, Pullman, Washington": BEASLEY_COLISEUM,
    "Lafayette, Louisiana": SportsballGeocodeTuple(
        city="Lafayette",
        state="LA",
        postal="",
        lat=30.208056,
        lng=-92.0325,
        housenumber="",
        country="USA",
    ),
    "Corbin J. Robertson Center, Georgetown, Texas": SportsballGeocodeTuple(
        city="Georgetown",
        state="TX",
        postal="78626",
        lat=30.6361364,
        lng=-97.6633265,
        housenumber="930",
        country="USA",
    ),
    "Daniel-Meyer Coliseum, Fort Worth, Texas": SCHOLLMAIER_ARENA,
    "Statesboro, Georgia": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="",
        lat=32.445278,
        lng=-81.779167,
        housenumber="",
        country="USA",
    ),
    "Times Warner Cable Arena, Charlotte, North Carolina": SPECTRUM_CENTRE,
    "UHY Center, Loudonville, New York": SportsballGeocodeTuple(
        city="Loudonville",
        state="NY",
        postal="12211",
        lat=42.7174,
        lng=-73.7487,
        housenumber="515",
        country="USA",
    ),
    "Frank L. Forbes Arena, Atlanta, Georgia": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="",
        lat=33.748471,
        lng=-84.417106,
        housenumber="",
        country="USA",
    ),
    "Earl C. Sams Gymnasium, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="78212",
        lat=29.4618769,
        lng=-98.4859131,
        housenumber="1",
        country="USA",
    ),
    "Mullaney Gymnasium, Providence, Rhode Island": ALUMNI_HALL,
    "Camp Humphreys, Anjeong-ri": SportsballGeocodeTuple(
        city="Anjeong-ri",
        state="",
        postal="",
        lat=36.9684272,
        lng=126.9811043,
        housenumber="",
        country="South Korea",
    ),
    "Curtis Culwell Center, Garland, Texas": SportsballGeocodeTuple(
        city="Garland",
        state="TX",
        postal="",
        lat=32.95956,
        lng=-96.64191,
        housenumber="4999",
        country="USA",
    ),
    "Summit Arena, Hot Springs, Arkansas": SportsballGeocodeTuple(
        city="Hot Springs",
        state="AR",
        postal="",
        lat=34.509722,
        lng=-93.049167,
        housenumber="398",
        country="USA",
    ),
    "Sioux Falls Arena, Sioux Falls, South Dakota": SportsballGeocodeTuple(
        city="Sioux Falls",
        state="SD",
        postal="57104",
        lat=43.562081,
        lng=-96.749333,
        housenumber="1201",
        country="USA",
    ),
    "Bob Devaney Sports Center, Lincoln, Nebraska": SportsballGeocodeTuple(
        city="Lincoln",
        state="NB",
        postal="",
        lat=40.830207,
        lng=-96.697644,
        housenumber="1600",
        country="USA",
    ),
    "HPER Complex, Grambling, Louisiana": FREDRICK_C_HOBDY_ASSEMBLY_CENTER,
}


def _create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    g = _CACHED_GEOCODES.get(query)
    if g is None:
        logging.warning("Failed to find query: %s", query)
        g = geocoder.google(query, session=session)
        _CACHED_GEOCODES[query] = g
    latitude = g.lat
    longitude = g.lng
    weather_model = None
    tz = "UTC"
    if latitude is not None and longitude is not None:
        tf = TimezoneFinder()
        timezone = tf.timezone_at(lng=longitude, lat=latitude)
        if timezone is not None:
            tz = timezone
        weather_model = create_mutli_weather_model(
            session,
            latitude,
            longitude,
            dt,  # pyright: ignore
            tz,
        )
    try:
        return AddressModel(
            city=g.city,
            state=g.state,
            zipcode=g.postal,
            latitude=latitude,
            longitude=longitude,
            housenumber=g.housenumber,
            weather=weather_model,  # pyright: ignore
            timezone=tz,
            country=g.country,
        )
    except Exception as exc:
        logging.warning("Failed to retrieve address model for query %s", query)
        raise ValueError(f"AddressModel failed to validate: {query}") from exc


@MEMORY.cache(ignore=["session"])
def _cached_create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    return _create_google_address_model(query, session, dt)


def create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    """Create address model from google."""
    if not pytest_is_running.is_running() and dt < datetime.datetime.now().replace(
        tzinfo=dt.tzinfo
    ) - datetime.timedelta(days=7):
        return _cached_create_google_address_model(query, session, dt)
    with session.cache_disabled():
        return _create_google_address_model(query, session, dt)
